@@ -20,7 +20,7 @@
     MultiBAM
     SAM
     SAMFlags
-    SAMBAMbase 
+    SAMBAMbase
 
 .. note:: BAM being the compressed version of SAM files, we do not
     implement any functionalities related to SAM files. We strongly encourage
@@ -29,22 +29,19 @@
 """
 import json
 import math
-
 from collections import Counter, OrderedDict, defaultdict
 
-from bx.intervals.intersection import Interval, IntervalTree
+import colorlog
 from bx.bitset import BinnedBitSet
 from bx.bitset_builders import binned_bitsets_from_list
-from sequana.lazy import pandas as pd
-from sequana.lazy import numpy as np
-from sequana.lazy import pylab
+from bx.intervals.intersection import Interval, IntervalTree
+from tqdm import tqdm
 
 from sequana.bed import BED
-from sequana.cigar import fetch_intron, fetch_exon
-
-import pysam
-
-import colorlog
+from sequana.cigar import fetch_exon, fetch_intron
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab, pysam
 
 logger = colorlog.getLogger(__name__)
 
@@ -175,8 +172,7 @@ class SAMBAMbase:
     @_reset
     def __len__(self):
         if self._N is None:
-            logger.warning("Scanning the BAM. Please wait")
-            self._N = sum(1 for _ in self._data)
+            self._N = sum([1 for _ in tqdm(self._data, leave=False)])
             self.reset()
         return self._N
 
@@ -222,7 +218,7 @@ class SAMBAMbase:
         return pylab.mean([abs(x) for x in data])
 
     @_reset
-    def get_df(self, max_align=-1):
+    def get_df(self, max_align=-1, progress=True):
         flags = []
         starts = []
         ends = []
@@ -231,7 +227,7 @@ class SAMBAMbase:
         querynames = []
         querylengths = []
         cigar = []
-        for i, a in enumerate(self._data):
+        for i, a in tqdm(enumerate(self._data), leave=False, disable=not progress):
             flags.append(a.flag)
             starts.append(a.reference_start)
             ends.append(a.reference_end)
@@ -259,7 +255,7 @@ class SAMBAMbase:
         return df
 
     @_reset
-    def get_df_concordance(self, max_align=-1):
+    def get_df_concordance(self, max_align=-1, progress=True):
         """This methods returns a dataframe with Insert, Deletion, Match,
         Substitution, read length, concordance (see below for a definition)
 
@@ -278,7 +274,7 @@ class SAMBAMbase:
         count = 0
         I, D, M, L, mapq, flags, NM, rnames = [], [], [], [], [], [], [], []
         S = []
-        for i, a in enumerate(self._data):
+        for i, a in tqdm(enumerate(self._data), leave=False, disable=not progress):
             # tags and cigar populated  if there is a match
             # if we use --cs cigar is not populated so we can only look at tags
             # tags can be an empty list
@@ -338,7 +334,18 @@ class SAMBAMbase:
 
         df = pd.DataFrame([C, L, I, D, M, mapq, flags, NM, S, rnames])
         df = df.T
-        df.columns = ["concordance", "length", "I", "D", "M", "mapq", "flags", "NM", "mismatch", "rname"]
+        df.columns = [
+            "concordance",
+            "length",
+            "I",
+            "D",
+            "M",
+            "mapq",
+            "flags",
+            "NM",
+            "mismatch",
+            "rname",
+        ]
         return df
 
     def __iter__(self):
@@ -499,8 +506,15 @@ class SAMBAMbase:
         return [protocol, spec1, spec2, other]
 
     @_reset
-    def mRNA_inner_distance(self, refbed, low_bound=-250, up_bound=250, step=5, sample_size=1000000, q_cut=30):
-
+    def mRNA_inner_distance(
+        self,
+        refbed,
+        low_bound=-250,
+        up_bound=250,
+        step=5,
+        sample_size=1000000,
+        q_cut=30,
+    ):
         """Estimate the inner distance of mRNA pair end fragment.
 
         ::
@@ -753,13 +767,17 @@ class SAMBAMbase:
         """Count flags/mapq/read length in one pass."""
         if self._summary is not None:
             return self._summary
+        else:
+            # make sure we reset the pointer to the first read
+            self.reset()
 
         mapq_dict = {}
         read_length_dict = {}
         flag_dict = {}
         mean_qualities = []
         count = 0
-        for read in self:
+
+        for read in tqdm(self, leave=False):
             self._count_item(mapq_dict, read.mapq)
             self._count_item(flag_dict, read.flag)
             if read.is_unmapped is False:
@@ -791,7 +809,14 @@ class SAMBAMbase:
         Y = [self.summary["read_length"][k] for k in X]
         return X, Y
 
-    def plot_insert_size(self, max_entries=100000, bins=100, upper_bound=1000, lower_bound=-1000, absolute=False):
+    def plot_insert_size(
+        self,
+        max_entries=100000,
+        bins=100,
+        upper_bound=1000,
+        lower_bound=-1000,
+        absolute=False,
+    ):
         """
 
         This gives an idea of the insert size without taking into account any
@@ -837,6 +862,21 @@ class SAMBAMbase:
         pylab.xlabel("Read length", fontsize=16)
         pylab.legend()
 
+    def plotly_hist_read_length(self, log_y=False, title="", xlabel="Read length (bp)", ylabel="count", **kwargs):
+        """Histogram of the read length using plotly
+
+        :param log_y:
+        :param title:
+
+        any additional arguments is pass to the plotly.express.hist function
+        """
+        import plotly.express as px
+
+        X, Y = self._get_read_length()
+        data = [x for x, y in self.summary["read_length"].items() for i in range(y)]
+        fig = px.histogram(data, labels={"x": xlabel, "y": ylabel}, log_y=log_y, title=title, **kwargs)
+        return fig
+
     def get_stats(self):
         """Return basic stats about the reads
 
@@ -1139,7 +1179,7 @@ SN	pairs on different chromosomes:	0
             barplot = df.plot(kind="bar", grid=True)
         pylab.xlabel("flags", fontsize=fontsize)
         pylab.ylabel("count", fontsize=fontsize)
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
         if filename:
             pylab.savefig(filename)
         return barplot
@@ -1235,10 +1275,16 @@ SN	pairs on different chromosomes:	0
 
         """
         df = self.get_mapq_as_df()
-        df.plot(kind="hist", bins=range(0, df.max().values[0] + 1), legend=False, grid=True, logy=True)
+        df.plot(
+            kind="hist",
+            bins=range(0, df.max().values[0] + 1),
+            legend=False,
+            grid=True,
+            logy=True,
+        )
         pylab.xlabel("MAPQ", fontsize=fontsize)
         pylab.ylabel("Count", fontsize=fontsize)
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
         if filename:
             pylab.savefig(filename)
 
@@ -1377,7 +1423,7 @@ SN	pairs on different chromosomes:	0
                     self.deletions.extend([x[1] for x in this.cigartuples if x[0] == 2])
 
     def plot_coverage(self, chrom=None):
-        """Please use :class:`GenomeCov` for more sophisticated
+        """Please use :class:`SequanaCoverage` for more sophisticated
         tools to plot the genome coverage
 
         .. plot::
@@ -1502,6 +1548,57 @@ SN	pairs on different chromosomes:	0
         pylab.xlabel("Soft clip length", fontsize=16)
         pylab.ylabel("#", fontsize=16)
 
+    def get_query_start(self, read):
+        """Get start of the query read."""
+        CLIP_FLAG = {4, 5}
+        strand = -1 if read.is_reverse else 0
+        if read.cigar[strand][0] in CLIP_FLAG:
+            return read.cigar[strand][1]
+        return 0
+
+    def get_query_end(self, read):
+        """Get end of the query read."""
+        strand = 0 if read.is_reverse else -1
+        CLIP_FLAG = {4, 5}
+        if read.cigar[strand][0] in CLIP_FLAG:
+            return read.infer_read_length() - read.cigar[strand][1]
+        return read.infer_read_length()
+
+    def to_paf(self):
+        with pysam.AlignmentFile(self.filename) as bam_in:
+            info = [
+                (
+                    align.reference_name,
+                    align.reference_start,
+                    align.reference_end,
+                    "-" if align.is_reverse else "+",
+                    align.flag,
+                    align.mapq,
+                    align.cigarstring,
+                    align.query_name,
+                    align.infer_read_length(),
+                    get_query_start(align),
+                    get_query_end(align),
+                )
+                for align in takewhile(lambda x: x.reference_start < 10, bam_in)
+            ]
+
+        COLNAMES = [
+            "r_name",
+            "r_start",
+            "r_end",
+            "strand",
+            "flag",
+            "mapq",
+            "cigar",
+            "q_name",
+            "q_len",
+            "q_start",
+            "q_end",
+        ]
+        paf = pd.DataFrame(info, columns=COLNAMES)
+        return paf
+
 
 class SAM(SAMBAMbase):
     """SAM Reader. See :class:`~samtools.bamtools.SAMBAMbase` for details"""
@@ -1608,7 +1705,7 @@ class MultiBAM:
             self.df.sum(axis=1).plot(kind="bar")
         pylab.ylabel("Number of reads", fontsize=14)
         pylab.title("Number of mapped reads per sample", fontsize=14)
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
 
     def plot_alignments_per_chromosome(self):
         # on a given sample, let us keep total number of alignments (for
