@@ -12,18 +12,16 @@
 #
 ##############################################################################
 """Utilities to access to online FASTA, taxon, lineage ..."""
-import os
+import ftplib
 import glob
 import math
-import ftplib
-
-from easydev import AttrDict, execute, Progress
-
-from sequana.lazy import pandas as pd
-
-from bioservices import ENA, EUtils
+import os
 
 import colorlog
+from bioservices import ENA, EUtils
+from easydev import AttrDict, Progress, execute
+
+from sequana.lazy import pandas as pd
 
 logger = colorlog.getLogger(__name__)
 
@@ -95,7 +93,6 @@ class ENADownload(object):
         self.ena = ENA(cache=True)
 
     def ena_id_to_gi_number(self, identifiers):
-
         # Now, let us convert the ENA accession to NCBI GI number once for all.
         # We can fetch only at max 200 identifiers:
         logger.info("Fetching %s identifiers from NCBI" % len(identifiers))
