@@ -11,10 +11,10 @@
 #
 ##############################################################################
 """Retrieve data from sequana library"""
-import os
-import easydev
-import glob
 import collections
+import glob
+import inspect
+import os
 
 import colorlog
 
@@ -50,8 +50,13 @@ def sequana_data(filename=None, where=None):
     .. note:: this does not handle wildcards. The * means retrieve all files.
 
     """
-    sequana_path = easydev.get_package_location("sequana")
-    sharedir = os.sep.join([sequana_path, "sequana", "resources"])
+    from pathlib import Path
+
+    import sequana
+
+    sequana_path = Path(inspect.getfile(sequana)).parent
+
+    sharedir = str(Path(sequana_path) / "resources")
     directories = ["data", "testing", "examples", "images", "scripts", "doc"]
 
     if filename == "*":
@@ -72,7 +77,7 @@ def sequana_data(filename=None, where=None):
 
     if filename is None:
         for thisdir in directories:
-            print("From %s directory:" % thisdir)
+            print(f"From %s directory:" % thisdir)
             for filename in glob.glob(sharedir + "/%s/*" % thisdir):
                 filename = os.path.split(filename)[1]
                 to_ignore = ["__init__.py", "__pycache__"]
@@ -93,7 +98,7 @@ def sequana_data(filename=None, where=None):
 
         def _get_valid_file(filename, directory):
             filename = os.sep.join([sharedir, directory, filename])
-            if os.path.exists(filename) is False: #pragma: no cover
+            if os.path.exists(filename) is False:  # pragma: no cover
                 return False
             else:
                 return filename
