@@ -11,11 +11,12 @@
 #
 ##############################################################################
 import json
-from sequana.lazy import pylab
-from sequana.lazy import pandas as pd
 
 import colorlog
 
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
+
 logger = colorlog.getLogger(__name__)
 
 
@@ -44,7 +45,6 @@ class StatsFile(object):
                     pass
 
     def get_data_reads(self):
-
         lanes = []
         names = []
         reads = []
@@ -150,7 +150,15 @@ class StatsFile(object):
 
         all_data.plot(kind="barh", alpha=alpha, zorder=1, width=width, ec="k")
 
-        under.plot(kind="barh", alpha=alpha, color="red", ax=pylab.gca(), zorder=1, width=width, ec="k")
+        under.plot(
+            kind="barh",
+            alpha=alpha,
+            color="red",
+            ax=pylab.gca(),
+            zorder=1,
+            width=width,
+            ec="k",
+        )
         self.all_data = all_data
         self.under = under
         if len(all_data) < 100:
@@ -164,14 +172,13 @@ class StatsFile(object):
         else:
             pylab.xlabel("Number of reads")
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
         if filename:
             pylab.savefig(filename, dpi=200)
 
     def barplot_summary(self, filename=None, color=["green", "red"], alpha=0.8):
-
         df = self.get_data_reads()
         under = df.query("name=='Undetermined'")
 
@@ -219,7 +226,10 @@ class StatsFile(object):
         pylab.xlabel("Number of reads", fontsize=12)
         pylab.ylabel("")
         pylab.grid(True)
-        pylab.legend(["Lane {}".format(x) for x in range(1, len(df.columns) + 1)], loc="lower right")
+        pylab.legend(
+            ["Lane {}".format(x) for x in range(1, len(df.columns) + 1)],
+            loc="lower right",
+        )
 
         # here we plot a vertical line corresponding to the median of reads
         # found in determined indices
@@ -231,7 +241,7 @@ class StatsFile(object):
             pass
 
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except Exception as err:
             print(err)
         return data
