@@ -14,19 +14,24 @@
 import glob
 import json
 import os
+import shutil
+import time
+import urllib
+from os.path import expanduser
 from pathlib import Path
 
 import colorlog
 import colormap
+import plotly.express as px
 import requests
 from bioservices import KEGG
-from matplotlib_venn import venn2_unweighted, venn3_unweighted
+from tqdm import tqdm
+
 from sequana.enrichment.gsea import GSEA
 from sequana.lazy import numpy as np
 from sequana.lazy import pandas as pd
 from sequana.lazy import pylab
 from sequana.summary import Summary
-from tqdm import tqdm
 
 logger = colorlog.getLogger(__name__)
 
@@ -45,7 +50,7 @@ class KEGGPathwayEnrichment:
     This class takes as input a dictionary with 3 lists of genes: 'up',
     'down' and 'all'.
 
-    For example, using the output of the RNA-seq DGE, use:
+    For example, using the output of the RNA-seq DGE, use::
 
         from sequana import RNADiffResults
         r = RNADiffResults("rnadiff.csv")
@@ -90,25 +95,25 @@ class KEGGPathwayEnrichment:
                 axis=1)
         df = df.set_index("ensembl", inplace=True)
 
-        KEGGPathwayEnrichment("path_to_rnadiff", "mmu", mapper=df)
+        ke = KEGGPathwayEnrichment("path_to_rnadiff", "mmu", mapper=df)
 
-    More generally, when starting KEGGPathwayEnrichment, we read all pathways.
-
-    This may change with time. So, you can save the pathways::
-
-        ke.export_pathways_to_json()
-
-    And read them back::
-
-        ke = KEGGPathwayEnrichment("path_to_rnadiff", "mmu", mapper=df,
-            preload_directory="kegg_pathways/mmu")
-
-        df = ke.scatterplot('down')
-        tight_layout()
+        ke.scatterplot('down')
         savefig("B4052_T1vsT0_KE_scatterplot_down.png")
-        df = ke.scatterplot('up')
+        ke.scatterplot('up')
         savefig("B4052_T1vsT0_KE_scatterplot_up.png")
 
+    Pathways are loaded from KEGG which may take some time. For development or production, you may want
+    to save the KEGG pathways in a given place. Note however, that the pathways that are enriched will
+    still be downloaded for the final annotation and image creation
+
+    To save the pathways locally and load them later do as follows (here for human)::
+
+        ke = KEGGPathwayEnrichment({}, organism="hsa")
+        ke.save_pathways("all_pathways/")
+
+        # load them back next time
+        ke = KEGGPathwayEnrichment({}, organism="hsa", preload_directory="all_pathways")
+
     """
 
     def __init__(
@@ -118,9 +123,11 @@ class KEGGPathwayEnrichment:
         progress=True,
         mapper=None,
         background=None,
+        padj_cutoff=0.05,
         preload_directory=None,
         convert_input_gene_to_upper_case=False,
-        color_node_with_annotation='Name'
+        color_node_with_annotation="Name",
+        used_genes=None,
     ):
         """
 
@@ -138,26 +145,70 @@ class KEGGPathwayEnrichment:
         self.kegg = KEGG(cache=True)
         self.kegg.organism = organism
         self.summary = Summary("KEGGPathwayEnrichment")
+        self.gene_lists = gene_lists
+
+        # What is the intersection between the gene names found in KEGG and
+        # the used names used within the RNAdiff analysis (and therefore the
+        # gene names to be found in gene_lists)
+        # First, we get the list of KEGG names and print number of genes
+        kegg_gene_names = self.kegg.list(self.kegg.organism).strip()
+        N_kegg_genes = len(kegg_gene_names.split("\n"))
+        logger.info(f"Number of KEGG genes for {organism}: {N_kegg_genes}")
+        # then, we extract the fourth columns that contains gene names and synonyms
+        kegg_gene_names = [x.split("\t")[3] for x in kegg_gene_names.split("\n") if len(x.split("\t")) == 4]
+        kegg_gene_names = [y.strip() for x in kegg_gene_names for y in x.split(";")]
+        kegg_gene_names = [y.strip() for x in kegg_gene_names for y in x.split(",")]
+
+        def _get_intersection_kegg_genes(genes):
+            if len(genes) == 0:
+                return "NA"
+            else:
+                return len(set(kegg_gene_names).intersection(set(genes))) / len(genes) * 100
+
+        dge_genes = set([x for k, v in gene_lists.items() for x in v])
+
+        mapped = [
+            _get_intersection_kegg_genes(gene_lists["down"]),
+            _get_intersection_kegg_genes(gene_lists["up"]),
+            _get_intersection_kegg_genes(gene_lists["all"]),
+        ]
+
+        lengths = [len(gene_lists["down"]), len(gene_lists["up"]), len(gene_lists["all"])]
+        category = ["down", "up", "all"]
+
+        if used_genes is not None:
+            lengths.append(len(used_genes))
+            category.append("all genes")
+            intersection = _get_intersection_kegg_genes(used_genes)
+            logger.info(f"Percentage of genes used in RNAdiff and found in KEGG: {intersection}")
+            mapped.append(intersection)
+            # if no background provided, let us use the number of found genes
+            if background is None:
+                background = len(used_genes)
+
+        self.overlap_stats = pd.DataFrame({"category": category, "mapped_percentage": mapped, "N": lengths})
+
+        # Define the background
+        if background:
+            self.background = background
+            logger.info(f"User-defined background: {self.background}")
+        else:
+            self.background = N_kegg_genes
+            logger.info(f"Background defined as number of KEGG genes: {self.background} ")
+
         self.summary.add_params(
             {
                 "organism": organism,
                 "mapper": (True if mapper is not None else False),
-                "background": background,
+                "background": self.background,
             }
         )
 
-        self.gene_lists = gene_lists
-
-        if background:
-            self.background = background
-        else:
-            self.background = len(self.kegg.list(self.kegg.organism).split("\n"))
-        logger.info("Set number of genes to {}".format(self.background))
+        self.padj_cutoff = padj_cutoff
 
         self._load_pathways(progress=progress, preload_directory=preload_directory)
 
         if isinstance(mapper, str):
-
             df = pd.read_csv(mapper)
             df = df.rename({"external_gene_name": "name", "ensembl_gene_id": "ensembl"}, axis=1)
             df.set_index("ensembl", inplace=True)
@@ -176,19 +227,26 @@ class KEGGPathwayEnrichment:
         if cat not in self.gene_lists.keys():
             raise ValueError(f"category must be set to one of {self.gene_lists.keys()}. You provided {cat}")
 
+    def save_pathways(self, out_directory):
+        outdir = Path(out_directory)
+        outdir.mkdir(exist_ok=True)
+        with open(outdir / f"{self.kegg.organism}.json", "w") as fout:
+            json.dump(self.pathways, fout)
+
     def _load_pathways(self, progress=True, preload_directory=None):
         # This is just loading all pathways once for all
         self.pathways = {}
+
         if preload_directory:
             # preload is a directory with all pathways in it
-
-            pathways = glob.glob(preload_directory + "/*json")
-            logger.info(f"Loading {len(pathways)} pathways from local files in {preload_directory}.")
-            for name in tqdm(pathways):
-                key = name.strip(".json").split("/")[-1]
-                with open(name, "r") as fin:
-                    data = json.load(fin)
-                    self.pathways[key] = data
+            indir = Path(preload_directory)
+            logger.info(
+                f"Loading pathways from local files in {preload_directory}. Expecting a file named {self.kegg.organism}.json"
+            )
+            with open(indir / f"{self.kegg.organism}.json", "r") as fin:
+                data = json.load(fin)
+                self.pathways = data
+            logger.info(f"Loaded {len(self.pathways)} pathways.")
         else:  # pragma: no cover  #not tested due to slow call
             for ID in tqdm(self.kegg.pathwayIds, desc="Downloading KEGG pathways"):
                 self.pathways[ID.replace("path:", "")] = self.kegg.parse(self.kegg.get(ID))
@@ -234,7 +292,7 @@ class KEGGPathwayEnrichment:
         pylab.hist([len(v) for k, v in self.gene_sets.items()], bins=bins, lw=1, ec="k")
         pylab.title("{} gene sets".format(N))
         pylab.xlabel("Gene set sizes")
-        pylab.grid(True)
+        pylab.grid(True, alpha=0.5)
         a, b = pylab.xlim()
         pylab.xlim([0, b])
 
@@ -247,12 +305,11 @@ class KEGGPathwayEnrichment:
         self.enrichment = {
             category: self._enrichr(category, background=background) for category in self.gene_lists.keys()
         }
+        self.dfs = {
+            category: self._get_final_df(self.enrichment[category].results) for category in self.gene_lists.keys()
+        }
 
-    def _enrichr(self, category, background=None, verbose=True):
-
-        if background is None:
-            background = self.background
-
+    def _enrichr(self, category, background, verbose=True):
         if isinstance(category, list):
             gene_list = category
         else:
@@ -284,118 +341,100 @@ class KEGGPathwayEnrichment:
 
         return enr
 
-    def _get_final_df(self, df, cutoff=0.05, nmax=10):
+    def _get_final_df(self, df):
         # takes the df and populate the name and size of the found pathways
         # we also sort by adjusted p-value
-        # we keep adj p-value <=0.05
         if len(df) == 0:
             return df
 
         df = df.copy()
         df["name"] = [self.pathways[x]["NAME"] for x in df.Term]
         df = df.sort_values("Adjusted P-value")
-        df.reset_index(drop=True, inplace=True)
-        df = df[df["Adjusted P-value"] <= cutoff]
 
-        if len(df) < nmax:
-            nmax = len(df)
-        df = df.iloc[0:nmax]
-        df = df.sort_values("Adjusted P-value", ascending=False)
+        df["Adjusted P-value (-log10)"] = -np.log10(df["Adjusted P-value"])
+        df.reset_index(drop=True, inplace=True)
+
+        df = df.sort_values("Adjusted P-value")
         df = df.rename({"Term": "pathway_id"}, axis=1)
         df = df[df.columns]
+
+        df["significative"] = df["Adjusted P-value"] < self.padj_cutoff
         return df
 
-    def barplot(self, category, cutoff=0.05, nmax=10):
+    def barplot(self, category, nmax=15):
         self._check_category(category)
-        df = self._get_final_df(self.enrichment[category].results, cutoff=cutoff, nmax=nmax)
-        if len(df) == 0:
-            return df
+        df = self.dfs[category].query("significative == True").head(nmax)
+        df = df.sort_values("Adjusted P-value (-log10)")
 
-        pylab.clf()
-        pylab.barh(range(len(df)), -pylab.log10(df["Adjusted P-value"]))
+        fig = px.bar(df, x="Adjusted P-value (-log10)", y="name", orientation="h")
 
-        names = [x[0:40] + "..." if len(x) > 40 else x for x in df.name]
-        pylab.yticks(range(len(df)), names)
-        pylab.axvline(1.3, lw=2, ls="--", color="r")
-        pylab.grid(True)
-        pylab.xlabel("Adjusted p-value (log10)")
-        pylab.ylabel("Gene sets")
-        a, b = pylab.xlim()
-        pylab.xlim([0, b])
-        pylab.tight_layout()
-        return df
+        # To have all labels displayed
+        if len(df) > 20:
+            fig.update_layout(height=800)
 
-    def scatterplot(self, category, cutoff=0.05, nmax=15, gene_set_size=[]):
+        return fig
+
+    def barplot_up_and_down(self, nmax=15):
+        import plotly.graph_objects as go
+
+        dfup = self.dfs["up"].query("significative == True").head(nmax)
+        dfdown = self.dfs["down"].query("significative == True").head(nmax)
+        names = sorted(list(set(list(dfdown["name"].values) + list(dfup["name"].values))))
+        names = names[::-1]
+
+        U = [dfup.query("name == @name")["size"].values[0] if name in dfup["name"].values else 0 for name in names]
+        D = [-dfdown.query("name == @name")["size"].values[0] if name in dfdown["name"].values else 0 for name in names]
+
+        fig = go.Figure()
+        fig.add_trace(go.Bar(y=names, x=U, marker_color="blue", orientation="h", name="Up"))
+        fig.add_trace(go.Bar(y=names, x=D, base=0, orientation="h", marker_color="red", name="Down"))
+
+        fig.update_layout(barmode="stack", xaxis_title="Number of Genes")
+
+        return fig
+
+    def scatterplot(self, category, nmax=15):
         self._check_category(category)
-        df = self._get_final_df(self.enrichment[category].results, cutoff=cutoff, nmax=nmax)
-        if len(df) == 0:
-            return df
+        df = self.dfs[category].query("significative == True").head(nmax)
 
-        pylab.clf()
-        pylab.scatter(
-            -pylab.log10(df["Adjusted P-value"]),
-            range(len(df)),
-            s=10 * df["size"],
-            c=-pylab.log10(df["Adjusted P-value"]),
+        df.sort_values("Odds Ratio", inplace=True)
+        df = df.round({"Odds Ratio": 2, "Combined Score": 2})
+        fig = px.scatter(
+            df,
+            x="Odds Ratio",
+            y="name",
+            color="Combined Score",
+            size="size",
+            hover_data=["Combined Score", "Adjusted P-value", "Overlap"],
+            color_continuous_scale="Viridis",
         )
 
-        pylab.xlabel("Odd ratio")
-        pylab.ylabel("Gene sets")
+        # To have all labels displayed
+        if len(df) > 20:
+            fig.update_layout(height=800)
 
-        names = [x[0:40] + "..." if len(x) > 40 else x for x in df.name]
-
-        pylab.yticks(range(len(df)), names)
-
-        a, b = pylab.xlim()
-        pylab.xlim([0, b * 1.1 + 1])
-
-        a, b = pylab.ylim()
-        pylab.ylim([a - 0.5, b + 0.5])
-
-        pylab.grid(True)
-        ax = pylab.gca()
-
-        M = max(df["size"])
-        if M > 100:
-            l1, l2, l3 = "10", "100", str(M)
-        else:
-            l1, l2, l3 = str(round(M / 3)), str(round(M * 2 / 3)), str(M)
-
-        handles = [
-            pylab.Line2D([0], [0], marker="o", markersize=5, label=l1, ls=""),
-            pylab.Line2D([0], [0], marker="o", markersize=10, label=l2, ls=""),
-            pylab.Line2D([0], [0], marker="o", markersize=15, label=l3, ls=""),
-        ]
-        ax.legend(handles=handles, loc="upper left", title="gene-set size")
-
-        pylab.axvline(1.3, lw=2, ls="--", color="r")
-        ax = pylab.colorbar(pylab.gci())
-        pylab.tight_layout()
-        return df
+        return fig
 
     def _get_summary_pathway(self, pathway_ID, df, l2fc=0, padj=0.05):
-
         genes = self.df_pathways.loc[pathway_ID]["GENE"]
 
         df_down = df.query("padj<=@padj and log2FoldChange<=-@l2fc").copy()
         df_up = df.query("padj<=@padj and log2FoldChange>=@l2fc").copy()
 
-
         # for the color, we need to find the match between names and the annotation
         # since names is suppose to have been populated with the annotaion, it should be
         # found. no need for sanity checks.
         df_down["Name"] = df_down[self.color_node_with_annotation]
         df_up["Name"] = df_up[self.color_node_with_annotation]
 
-
-        # in principle, the KEGG pathays field 'GENE' is stored as 
+        # in principle, the KEGG pathays field 'GENE' is stored as
         # "GENE":{key: value} and the values are the NAME, a semi column, and a description
         # hence the split on ; herebelow:
         # unfortunately, there are special cases to handle such as vibrio cholera (vc)
         mapper = {}
-        if self.kegg.organism.startswith('vc'):
+        if self.kegg.organism.startswith("vc"):  # pragma: no cover
             for k, v in genes.items():
-                #the value is just the description. Let us assume that the name is also the ID
+                # the value is just the description. Let us assume that the name is also the ID
                 mapper[k] = k
         else:
             for k, v in genes.items():
@@ -439,20 +478,24 @@ class KEGGPathwayEnrichment:
                     logger.warning("Skipped {}(kegg ID {}). could not find mapping".format(name, kegg_id))
             mapper = new_mapper
 
+        df_down["Name"] = df_down["Name"].str.lower()
+        df_up["Name"] = df_up["Name"].str.lower()
+
         for name, kegg_id in mapper.items():
+
             summary_names.append(name)
             summary_keggids.append(kegg_id)
 
             if name.lower() in {x.lower() for x in df_down.Name.fillna("undefined")}:
-                padj = -pylab.log10(df_down.query("Name==@name").padj.values[0])
-                fc = df_down.query("Name==@name").log2FoldChange.values[0]
+                padj = -pylab.log10(df_down.query("Name==@name.lower()").padj.values[0])
+                fc = df_down.query("Name==@name.lower()").log2FoldChange.values[0]
                 summary_fcs.append(fc)
                 summary_pvalues.append(padj)
                 summary_types.append("-")
             elif name.lower() in {x.lower() for x in df_up.Name.fillna("undefined")}:
-                padj = -pylab.log10(df_up.query("Name==@name").padj.values[0])
+                padj = -pylab.log10(df_up.query("Name==@name.lower()").padj.values[0])
                 summary_pvalues.append(padj)
-                fc = df_up.query("Name==@name").log2FoldChange.values[0]
+                fc = df_up.query("Name==@name.lower()").log2FoldChange.values[0]
                 summary_fcs.append(fc)
                 summary_types.append("+")
             else:
@@ -489,67 +532,148 @@ class KEGGPathwayEnrichment:
                 l2fc = -4
             elif l2fc >= 4:
                 l2fc = 4
-            # to get a value in the range 0,1 expectd by the colormap
+            # to get a value in the range 0,1 expected by the colormap
             l2fc = (l2fc + 4) / 8
 
             color = colormap.rgb2hex(*cmap(l2fc)[0:3], normalised=True)
 
-            if l2fc < 0.2:
-                colors[kegg_id] = f"{color},grey"
-            else:
-                colors[kegg_id] = f"{color},black"
+            # this is to reduce URL length until a POST solution is found.
+            # all entries with low l2fc below |1| are ignored
+            # 0.625 <=> l2fc = 1
+            # 0.375 <=> l2fc = -1
+            if l2fc >= 0.625 or l2fc <= 0.375:
+                colors[kegg_id] = f"{color}"
+
+            # 0.125 <==> l2fc = -3 here color is very dark, text should be in another color
+            if l2fc < 0.125 or l2fc > 0.875:
+                colors[kegg_id] = f"{color},white"
+            # else:  #FIXME for now, genes not in the annotation/rnadiff are also ignored
+            # to keep URL short
+            #    colors[kegg_id] = f"{color}"
         return colors
 
     def save_pathway(self, pathway_ID, df, scale=None, show=False, filename=None):
-
         summary = self._get_summary_pathway(pathway_ID, df)
         colors = self._get_colors(summary)
 
         count_up = len(summary.query("type == '+'"))
         count_down = len(summary.query("type == '-'"))
-        logger.info(f"pathway {pathway_ID} total genes: {len(summary)}. Found {count_down} down-regulated and {count_up} up-regulated")
+        logger.info(
+            f"pathway {pathway_ID} total genes: {len(summary)}. Found {count_down} down-regulated and {count_up} up-regulated"
+        )
 
         url = "https://www.kegg.jp/kegg-bin/show_pathway"
-        # dcolor = "white"  --> does not work with the post requests unlike get
-        # requests
+
         params = {
             "map": pathway_ID,
-            "multi_query": "\r\n".join(["{} {}".format(k, v) for k, v in colors.items()]),
+            "multi_query": "\r\n".join([f"{k} {v}" for k, v in colors.items()]),
         }
 
-        self.params = params
-
-        html_page = requests.post(url, data=params)
-
-        self.tmp = html_page
-        html_page = html_page.content.decode()
-
-        links_to_png = [x for x in html_page.split() if "png" in x and x.startswith("src")]
-        link_to_png = links_to_png[0].replace("src=", "").replace('"', "")
-        r = requests.get("https://www.kegg.jp/{}".format(link_to_png))
-
         if filename is None:
             filename = f"{pathway_ID}.png"
 
-        with open(filename, "wb") as fout:
-            fout.write(r.content)
+        try:
+            # let us try the selenium solution. If it works, we overwrite the previous image
+            urlsel = url + f"?map={pathway_ID}&multi_query="
+            # print(urlsel)
+            # print("\\r\\n".join([f"{k} {v}" for k, v in colors.items()]))
+            urlsel += urllib.parse.quote("\r\n".join([f"{k} {v}" for k, v in colors.items()]))
+            if len(urlsel) >= 2048:
+                logger.warning(f"EXCESS. consider increasing l2fc: {len(urlsel)}, {len(colors)}")
+            self._download_kegg_image(urlsel, pathway_ID)
+            # in theory one should have an image called PATHWAYID_date_ID.png
+            # we need to renae it
+            filenames = glob.glob(f"{pathway_ID}@2x_*png")
+            if len(filenames) > 1:
+                logger.warning(
+                    f"expected one PNG file. found several KEGG PNG files: {filenames}. please remove them. Moving the first one found"
+                )
+            if len(filenames) == 0:
+                logger.warning("no files were saved using headless call. roll back to requests ")
+            # filename is defined above by the user or as pathway_ID.png
+            shutil.move(filenames[0], filename)
+        except Exception as err:  # pragma: no cover
+            print(err)
+
+            # color do not work anymore since Aug 2023 but this allows us to get the image
+            # in case the new implementation (above) fails
+            self.params = params
+            html_page = requests.post(url, data=params)
+            self.tmp = html_page
+            html_page = html_page.content.decode()
+
+            try:
+                links_to_png = [x for x in html_page.split() if "png" in x and x.startswith("src")]
+                link_to_png = links_to_png[0].replace("src=", "").replace('"', "")
+                r = requests.get(f"https://www.kegg.jp/{link_to_png}")
+                with open(filename, "wb") as fout:
+                    fout.write(r.content)
+            except IndexError:
+                logger.warning(f"could not create image for {pathway_ID}")
 
         return summary
 
-    def save_significant_pathways(
-        self, category, cutoff=0.05, nmax=20, background=None, tag="", outdir="."
-    ):  # pragma: no cover
+    def _download_kegg_image(self, url, pathwayID):
+        from selenium import webdriver
+        from selenium.webdriver.chrome.service import Service as ChromeService
+        from selenium.webdriver.common.action_chains import ActionChains
+        from selenium.webdriver.common.by import By
+        from selenium.webdriver.support import expected_conditions as EC
+        from selenium.webdriver.support.ui import WebDriverWait
+
+        # Define the path to the Chrome WebDriver executable
+        # Drivers can be found here : https://pypi.org/project/selenium/
+        home = expanduser("~")
+        webdriver_path = f"{home}/.config/sequana/chromedriver"
+        if os.path.exists(webdriver_path) is False:
+            logger.critical(
+                "To annotate KEGG image, you currently need chrome and a valid/compatible selenium driver for chroe. Please see https://pypi.org/project/selenium"
+            )
+
+        # Set up the WebDriver with options
+        chrome_options = webdriver.ChromeOptions()
+        chrome_options.binary_location = "/usr/bin/google-chrome"  # Path to your Chrome executable
+        chrome_options.add_argument("--headless")  # Optional: run Chrome in headless mode (no GUI)
+
+        # Create a ChromeService object with the WebDriver path
+        chrome_service = ChromeService(executable_path=webdriver_path)
+
+        logger.info(f"Creating driver to access KEGG website for {pathwayID}")
+        # Create a WebDriver instance
+        driver = webdriver.Chrome(service=chrome_service, options=chrome_options)
+
+        # Navigate to the web page. Wait 10s for the page to be updated with the requests
+        # somehow the WebDriverWait is not enough. Requests larger than 2048 characters will fail
+        # here, FIXME with a javascript of post requests but not easy.
+        driver.get(url)
+        time.sleep(10)
+
+        # Find and click the menu tab 'download-menu'
+        download_menu = WebDriverWait(driver, 10).until(EC.presence_of_element_located((By.ID, "downloadMenu")))
+
+        # Use ActionChains to hover over the "Download" menu item
+        actions = ActionChains(driver)
+        actions.move_to_element(download_menu).perform()
+
+        logger.info("Downloading image\n")
+        image_link = WebDriverWait(driver, 10).until(EC.element_to_be_clickable((By.LINK_TEXT, "Image (png) file 2x")))
+        actions.move_to_element(image_link).click().perform()
+
+        # Wait for the download to complete (you can use a more robust approach to wait for the file to be ready)
+        time.sleep(5)
+
+        # Close the WebDriver
+        driver.quit()
+
+    def save_significant_pathways(self, category, nmax=20, tag="", outdir="."):  # pragma: no cover
         """category should be up, down or all"""
 
-        if background is None:
-            background = self.background
-
         # select the relevant pathways
-        df = self._enrichr(category, background).results
-        df = self._get_final_df(df, cutoff=cutoff, nmax=nmax)
+        df = self.dfs[category].query("significative == True")
         logger.warning("Found {} pathways to save".format(len(df)))
-        if len(df) == nmax:
+        if len(df) > nmax:
             logger.warning("Restricted pathways to {}".format(nmax))
+            df = df.head(nmax)
 
         logger.info("saving {} deregulated pathways".format(len(df)))
 
@@ -591,36 +715,15 @@ class KEGGPathwayEnrichment:
         for category in self.gene_lists.keys():
             common_out = Path(f"{tag}_kegg_gsea_{category}_degs")
 
-            results = self.enrichment[category].results
+            df = self.dfs[category]
 
-            if not results.empty:
+            if not df.empty:
+                df.to_csv(outdir / (common_out.name + ".csv"))
+                df.query("significative == True").to_csv(outdir / (common_out.name + "_significant.csv"))
 
-                # FIXME: For now fixing a nmax to 10000 to be sure to have all results
-                # (this could be improved by having self.complete_df and self.filtered_df attributes)
-                self._get_final_df(results, cutoff=1, nmax=10000).to_csv(outdir / (common_out.name + ".csv"))
-                self._get_final_df(results, cutoff=0.05, nmax=10000).to_csv(
-                    outdir / (common_out.name + "_significant.csv")
-                )
-
-                self.barplot(category)
-                pylab.savefig(outdir / (common_out.name + "_barplot.png"), dpi=200)
-                self.scatterplot(category)
-                pylab.savefig(outdir / (common_out.name + "_scatterplot.png"), dpi=200)
+                self.barplot(category).write_image(outdir / (common_out.name + "_barplot.png"))
+                self.scatterplot(category).write_image(outdir / (common_out.name + "_scatterplot.png"))
 
             # In case of no enrichment results, create empty files stating so
             else:
                 (outdir / (common_out.name + "_NO_RESULTS")).touch()
-
-    def export_pathways_to_json(self, outdir="kegg_pathways"):
-        # This is useful to keep an exact track of the pathways that were used.
-        # They can be loaded back. If so, we use kegg service only in
-        # :meth:`find_pathways_by_gene` method and
-
-        outdir = outdir + "/" + self.kegg.organism
-        os.makedirs(outdir, exist_ok=True)
-
-        for key, data in self.pathways.items():
-            output_json = f"{outdir}/{key}.json"
-            if not os.path.exists(output_json):
-                with open(output_json, "w") as fout:
-                    json.dump(data, fout)
