@@ -12,13 +12,14 @@
 ##############################################################################
 
 import colorlog
+from tqdm import tqdm
+
 from sequana.enrichment.ontology import Ontology
 from sequana.enrichment.plot_go_terms import PlotGOTerms
 from sequana.enrichment.quickgo import QuickGOGraph
 from sequana.lazy import numpy as np
 from sequana.lazy import pandas as pd
 from sequana.lazy import pylab
-from tqdm import tqdm
 
 logger = colorlog.getLogger(__name__)
 
@@ -178,7 +179,6 @@ class PantherEnrichment(Ontology, PlotGOTerms):
         fc_threshold = log2_fc_threshold
 
         for x in sorted(gene_lists.keys()):
-
             N = len(gene_lists[x])
             logger.info(f"Starting with {N} genes from category '{x}'")
 
@@ -248,7 +248,6 @@ class PantherEnrichment(Ontology, PlotGOTerms):
             )
 
     def get_mapping_stats(self):
-
         results = []
         for k in self.enrichment.keys():
             if self.enrichment[k]:
@@ -258,16 +257,18 @@ class PantherEnrichment(Ontology, PlotGOTerms):
                     U = self.enrichment[k][o]["input_list"]["unmapped_count"]
                     results.append([k, o, M, U])
         df = pd.DataFrame(results)
-        df[4] = 100 * df[2] / (df[3] + df[2])
-        df[5] = df[2] + df[3]
-        df.columns = [
-            "category",
-            "ontology",
-            "mapped",
-            "unmapped",
-            "mapped_percentage",
-            "total",
-        ]
+        if not df.empty:
+            df[4] = 100 * df[2] / (df[3] + df[2])
+            df[5] = df[2] + df[3]
+
+            df.columns = [
+                "category",
+                "ontology",
+                "mapped",
+                "unmapped",
+                "mapped_percentage",
+                "total",
+            ]
         return df
 
     def _compute_enrichment(
@@ -278,14 +279,13 @@ class PantherEnrichment(Ontology, PlotGOTerms):
         enrichment_test="FISHER",
         correction="FDR",
     ):
-
         # taxid=83333 # ecoli
         if taxid is None:
             taxid = self.taxon
 
         # nice bug from panterdb website. if 'php' is a gene name, no process is done
-        if 'php' in mygenes:
-            mygenes.remove('php')
+        if "php" in mygenes:
+            mygenes.remove("php")
 
         if isinstance(mygenes, list):
             mygenes = ",".join(mygenes)
@@ -348,8 +348,6 @@ class PantherEnrichment(Ontology, PlotGOTerms):
             # extract the ID and label of the go term and save
             # as primary keys
 
-
-
             for i, k in enumerate(results["result"]):
                 if results["result"][i]["term"]["label"] == "UNCLASSIFIED":
                     unclassified[ontology] += 1
@@ -419,7 +417,7 @@ class PantherEnrichment(Ontology, PlotGOTerms):
         df["pct_diff_expr"] = df["number_in_list"] * 100 / df["number_in_reference"]
 
         # could happen that all fold enrichment are set to 'NaN'
-        df = df[df['fold_enrichment'] != 'NaN']
+        df = df[df["fold_enrichment"] != "NaN"]
         df["log2_fold_enrichment"] = pylab.log2(df["fold_enrichment"])
         df["abs_log2_fold_enrichment"] = abs(pylab.log2(df["fold_enrichment"]))
         df["expected"] = [int(x) for x in df.expected]
@@ -477,7 +475,7 @@ class PantherEnrichment(Ontology, PlotGOTerms):
             else:
                 labels.append(this[0:50] + "...")
         pylab.pie(df.query("number_in_list!=0").number_in_list, labels=labels)
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
 
     def save_chart(self, df, filename="chart.png"):
         """
