@@ -15,6 +15,7 @@ from collections import Counter, defaultdict
 
 import colorlog
 from bioservices import UniProt
+
 from sequana.enrichment.gsea import GSEA
 from sequana.enrichment.ontology import Ontology
 from sequana.enrichment.plot_go_terms import PlotGOTerms
@@ -77,7 +78,7 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
         df = e.plot_go_terms(['MF', 'CC', 'BP'],
                 log=False, include_negative_enrichment=False,
                 fontsize=8, sort_by='fold_enrichment',
-                show_pvalues=True, fdr_threshold=0.05)
+                fdr_threshold=0.05)
 
     """
 
@@ -113,10 +114,6 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
         self._taxon = None
         self.taxon = taxon
 
-        # panther accepts onyl ~2-3000 genes at max. Let us restrict the analysis
-        # to the first 2000 genes based on their log2 fold change 2000 + and
-        # 2000 negatives
-
         msg = "Ignoring DEGs with adjusted p-value > {} and fold change in [{}, {}]".format(
             padj_threshold, 1 / (2**log2_fc_threshold), 2**log2_fc_threshold
         )
@@ -171,7 +168,7 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
         for i, x in enumerate(conv["Gene Names"]):
             names = x.split()
 
-            # Some gene names are very species-dependent. 
+            # Some gene names are very species-dependent.
             # A gene name may also be composed of several valid names
 
             # for cryptococcus, we keep first name starting with CNAG , otherwise we keep the first word only.
@@ -205,7 +202,6 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
         uniprot = UniProt(cache=True, verbose=True)
         df = uniprot.search(f"organism_name:{self.taxon}", frmt="tsv", columns=columns)
 
-
         try:
             df = pd.read_csv(io.StringIO(df), sep="\t")
         except TypeError:
@@ -269,7 +265,6 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
         ontologies=None,
         background=None,
     ):
-
         if background is None:
             background = len(self.df_genes)
 
@@ -284,12 +279,16 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
         stats = {}
 
         for ontology in ontologies:
-
             gs = GSEA(self.gene_sets[ontology])
+
             enr = gs.compute_enrichment(mygenes, verbose=False, background=background)
-            result = enr.results[enr.results["Adjusted P-value"] < 0.05].copy()
-            description = self._get_go_description(result["Term"].values)
-            result["description"] = description
+            if len(enr.results):
+                result = enr.results[enr.results["Adjusted P-value"] < 0.05].copy()
+                description = self._get_go_description(result["Term"].values)
+                result["description"] = description
+            else:
+                result = enr.results
+                result["description"] = []
 
             enrichment[ontology] = {"result": result}
 
@@ -306,7 +305,7 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
             else:
                 labels.append(this[0:50] + "...")
         pylab.pie(df.query("number_in_list!=0").number_in_list, labels=labels)
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
 
     def save_chart(self, df, filename="chart.png"):
         self.quick_go_graph.save_chart(df, filename)
@@ -357,13 +356,15 @@ class UniprotEnrichment(Ontology, PlotGOTerms):
         df["total_genes"] = len(self.df_genes)
 
         logger.warning("fold enrichment currently set to log10(adjusted pvalue)")
-        df["fold_enrichment"] = -pylab.log10(df["pValue"])
-
-        df["log2_fold_enrichment"] = pylab.log2(df["fold_enrichment"])
-        df["abs_log2_fold_enrichment"] = abs(pylab.log2(df["fold_enrichment"]))
+        try:
+            df["fold_enrichment"] = -pylab.log10(df["pValue"])
+            df["log2_fold_enrichment"] = pylab.log2(df["fold_enrichment"])
+            df["abs_log2_fold_enrichment"] = abs(pylab.log2(df["fold_enrichment"]))
+            df = df.query("fdr<=@fdr").copy()
+        except KeyError:
+            pass
 
         # filter out FDR>0.05
-        df = df.query("fdr<=@fdr").copy()
         logger.info("Found {} GO terms after keeping only FDR<{}".format(len(df), fdr))
 
         return df
