@@ -1,8 +1,9 @@
 """This is a MultiQC plugin re-used temporarely here"""
-import zipfile
 import re
-from sequana.lazy import pylab
+import zipfile
+
 from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
 
 
 class FastQC:
@@ -14,7 +15,6 @@ class FastQC:
     """
 
     def __init__(self):
-
         self.fastqc_data = {}
 
     def read_sample(self, filename, s_name):
@@ -27,7 +27,6 @@ class FastQC:
         temporary hack to read the sample data.
         """
         try:
-
             zz = zipfile.ZipFile(filename)
             file_contents = zz.open("{}{}".format(zz.namelist()[0], "fastqc_data.txt")).read().decode("utf8")
         except:
@@ -40,12 +39,10 @@ class FastQC:
         s_headers = None
         self.dup_keys = []
         for l in file_contents.splitlines():
-
-
-            # Hack to fix falco bug found in some versions where this 
+            # Hack to fix falco bug found in some versions where this
             # line is missing the # character in front of it
-            if l.startswith('Length\tCount'):
-                l = '#' + l
+            if l.startswith("Length\tCount"):
+                l = "#" + l
 
             if l == ">>END_MODULE":
                 section = None
@@ -60,7 +57,10 @@ class FastQC:
                     # Special case: Total Deduplicated Percentage header line
                     if s_headers[0] == "Total Deduplicated Percentage":
                         self.fastqc_data[s_name]["basic_statistics"].append(
-                            {"measure": "total_deduplicated_percentage", "value": float(s_headers[1])}
+                            {
+                                "measure": "total_deduplicated_percentage",
+                                "value": float(s_headers[1]),
+                            }
                         )
                     else:
                         if s_headers[1] == "Relative count":
@@ -70,7 +70,7 @@ class FastQC:
                 elif s_headers is not None:
                     s = l.split("\t")
                     row = dict()
-                    for (i, v) in enumerate(s):
+                    for i, v in enumerate(s):
                         v.replace("NaN", "0")
                         try:
                             v = float(v)
@@ -130,7 +130,6 @@ class FastQC:
         return int(bp)
 
     def plot_sequence_quality(self, max_score=40, ax=None):
-
         ymax = max_score + 1
         xmax = 0
         for sample in self.fastqc_data.keys():
