@@ -11,17 +11,17 @@
 #
 ##############################################################################
 """feature counts related tools"""
+import glob
 import os
 import re
-import glob
 import sys
 from pathlib import Path
 
+import colorlog
+
 from sequana.lazy import pandas as pd
 from sequana.lazy import pylab
 
-import colorlog
-
 logger = colorlog.getLogger(__name__)
 
 
@@ -256,7 +256,6 @@ class MultiFeatureCount:
         self.probable_strand, self.df = get_most_probable_strand_consensus(self.rnaseq_folder, self.tolerance)
 
     def plot_strandness(self, fontsize=12, output_filename="strand_summary.png", savefig=False):
-
         df = self.df.sort_index(ascending=False)
         df["strandness"] = df["strandness"].T
         df["strandness"].plot(kind="barh")
@@ -267,7 +266,7 @@ class MultiFeatureCount:
         pylab.axvline(0.5, ls="--", color="k")
         pylab.xlabel("Strandness", fontsize=fontsize)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except Exception:
             pass
         if savefig:  # pragma: no cover
@@ -277,7 +276,9 @@ class MultiFeatureCount:
 class FeatureCountMerger:
     """Merge several feature counts files"""
 
-    def __init__(self, pattern="*feature.out", fof=[]):
+    def __init__(self, pattern="*feature.out", fof=[], skiprows=1):
+
+        self.skiprows = skiprows
         if len(fof):
             self.filenames = fof
         else:
@@ -291,9 +292,9 @@ class FeatureCountMerger:
                 logger.critical(f"file x not found")
                 sys.exit(1)
 
-        self.df = pd.read_csv(self.filenames[0], sep="\t", skiprows=1)
+        self.df = pd.read_csv(self.filenames[0], sep="\t", skiprows=self.skiprows)
         for filename in self.filenames[1:]:
-            other_df = pd.read_csv(filename, sep="\t", skiprows=1)
+            other_df = pd.read_csv(filename, sep="\t", skiprows=self.skiprows)
             self.df = pd.merge(self.df, other_df)
 
     def to_tsv(self, output_filename="all_features.out"):
