@@ -11,12 +11,12 @@
 #
 ##############################################################################
 
-from sequana import BAM, FastQ
-from sequana.lazy import pylab
-from sequana.lazy import pandas as pd
-
 import colorlog
 
+from sequana import BAM, FastQ
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
+
 logger = colorlog.getLogger(__name__)
 
 
@@ -72,7 +72,6 @@ class FindMotif:
         self.window = window
 
     def find_motif_from_sequence(self, seq, motif, window=None, local_threshold=None):
-
         if local_threshold is None:
             local_threshold = self.local_threshold
 
@@ -92,9 +91,7 @@ class FindMotif:
 
         data = FastA(filename)
         N = len(data)
-        from easydev import Progress
 
-        pb = Progress(N)
         df = {"query_name": [], "hit": [], "length": [], "start": [], "end": []}
         for i, item in enumerate(data):
             X1, S = self.find_motif_from_sequence(item.sequence, motif, window=window, local_threshold=local_threshold)
@@ -104,12 +101,18 @@ class FindMotif:
                 df["end"].append(len(item.sequence))
                 df["length"].append(len(item.sequence))
                 df["hit"].append(S)
-            pb.animate(i + 1)
         df = pd.DataFrame(df)
         return df
 
     def find_motif_bam(
-        self, filename, motif, window=200, figure=False, savefig=False, local_threshold=None, global_threshold=None
+        self,
+        filename,
+        motif,
+        window=200,
+        figure=False,
+        savefig=False,
+        local_threshold=None,
+        global_threshold=None,
     ):
         from sequana import BAM
 
@@ -133,7 +136,10 @@ class FindMotif:
                 off = a.query_alignment_start
                 # pylab.clf()
                 if figure:
-                    pylab.plot(range(off + a.reference_start, off + a.reference_start + len(seq)), X1)
+                    pylab.plot(
+                        range(off + a.reference_start, off + a.reference_start + len(seq)),
+                        X1,
+                    )
                     if savefig:
                         pylab.savefig("{}_{}_{}.png".format(a.reference_name, S, a.query_name.replace("/", "_")))
 
@@ -153,7 +159,6 @@ class FindMotif:
         windows=[10, 50, 100, 150, 200, 250, 500, 1000],
         local_threshold=5,
     ):
-
         found = None
         bam = BAM(bamfile)
         for aln in bam:
@@ -228,7 +233,11 @@ class FindMotif:
             if seq:
                 count += 1
                 X1 = [seq[i : i + window].count(motif) for i in range(len(seq))]
-                pylab.plot(range(aln.reference_start, aln.reference_start + len(seq)), X1, label=aln.query_name)
+                pylab.plot(
+                    range(aln.reference_start, aln.reference_start + len(seq)),
+                    X1,
+                    label=aln.query_name,
+                )
         print("Showing {} entries after filtering".format(count))
         max_theo = int(1.2 * window / len(motif))
         pylab.ylim([0, max_theo])
