@@ -11,19 +11,24 @@
 #
 ##############################################################################
 import re
-from sequana.fasta import FastA
 
 import colorlog
 
+from sequana.fasta import FastA
+
 logger = colorlog.getLogger(__name__)
 
 
 __all__ = ["GenBank"]
 
 
-# TODO: we should factorise gff and genbank in a parent class (Annotation)
 class GenBank:
-    """
+    """This class reads a Genbank file
+
+    This is kept for back compatibility but most code in Sequana
+    will rely on :class:`sequana.gff3.GFF3` instead. So please, transform
+    your genbank to GFF3 format if possible.
+
     ::
 
         gg = GenBank()
@@ -31,11 +36,30 @@ class GenBank:
 
     """
 
-    def __init__(self, filename):
+    def __init__(self, filename, skip_types=["biological_region"]):
         self.filename = filename
+        self._df = None
+        self._features = None
+        self.skip_types = skip_types
 
-    def get_types(self):
+    # property from parent class
+    def _get_features(self):
+        if self._features:
+            features = self._features
+        else:
+            records = self.genbank_features_parser()
+            _types = set()
+            for contig in records.keys():
+                for feature in records[contig]:
+                    _type = feature["type"]
+                    _types.add(_type)
+            self._features = sorted(_types)
+        return self._features
 
+    features = property(_get_features)
+
+    def get_types(self):  # pragma no cover
+        logger.warning("genbank.GenBank.get_types is deprecrated. Please use features property")
         records = self.genbank_features_parser()
         _types = set()
         for contig in records.keys():
@@ -45,9 +69,8 @@ class GenBank:
         return sorted(_types)
 
     def extract_fasta(self, fastafile, features=["rRNA"]):
-        types = self.get_types()
         for feature in features:
-            if feature not in types:
+            if feature not in self.features:
                 raise ValueError("{} not found".format(feature))
 
         # fasta may have several contig/chromosome names
@@ -129,7 +152,12 @@ class GenBank:
                         start = pos[0]
                         end = pos[-1]
                         strand = "-" if split_line[1].startswith("c") else "+"
-                        new_feature = {"type": t, "gene_start": start, "gene_end": end, "strand": strand}
+                        new_feature = {
+                            "type": t,
+                            "gene_start": start,
+                            "gene_end": end,
+                            "strand": strand,
+                        }
 
                     # recover qualifier bound with feature
                     else:
