@@ -11,15 +11,16 @@
 #
 ##############################################################################
 import os
+from collections import defaultdict
 
 import colorlog
-import pysam
 
 from sequana.errors import BadFileFormat
 
 logger = colorlog.getLogger(__name__)
 
 from sequana.lazy import pandas as pd
+from sequana.lazy import pysam
 
 __all__ = ["GFF3"]
 
@@ -50,11 +51,10 @@ class GFF3:
 
     def __init__(self, filename, skip_types=["biological_region"]):
         self.filename = filename
-        assert os.path.exists(filename)
-        self._df = None
-        self._features = set()
-        self._attributes = set()
         self.skip_types = skip_types
+        self._df = None
+        self._features = None
+        self._attributes = None
 
     def _get_features(self):
         """Extract unique GFF feature types
@@ -89,13 +89,19 @@ class GFF3:
 
     features = property(_get_features)
 
-    def get_attributes(self, feature=None, sep=";"):
+    def get_attributes(self, feature=None, sep="; "):
         """Return list of possible attributes
 
         If feature is provided, must be valid and used as a filter
         to keep only entries for that feature.
 
         ~10 seconds on mouse genome GFF file.
+
+        sep must be "; " with extra space to cope with special cases
+        where an attribute has several entries separated by ; e.g.:
+
+            BP="GO:0006412"; MF="GO:0005524;GO:0004004;"
+
         """
         # This is used by the rnaseq pipeline and should be kept fast
         if self._attributes:
@@ -104,9 +110,11 @@ class GFF3:
         attributes = set()
         with open(self.filename, "r") as reader:
             for line in reader:
-
+                # stop once FASTA starts
+                if line.startswith("##FASTA"):
+                    break
                 # Skip metadata and comments and empty lines
-                if line.startswith("#") or not line.strip():
+                if line.startswith("#") or not line.strip():  # pragma: no cover
                     continue
 
                 split = line.rstrip().split("\t")
@@ -139,6 +147,10 @@ class GFF3:
         with open(self.filename, "r") as reader:
             line = None
             for line in reader:
+                # stop once FASTA starts
+                if line.startswith("##FASTA"):
+                    break
+
                 # Skip metadata and comments
                 if line.startswith("#"):
                     continue
@@ -184,13 +196,11 @@ class GFF3:
     df = property(_get_df)
 
     def get_duplicated_attributes_per_genetic_type(self):
-
         results = {}
         for typ in self.features:
             results[typ] = {}
             print("{}: {} entries".format(typ, len(self.df.query("genetic_type==@typ"))))
             for attr in sorted(self.attributes):
-
                 L = len(self.df.query("genetic_type==@typ")[attr].dropna())
                 dups = self.df.query("genetic_type==@typ")[attr].dropna().duplicated().sum()
                 if dups > 0:
@@ -198,7 +208,6 @@ class GFF3:
                 else:
                     print(f"  - {attr}:No duplicates ({L} in total)")
                 results[typ][attr] = dups
-        import pandas as pd
 
         df = pd.DataFrame(results)
         return df
@@ -219,7 +228,6 @@ class GFF3:
         transcripts_df = transcripts_df.reset_index()
 
         results = {}
-        from collections import defaultdict
 
         results2 = defaultdict(list)
         for _id, data in transcripts_df[["ID", "Parent"]].iterrows():
@@ -232,10 +240,12 @@ class GFF3:
         self.df.to_csv(filename, index=False)
 
     def read_and_save_selected_features(self, outfile, features=["gene"]):
-
         count = 0
         with open(self.filename, "r") as fin, open(outfile, "w") as fout:
             for line in fin:
+                # stop once FASTA starts
+                if line.startswith("##FASTA"):
+                    break
                 split = line.rstrip().split("\t")
                 # skipping  biological_region saves lots of time
                 try:
@@ -253,7 +263,6 @@ class GFF3:
                 replace_seqid='locus_tag')
         """
         with open(filename, "w") as fout:
-
             fout.write("#gff-version 3\n#Custom gff from sequana\n")
             count = 0
             from collections import defaultdict
@@ -329,6 +338,7 @@ class GFF3:
             if x in ["=", " "]:
                 sep = x
                 break
+
         if sep is None:
             logger.error(f"Your GFF/GTF does not seem to be correct ({text}). Expected a = or space as separator")
             sys.exit(1)
@@ -341,7 +351,13 @@ class GFF3:
 
         # split into mutliple attributes
         # GTF ends in ; so we need to strip it
-        split = text.rstrip(";").split(";")
+        split = text.rstrip(";")
+
+        # some GFF uses ; and a space as separator but usually, it is just ; with no surrounding spaces.
+        if "; " in split:
+            split = text.split("; ")
+        else:
+            split = text.split(";")
 
         for attr in split:
             # make sure there is no trailing spaces
@@ -355,88 +371,6 @@ class GFF3:
             attributes[attr[:idx]] = value.replace('"', "").replace("%3B", ";").replace("%20", " ")
         return attributes
 
-    def create_files_for_rnadiff(
-        self,
-        outname,
-        genetic_type="gene",
-        ID="Name",
-        fields=["Name"],
-        merge_identical_id=True,
-    ):
-        """Creates two files required for the RNADiff analysis following
-        sequana_rnaseq pipeline
-
-        :param str outname: the output filename prefix
-        :param genetic_type: genetic type to be selected from the GFF file e.g.
-            gene (default), CDS, etc
-        :param ID: the identifier (key) to be selected from the list of
-            attributes found in the GFF for the given type. By default, 'Name'.
-            Used as first column in the two ouptut file.
-        :param fields: the fields to be save in the outname_info.tsv file
-        :param merge_identical_id: it may happen that the same gene **Name** has two
-            entries (e.g in e-coli with 2 unique IDs have the same name with an
-            annotation such as  partI and part II). If so, feature
-            counts is clever enough to deal with it. Here, we need to merge the
-            entries and sum the length together. Ideally, one should not use the
-            Name but ID or gene_id or locus_tag.
-        :return: nothing
-
-        This functions reads the GFF file and creates two files:
-
-        #. outname_gene_lengths.tsv contains column 1 with identifiers and
-           column 2 with length of the selected type (e.g. gene)
-        #. outname_info.tsv first column is the same identifier as in the first
-           file and following columns contain the fields of interest (Name by
-           default but could be any attributes to be found in the GFF such as
-           description
-
-        """
-        tokeep = []
-        for entry in self.read():
-            if genetic_type == entry["genetic_type"]:
-                tokeep.append(entry)
-
-        if len(tokeep) == 0:
-            raise ValueError("No genetic type {} was found".format(genetic_type))
-
-        df = pd.DataFrame(tokeep)
-
-        # FIXME surely this is now redundant since we have a loop above that
-        # performs the filtering already.
-        df = df.query("genetic_type==@genetic_type").copy()
-
-        # HERE we could check that ID exists
-        # This file is required by the RNAdiff pipeline
-
-        identifiers = df.attributes.apply(lambda x: x[ID])
-        df["Gene_id"] = identifiers
-        df["Length"] = df.stop - df.start + 1
-
-        if merge_identical_id:
-            duplicated = df[df.Gene_id.duplicated()].Gene_id.drop_duplicates()
-            if len(duplicated):
-                logger.warning("Dropping {} duplicated {}(s)".format(len(duplicated), ID))
-
-            for name in duplicated.values:
-                S = df.query("Gene_id == @name").Length.sum()
-                items = df.query("Gene_id == @name").index
-                df.loc[items, "Length"] = S
-            df = df.drop_duplicates(subset=["Gene_id"])
-
-        df.sort_values("Gene_id")[["Gene_id", "Length"]].to_csv(
-            "{}_gene_lengths.tsv".format(outname), sep="\t", index=None
-        )
-
-        # Second file (redundant) is also required by the rnadiff pipeline
-        for this in fields:
-            data = df.attributes.apply(lambda x: x.get(this, "NA"))
-            df[this] = data
-
-        data = df.sort_values("Gene_id")[["Gene_id"] + fields]
-        data.to_csv("{}_info.tsv".format(outname), sep="\t", index=None)
-
-        return df
-
     def to_gtf(self, output_filename="test.gtf", mapper={"ID": "{}_id"}):
         # experimental . used by rnaseq pipeline to convert input gff to gtf,
         # used by RNA-seqc tools
@@ -445,6 +379,9 @@ class GFF3:
 
         with open(self.filename, "r") as reader:
             for line in reader:
+                # stop once FASTA starts
+                if line.startswith("##FASTA"):
+                    break
                 # Skip metadata and comments
                 if line.startswith("#"):
                     fout.write(line)
@@ -520,6 +457,9 @@ class GFF3:
         fout = open(output_filename, "w")
         with open(self.filename, "r") as reader:
             for line in reader:
+                # stop once FASTA starts
+                if line.startswith("##FASTA"):
+                    break
                 # Skip metadata and comments
                 if line.startswith("#"):
                     continue
@@ -577,27 +517,41 @@ class GFF3:
         return text
 
     def get_simplify_dataframe(self):
-        """ Method to simplify the gff and keep only the most informative features.
-        """
+        """Method to simplify the gff and keep only the most informative features."""
         # Set weight for genetic type to sort them and keep only the most informative
         if self.df.empty:
             raise BadFileFormat("%s file is not a GFF3.", self.filename)
-        genetype = ["tRNA", "rRNA", "CDS", "exon", "gene"]
+        genetype = ["tRNA", "rRNA", "ncRNA", "CDS", "exon", "gene", "tRNA"]
         worst_score = len(genetype) + 1
         weight = {k: i for i, k in enumerate(genetype)}
         # Note seems optional
-        if "Note" in self.df.columns:
-            df = self.df.filter(
-                ["seqid", "genetic_type", "start", "stop", "strand", "gene", "locus_tag", "product", "Note"], axis=1
-            )
-            df["product"] = df["product"].fillna(df["Note"])
-        else:
-            df = self.df.filter(
-                ["seqid", "genetic_type", "start", "stop", "strand", "gene", "locus_tag", "product"], axis=1
-            )
+
+        tokeep = [
+            x
+            for x in [
+                "seqid",
+                "genetic_type",
+                "start",
+                "stop",
+                "strand",
+                "gene",
+                "gene_id",
+                "gene_name",
+                "locus_tag",
+                "Note",
+                "product",
+            ]
+            if x in self.df.columns
+        ]
+
+        df = self.df.filter(tokeep, axis=1)
+
         # remove region and chromosome row
         df = df.drop(df.loc[df.genetic_type.isin({"region", "chromosome"})].index)
-        df["gene"] = df["gene"].fillna(df.locus_tag)
+        try:
+            df["gene"] = df["gene"].fillna(df.locus_tag)
+        except (KeyError, AttributeError):
+            pass
         df["score"] = [weight.get(g_t, worst_score) for g_t in df.genetic_type]
         # keep most informative features if on the same region
         best_idx = df.groupby(["seqid", "start", "stop"])["score"].idxmin()
@@ -607,7 +561,5 @@ class GFF3:
         """Format feature dict for sequana_coverage."""
         df = self.get_simplify_dataframe()
         # rename column to fit for sequana_coverage
-        df = df.set_index("seqid").rename(
-            columns={"start": "gene_start", "stop": "gene_end", "genetic_type": "type"}
-        )
+        df = df.set_index("seqid").rename(columns={"start": "gene_start", "stop": "gene_end", "genetic_type": "type"})
         return {chr: df.loc[chr].to_dict("records") for chr in df.index.unique()}
