@@ -14,12 +14,12 @@
 #
 ##############################################################################
 
-from sequana.lazy import pylab
-from sequana.utils.pandas import PandasReader
+from collections import Counter
 
 import colorlog
 
-from collections import Counter
+from sequana.lazy import pylab
+from sequana.utils.pandas import PandasReader
 
 logger = colorlog.getLogger(__name__)
 
@@ -29,15 +29,19 @@ __all__ = ["Homer"]
 
 class Homer:
     def __init__(self, filename):
-
+        self.filename = filename
         header = open(filename).readline().strip().split("\t")[1:]
 
         self.df = PandasReader(filename, sep="\t", skiprows=1, header=None).df
-        self.df.columns = ["ID"] + header
-        self.df.fillna("NA", inplace=True)
+
+        if len(self.df):
+            self.df.columns = ["ID"] + header
+            self.df.fillna("NA", inplace=True)
 
     def pie_annotation(self, wedgeprops={"ec": "k"}, **kwargs):
+        if len(self.df):
 
-        counts = Counter(self.df.Annotation)
-        labels = [f"{k.split()[0]} ({str(v)})" for k, v in counts.items()]
-        pylab.pie(counts.values(), labels=labels, wedgeprops=wedgeprops, **kwargs)
+            annotations = [x.split()[0] for x in self.df.Annotation]
+            counts = Counter(annotations)
+            labels = [f"{k.split()[0]} ({str(v)})" for k, v in counts.items()]
+            pylab.pie(counts.values(), labels=labels, wedgeprops=wedgeprops, **kwargs)
