@@ -11,21 +11,20 @@
 #
 ##############################################################################
 import os
-import sys
 import shutil
-
-from easydev import execute, TempFile, md5
-
-from sequana.lazy import pandas as pd
-from sequana.lazy import pylab
-from sequana.lazy import numpy as np
-
-from sequana.misc import wget
-from sequana import sequana_config_path
-
-from colormap import Colormap
+import sys
+from pathlib import Path, PosixPath
 
 import colorlog
+from colormap import Colormap
+from easydev import TempFile, md5
+from snakemake import shell
+
+from sequana import sequana_config_path
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
+from sequana.misc import wget
 
 logger = colorlog.getLogger(__name__)
 
@@ -34,7 +33,6 @@ __all__ = [
     "KrakenResults",
     "KrakenPipeline",
     "KrakenAnalysis",
-    "KrakenDownload",
     "KrakenSequential",
     "KrakenDB",
 ]
@@ -44,7 +42,6 @@ class KrakenDB:
     """Class to handle a kraken DB"""
 
     def __init__(self, filename):
-
         if isinstance(filename, KrakenDB):
             filename = filename.path
 
@@ -63,9 +60,7 @@ class KrakenDB:
         if os.path.exists(self.path + os.sep + "hash.k2d"):
             return "kraken2"
         else:  # pragma: no cover
-            logger.error(
-                "Sequana supports kraken2 only. Looks like an invalid kraken database directory"
-            )
+            logger.error("Sequana supports kraken2 only. Looks like an invalid kraken database directory")
 
     version = property(_get_database_version)
 
@@ -274,7 +269,7 @@ class KrakenResults(object):
                 usecols=[0, 2, 3],
                 chunksize=1000000,
             )
-        except (pd.errors.EmptyDataError,FileNotFoundError):  # pragma: no cover
+        except (pd.errors.EmptyDataError, FileNotFoundError):  # pragma: no cover
             logger.warning("Empty files. 100%% unclassified ?")
             self.unclassified = 0  # size of the input data set
             self.classified = 0
@@ -299,9 +294,7 @@ class KrakenResults(object):
         percentage = count / len(self._df) * 100
         if percentage >= 1:
             logger.warning(
-                "Found {} taxons of classified reads with root ID (1) ({} %)".format(
-                    count, round(percentage, 2)
-                )
+                "Found {} taxons of classified reads with root ID (1) ({} %)".format(count, round(percentage, 2))
             )
 
         # This gives the list of taxons as index and their amount
@@ -347,7 +340,6 @@ class KrakenResults(object):
     df = property(_get_df)
 
     def _get_df_with_taxon(self, dbname):
-
         df = self.get_taxonomy_db([int(x) for x in self.taxons.index])
         df["count"] = self.taxons.values
         df.reset_index(inplace=True)
@@ -359,7 +351,7 @@ class KrakenResults(object):
         try:
             df["percentage"] = df["count"] / df["count"].sum() * 100
         except ZeroDivisionError:
-            df['percentage'] = 0
+            df["percentage"] = 0
 
         starter = ["taxon", "count", "percentage"]
         df = df[starter + [x for x in df.columns if x not in starter]]
@@ -386,13 +378,11 @@ class KrakenResults(object):
         :return: status: True is everything went fine otherwise False
         """
         if output_filename is None:
-            output_filename = self.filename + ".summary"
+            output_filename = str(self.filename) + ".summary"
 
         taxon_to_find = list(self.taxons.index)
         if len(taxon_to_find) == 0:
-            logger.warning(
-                "No reads were identified. You will need a more complete database"
-            )
+            logger.warning("No reads were identified. You will need a more complete database")
             self.output_filename = output_filename
             with open(output_filename, "w") as fout:
                 fout.write("%s\t%s" % (self.unclassified, "Unclassified"))
@@ -487,9 +477,7 @@ class KrakenResults(object):
             elif kingdom == "Archaea":
                 this_cmap = Colormap().cmap_linear("yellow", "yellow", "orange")
             else:
-                this_cmap = Colormap().cmap_linear(
-                    "light gray", "gray(w3c)", "dark gray"
-                )
+                this_cmap = Colormap().cmap_linear("light gray", "gray(w3c)", "dark gray")
 
             kingdom_colors.append(this_cmap(0.8))
             inner_colors.extend(this_cmap(np.linspace(0.6, 0.2, len(y))))
@@ -546,11 +534,7 @@ class KrakenResults(object):
             label = wedge.get_label()
             if mapper[label] > 1:
                 taxon = taxons.loc[label, "index"]
-                webbrowser.open(
-                    "https://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi?id={}".format(
-                        taxon
-                    )
-                )
+                webbrowser.open("https://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi?id={}".format(taxon))
             else:
                 wedge.set_color("white")
 
@@ -642,9 +626,7 @@ class KrakenResults(object):
         pylab.clf()
         self.dd = data
         if kind == "pie":
-            ax = data.plot(
-                kind=kind, cmap=cmap, autopct="%1.1f%%", radius=radius, **kargs
-            )
+            ax = data.plot(kind=kind, cmap=cmap, autopct="%1.1f%%", radius=radius, **kargs)
             pylab.ylabel(" ")
             for text in ax.texts:
                 #  large, x-small, small, None, x-large, medium, xx-small,
@@ -664,9 +646,14 @@ class KrakenResults(object):
         return data
 
     def to_js(self, output="krona.html"):
+        if not shutil.which("ktImportText"):  # pragma: no cover
+            logger.error(
+                "ktImportText executable not found. Please install it with conda or the method of your choice. We also provide ktImportText within damona.readthedocs.io "
+            )
+            sys.exit(1)
         if self._data_created == False:
             status = self.kraken_to_krona()
-        execute("ktImportText %s -o %s" % (self.output_filename, output))
+        shell("ktImportText %s -o %s" % (self.output_filename, output))
 
     def boxplot_classified_vs_read_length(self):
         """Show distribution of the read length grouped by classified or not"""
@@ -724,7 +711,7 @@ class KrakenPipeline(object):
         either download a database from https://ccb.jhu.edu/software/kraken/
         or use this class to download a toy example that will
         be stored in e.g .config/sequana under Unix platforms.
-        See :class:`KrakenDownload`.
+        See :class:`~sequana.kraken.downloads.KrakenDownload`.
 
     .. seealso:: We provide a standalone application of this class, which is
         called sequana_taxonomy and can be used within a command shell.
@@ -756,10 +743,7 @@ class KrakenPipeline(object):
         """
         # Set and create output directory
         self.output_directory = output_directory
-        try:
-            os.makedirs(output_directory)
-        except FileExistsError:
-            pass
+        os.makedirs(output_directory, exist_ok=True)
 
         self.database = database
         self.ka = KrakenAnalysis(fastq, database, threads, confidence=confidence)
@@ -780,8 +764,14 @@ class KrakenPipeline(object):
         .. todo:: reuse the KrakenResults code to simplify this method.
 
         """
+        if not shutil.which("ktImportText"):  # pragma: no cover
+            logger.error(
+                "ktImportText executable not found. Please install it with conda or the method of your choice. We also provide ktImportText within damona.readthedocs.io "
+            )
+            sys.exit(1)
+
         # Run Kraken (KrakenAnalysis)
-        kraken_results = self.output_directory + os.sep + "kraken.out"
+        kraken_results = self.output_directory / "kraken.out"
 
         self.ka.run(
             output_filename=kraken_results,
@@ -800,35 +790,32 @@ class KrakenPipeline(object):
         except Exception as err:
             logger.warning(err)
             self.kr.plot(kind="pie")
-        pylab.savefig(self.output_directory + os.sep + "kraken.png")
+        pylab.savefig(self.output_directory / "kraken.png")
 
         # we save information about the unclassified reads (length)
         try:
             self.kr.boxplot_classified_vs_read_length()
-            pylab.savefig(self.output_directory + os.sep + "boxplot_read_length.png")
+            pylab.savefig(self.output_directory / "boxplot_read_length.png")
         except Exception as err:
             logger.warning("boxplot read length could not be computed")
 
         try:
             self.kr.histo_classified_vs_read_length()
-            pylab.savefig(self.output_directory + os.sep + "hist_read_length.png")
+            pylab.savefig(self.output_directory / "hist_read_length.png")
         except Exception as err:
             logger.warning("hist read length could not be computed")
 
-        prefix = self.output_directory + os.sep
+        prefix = self.output_directory
 
-        self.kr.kraken_to_json(prefix + "kraken.json", self.dbname)
-        self.kr.kraken_to_csv(prefix + "kraken.csv", self.dbname)
+        self.kr.kraken_to_json(prefix / "kraken.json", self.dbname)
+        self.kr.kraken_to_csv(prefix / "kraken.csv", self.dbname)
 
         # Transform to Krona HTML
-        from snakemake import shell
 
-        kraken_html = self.output_directory + os.sep + "kraken.html"
-        status = self.kr.kraken_to_krona(output_filename=prefix + "kraken.out.summary")
+        kraken_html = self.output_directory / "kraken.html"
+        status = self.kr.kraken_to_krona(output_filename=prefix / "kraken.out.summary")
         if status is True:
-            shell(
-                "ktImportText %s -o %s" % (prefix + "kraken.out.summary", kraken_html)
-            )
+            shell("ktImportText %s -o %s" % (prefix / "kraken.out.summary", kraken_html))
         else:
             shell("touch {}".format(kraken_html))
 
@@ -901,7 +888,8 @@ class KrakenAnalysis(object):
         self.confidence = confidence
 
         # Fastq input
-        if isinstance(fastq, str):
+
+        if isinstance(fastq, (str, PosixPath)):
             self.paired = False
             self.fastq = [fastq]
         elif isinstance(fastq, list):
@@ -913,7 +901,8 @@ class KrakenAnalysis(object):
                 raise IOError(("You must provide 1 or 2 files"))
             self.fastq = fastq
         else:
-            raise ValueError("Expected a fastq filename or list of 2 fastq filenames")
+            print(type(fastq), len(fastq))
+            raise ValueError(f"Expected a fastq filename or list of 2 fastq filenames Got {fastq}")
 
     def run(
         self,
@@ -930,6 +919,12 @@ class KrakenAnalysis(object):
         :param str output_filename_unclassified: not compressed
 
         """
+        if not shutil.which("kraken2"):  # pragma: no cover
+            logger.error(
+                "kraken2 executable not found. Please install it with conda or the method of your choice. We also provide kraken2 within damona.readthedocs.io "
+            )
+            sys.exit(1)
+
         if self.database.version != "kraken2":
             logger.error(f"input database is not valid kraken2 database")
             sys.exit(1)
@@ -945,13 +940,13 @@ class KrakenAnalysis(object):
         # make sure the required output directories exist:
         # and that the output filenames ends in .fastq
         if output_filename_classified:
-            assert output_filename_classified.endswith(".fastq")
+            assert output_filename_classified.name.endswith(".fastq")
             dirname = os.path.dirname(output_filename_classified)
             if os.path.exists(dirname) is False:
                 os.makedirs(dirname)
 
         if output_filename_unclassified:
-            assert output_filename_unclassified.endswith(".fastq")
+            assert output_filename_unclassified.name.endswith(".fastq")
             dirname = os.path.dirname(output_filename_unclassified)
             if os.path.exists(dirname) is False:
                 os.makedirs(dirname)
@@ -1014,7 +1009,6 @@ class KrakenAnalysis(object):
 
         command = command % params
         logger.debug(command)
-        from snakemake import shell
 
         shell(command)
 
@@ -1090,16 +1084,13 @@ class KrakenSequential(object):
         # input databases may be stored in a file
         if isinstance(fof_databases, str) and os.path.exists(fof_databases):
             with open(fof_databases, "r") as fof:
-                self.databases = [
-                    absolute_path.split("\n")[0] for absolute_path in fof.readlines()
-                ]
+                self.databases = [absolute_path.split("\n")[0] for absolute_path in fof.readlines()]
         # or simply provided as a list
-        elif isinstance(fof_databases, list):
+        elif isinstance(fof_databases, (list, tuple)):
             self.databases = fof_databases[:]
         else:
             raise TypeError(
-                "input databases must be a list of valid kraken2 "
-                "databases or a file (see documebntation)"
+                "input databases must be a list of valid kraken2 " "databases or a file (see documentation)"
             )
 
         self.databases = [KrakenDB(x) for x in self.databases]
@@ -1122,8 +1113,7 @@ class KrakenSequential(object):
                 raise Exception
             elif force is True:
                 logger.warning(
-                    "Output directory %s already exists. You may "
-                    "overwrite existing results" % output_directory
+                    "Output directory %s already exists. You may " "overwrite existing results" % output_directory
                 )
 
         # list of input fastq files
@@ -1150,7 +1140,7 @@ class KrakenSequential(object):
         logger.info("Analysing data using database {}".format(db))
 
         # a convenient alias
-        _pathto = lambda x: self.output_directory + x
+        _pathto = lambda x: self.output_directory / x
 
         # the output is saved in this file
         if self.paired:
@@ -1178,7 +1168,7 @@ class KrakenSequential(object):
         else:
             only_classified_output = True
 
-        file_kraken_out = self.output_directory + "/kraken_{}.out".format(iteration)
+        file_kraken_out = self.output_directory / "kraken_{}.out".format(iteration)
 
         # The analysis itself
         analysis = KrakenAnalysis(inputs, db, self.threads, confidence=self.confidence)
@@ -1221,7 +1211,7 @@ class KrakenSequential(object):
             last_unclassified = self._list_kraken_input[-1]
 
             # If everything was classified, we can stop here
-            try: # handle special case of emmpty FastQ file
+            try:  # handle special case of emmpty FastQ file
                 try:
                     stat = os.stat(last_unclassified)
                     if stat.st_size == 0:
@@ -1234,7 +1224,7 @@ class KrakenSequential(object):
                 break
 
         # concatenate all kraken output files
-        file_output_final = self.output_directory + os.sep + "%s.out" % output_prefix
+        file_output_final = self.output_directory / f"{output_prefix}.out"
         with open(file_output_final, "w") as outfile:
             for fname in self._list_kraken_output:
                 with open(fname) as infile:
@@ -1246,27 +1236,27 @@ class KrakenSequential(object):
 
         try:
             result.histo_classified_vs_read_length()
-            pylab.savefig(self.output_directory + os.sep + "hist_read_length.png")
+            pylab.savefig(self.output_directory / "hist_read_length.png")
         except Exception as err:
             logger.warning("hist read length could not be computed")
 
         try:
             result.boxplot_classified_vs_read_length()
-            pylab.savefig(self.output_directory + os.sep + "boxplot_read_length.png")
+            pylab.savefig(self.output_directory / "boxplot_read_length.png")
         except Exception as err:
             logger.warning("hist read length could not be computed")
 
         # TODO: this looks similar to the code in KrakenPipeline. could be factorised
-        result.to_js("%s%s%s.html" % (self.output_directory, os.sep, output_prefix))
+        result.to_js("%s.html" % (self.output_directory / output_prefix))
         try:
             result.plot2(kind="pie")
         except Exception as err:
             logger.warning(err)
             result.plot(kind="pie")
-        pylab.savefig(self.output_directory + os.sep + "kraken.png")
-        prefix = self.output_directory + os.sep
-        result.kraken_to_json(prefix + "kraken.json", dbname)
-        result.kraken_to_csv(prefix + "kraken.csv", dbname)
+        pylab.savefig(self.output_directory / "kraken.png")
+        prefix = self.output_directory
+        result.kraken_to_json(prefix / "kraken.json", dbname)
+        result.kraken_to_csv(prefix / "kraken.csv", dbname)
 
         # remove kraken intermediate files (including unclassified files)
         if self.unclassified_output:
@@ -1276,7 +1266,6 @@ class KrakenSequential(object):
                 shutil.copy2(self._list_kraken_input[-1], self.unclassified_output)
             except:
                 for i, x in enumerate(self._list_kraken_input[-1]):
-
                     shutil.copy2(x, self.unclassified_output.replace("#", str(i + 1)))
 
         if self.classified_output:
@@ -1327,59 +1316,3 @@ class KrakenSequential(object):
         return summary
 
 
-class KrakenDownload(object):
-    """Utility to download Kraken DB and place them in a local directory
-
-    ::
-
-        from sequana import KrakenDownload
-        kd = KrakenDownload()
-        kd.download('toydb')
-
-    """
-
-    def __init__(self, output_dir=None):
-        if output_dir is None:
-            self.output_dir = f"{sequana_config_path}{os.sep}kraken2_dbs"
-        else:
-            self.output_dir = output_dir
-
-    def download(self, name, verbose=True):
-        if name == "toydb":
-            self._download_kraken2_toydb(verbose=verbose)
-        else:
-            raise ValueError("name must be 'toydb' for now")
-
-    def _download_kraken2_toydb(self, verbose=True):
-        """Download the kraken DB toy example from sequana_data into
-        .config/sequana directory
-
-        Checks the md5 checksums. About 32Mb of data
-        """
-        base = f"{self.output_dir}{os.sep}toydb"
-        try:
-            os.makedirs(base)
-        except FileExistsError:
-            pass
-
-        baseurl = "https://github.com/sequana/data/raw/main/"
-
-        # download only if required
-        logger.info("Downloading the database into %s" % base)
-
-        md5sums = [
-            "31f4b20f9e5c6beb9e1444805264a6e5",
-            "733f7587f9c0c7339666d5906ec6fcd3",
-            "7bb56a0f035b27839fb5c18590b79263",
-        ]
-
-        filenames = ["hash.k2d", "opts.k2d", "taxo.k2d"]
-
-        for filename, md5sum in zip(filenames, md5sums):
-            url = baseurl + f"kraken2_toydb/{filename}"
-            filename = base + os.sep + filename
-            if os.path.exists(filename) and md5(filename) == md5sum:
-                logger.warning(f"{filename} already present with good md5sum")
-            else:
-                logger.info(f"Downloading {url}")
-                wget(url, filename)
