@@ -18,9 +18,8 @@ from sequana.lazyimports import LazyImport
 # lazy imports
 pylab = LazyImport("pylab")
 numpy = LazyImport("numpy")
-scipy = LazyImport("scipy")
-scipy_stats = LazyImport("scipy.stats")
 pandas = LazyImport("pandas")
+pysam = LazyImport("pysam")
 
 
 def enabled():
