@@ -1,7 +1,9 @@
 # source
 # http://nbviewer.ipython.org/github/tritemio/notebooks/blob/master/Mixture_Model_Fitting.ipynb
 
-from easydev import DevTools, AttrDict
+import warnings
+
+from easydev import AttrDict, DevTools
 
 devtools = DevTools()
 
@@ -10,7 +12,6 @@ from sequana.lazy import pylab
 
 from . import criteria
 
-
 half_log_two_pi = 0.5 * np.log(2 * np.pi)
 
 
@@ -65,8 +66,10 @@ class GaussianMixtureModel(object):
         return data
 
     def log_likelihood(self, params, sample):
-        res = -1 * pylab.log(self.pdf(sample, params)).sum()
-        return res
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            res = -1 * pylab.log(self.pdf(sample, params)).sum()
+            return res
 
 
 class Fitting(object):
@@ -136,7 +139,6 @@ class Fitting(object):
         hist_kw={"color": "#5F9EA0", "edgecolor": "k"},
         ax=None,
     ):
-
         if ax:
             ax.hist(self.data, normed=normed, bins=bins, **hist_kw)
         else:
@@ -157,12 +159,27 @@ class Fitting(object):
         import scipy.stats as ss
 
         for i in range(self.k):
-
-            mu, sigma, pi_ = self.results.mus[i], self.results.sigmas[i], self.results.pis[i]
+            mu, sigma, pi_ = (
+                self.results.mus[i],
+                self.results.sigmas[i],
+                self.results.pis[i],
+            )
             if ax:
-                ax.plot(X, [pi_ * ss.norm.pdf(x, mu, sigma) for x in X], "k--", alpha=0.7, lw=2)
+                ax.plot(
+                    X,
+                    [pi_ * ss.norm.pdf(x, mu, sigma) for x in X],
+                    "k--",
+                    alpha=0.7,
+                    lw=2,
+                )
             else:
-                pylab.plot(X, [pi_ * ss.norm.pdf(x, mu, sigma) for x in X], "k--", alpha=0.7, lw=2)
+                pylab.plot(
+                    X,
+                    [pi_ * ss.norm.pdf(x, mu, sigma) for x in X],
+                    "k--",
+                    alpha=0.7,
+                    lw=2,
+                )
 
 
 class GaussianMixtureFitting(Fitting):
@@ -198,7 +215,10 @@ class GaussianMixtureFitting(Fitting):
         return self._method
 
     def _set_method(self, method):
-        devtools.check_param_in_list(method, ["Nelder-Mead", "Powell", "CG", "BFGS", "Newton-CG", "Anneal", "L-BFGS-B"])
+        devtools.check_param_in_list(
+            method,
+            ["Nelder-Mead", "Powell", "CG", "BFGS", "Newton-CG", "Anneal", "L-BFGS-B"],
+        )
         self._method = method
 
     method = property(_get_method, _set_method)
@@ -338,7 +358,9 @@ class EM(Fitting):
 
                 # self.model.pdf(self.data, p_new,normalise=False).sum()!=0:
                 gamma[k, :] = pi_[k] * ss.norm.pdf(self.data, mu[k], sig[k])
-                gamma[k, :] /= self.model.pdf(self.data, p_new, normalise=False)
+                with warnings.catch_warnings():
+                    warnings.simplefilter("ignore")
+                    gamma[k, :] /= self.model.pdf(self.data, p_new, normalise=False)
                 """else:
                     gamma[k, :] = pi_[k]*pylab.normpdf(self.data, mu[k],
                         sig[k])/(self.model.pdf(self.data, p_new,
