@@ -16,16 +16,16 @@
 #
 ##############################################################################
 """Generic module is the parent module of all other module"""
+import base64
+import io
 import os
 import shutil
-import io
-import base64
 
+import colorlog
 from jinja2 import Environment, PackageLoader
 
 # from reports import HTMLTable
 from sequana.utils import config
-import colorlog
 
 logger = colorlog.getLogger(__name__)
 
@@ -88,6 +88,7 @@ class SequanaBaseModule(object):
                 shutil.copy(filename, target)
 
         target = os.sep.join([self.output_dir, "images"])
+        os.makedirs(target, exist_ok=True)
         if os.path.isfile(target) is False:
             shutil.copy(config.logo, target)
 
@@ -252,7 +253,6 @@ class SequanaBaseModule(object):
         file_thumbnails=None,
         captions=None,
     ):
-
         if self._fotorama_js_added is False:
             script = """
         <!-- jQuery 1.8 or later, 33 KB -->
@@ -269,7 +269,7 @@ class SequanaBaseModule(object):
             if len(files) != len(captions):
                 raise ValueError("captions and files must be of same length with 1-to-1 mapping")
         else:
-            captions = [filename.split("/")[-1] for filename in files]
+            captions = [filename.name for filename in files]
 
         script += '<div class="fotorama" fzyz-keyboard="true" '
         if thumbnails is True:
