@@ -18,16 +18,15 @@
 """Module to write coverage report"""
 import os
 
+import colorlog
 import pandas as pd
 
 from sequana import bedtools
 from sequana.modules_report.base_module import SequanaBaseModule
+from sequana.modules_report.summary import SummaryModule
+from sequana.plots.canvasjs_linegraph import CanvasJSLineGraph
 from sequana.utils import config
 from sequana.utils.datatables_js import DataTable, DataTableFunction
-from sequana.plots.canvasjs_linegraph import CanvasJSLineGraph
-from sequana.modules_report.summary import SummaryModule
-
-import colorlog
 
 logger = colorlog.getLogger(__name__)
 
@@ -37,52 +36,63 @@ __all__ = ["CoverageModule", "ChromosomeCoverageModule"]
 
 class CoverageModule(SequanaBaseModule):
     """Write HTML report of coverage analysis. This class takes either a
-    :class:`GenomeCov` instances or a csv file where analysis are stored.
+    :class:`SequanaCoverage` instances or a csv file where analysis are stored.
     """
 
     def __init__(self, data, region_window=200000):
         """.. rubric:: constructor
 
         :param data: it can be a csv filename created by sequana_coverage or a
-            :class:`bedtools.GenomeCov` object.
+            :class:`bedtools.SequanaCoverage` object.
         :param region_window:
         """
         super().__init__()
         self.region_window = region_window
 
-        if isinstance(data, bedtools.GenomeCov):
+        if isinstance(data, bedtools.SequanaCoverage):
             self.bed = data
         else:
             raise TypeError
 
-        try:
-            html_list = self.create_chromosome_reports()
-        except TypeError:
-            msg = (
-                "Data must be either a csv file or a :class:`GenomeCov` "
-                "instance where zscore is computed."
-            )
-            raise TypeError(msg)
+        if len(self.bed._html_list) == 0:
+            try:
+                html_list = self.create_chromosome_reports()
+            except TypeError:
+                msg = (
+                    "Data must be either a csv file or a :class:`SequanaCoverage` " "instance where zscore is computed."
+                )
+                raise TypeError(msg)
+        else:
+            html_list = list(self.bed._html_list)
 
-        self.title = "Main coverage report ({0})".format(config.sample_name)
+        self.title = f"Main coverage report ({config.sample_name})"
         self.intro = (
-            "<p>Report the coverage of your sample ({0}) to check the "
+            f"<p>Report the coverage of your sample ({config.sample_name}) to check the "
             "quality of your mapping and to highlight regions of "
-            "interest (under and over covered).</p>".format(config.sample_name)
+            "interest (under and over covered).</p>"
         )
-        self.create_report_content(html_list)
-        self.create_html("sequana_coverage.html")
 
-    def create_report_content(self, html_list):
+        # set the chromosome tables
         self.sections = list()
+
         self.create_chromosome_table(html_list)
 
+        # and create final HTML
+        self.create_html("sequana_coverage.html")
+
     def create_chromosome_table(self, html_list):
         """Create table with links to chromosome reports"""
+
         df = pd.DataFrame(
             [
-                [chrom.chrom_name, chrom.get_size(), chrom.DOC, chrom.CV, page]
-                for chrom, page in zip(self.bed.chr_list, html_list)
+                [
+                    chrom,
+                    self.bed._basic_stats[chrom]["length"],
+                    self.bed._basic_stats[chrom]["DOC"],
+                    self.bed._basic_stats[chrom]["CV"],
+                    f"{chrom}/{chrom}.cov.html",
+                ]
+                for chrom in self.bed.chrom_names
             ],
             columns=["chromosome", "size", "mean_coverage", "coef_variation", "link"],
         )
@@ -107,7 +117,7 @@ class CoverageModule(SequanaBaseModule):
 
     def create_chromosome_reports(self):
         """Create HTML report for each chromosome present in data."""
-        # FIXME: why bed[0] (i.e. first chromosome)
+        # We choose the first chromosome, to build a common javascript object
         datatable_js = CoverageModule.init_roi_datatable(self.bed[0])
         chrom_output_dir = config.output_dir
         if not os.path.exists(chrom_output_dir):
@@ -115,10 +125,8 @@ class CoverageModule(SequanaBaseModule):
 
         page_list = []
         for chrom in self.bed:
-            logger.info("Creating coverage report {}".format(chrom.chrom_name))
-            chrom_report = ChromosomeCoverageModule(
-                chrom, datatable_js, region_window=self.region_window
-            )
+            logger.info(f"Creating coverage report {chrom.chrom_name}")
+            chrom_report = ChromosomeCoverageModule(chrom, datatable_js, region_window=self.region_window)
             page_list.append(chrom_report.html_page)
         return page_list
 
@@ -159,9 +167,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
     created by CoverageModule.
     """
 
-    def __init__(
-        self, chromosome, datatable, region_window=200000, options=None, command=""
-    ):
+    def __init__(self, chromosome, datatable, region_window=200000, options=None, command="", skip_html=False):
         """
 
         :param chromosome:
@@ -186,22 +192,22 @@ class ChromosomeCoverageModule(SequanaBaseModule):
         self.datatable = datatable
         self.command = command
         self.command += "\nSequana version: {}".format(config.version)
-        self.title = "Coverage analysis of chromosome {0}".format(
+        self.title = "Coverage analysis of chromosome {0}".format(self.chromosome.chrom_name)
+
+        self.intro = "<p>The genome coverage analysis of the chromosome " "<b>{0}</b>.</p>".format(
             self.chromosome.chrom_name
         )
-
-        self.intro = (
-            "<p>The genome coverage analysis of the chromosome "
-            "<b>{0}</b>.</p>".format(self.chromosome.chrom_name)
-        )
-
         self.create_report_content(directory, options=options)
-        self.html_page = "{0}{1}{2}.cov.html".format(
-            directory, os.sep, self.chromosome.chrom_name
-        )
 
+        if skip_html:
+            return
+
+        self.html_page = "{0}{1}{2}.cov.html".format(directory, os.sep, self.chromosome.chrom_name)
         self.create_html(self.html_page)
 
+        # inform the main coverage instance that HTML is ready
+        self.chromosome.bed._html_list = self.chromosome.bed._html_list.union([self.html_page])
+
     def create_report_content(self, directory, options=None):
         """Generate the sections list to fill the HTML report."""
         self.sections = list()
@@ -209,7 +215,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
         if self.chromosome._mode == "memory":
             # nothing to do, all computations should be already available
             # and in memory
-            rois = self.chromosome.get_rois()
+            rois = self.chromosome.rois
         elif self.chromosome._mode == "chunks":
             # we need to reset the data to the first chunk
             # and compute the median and zscore. So, first, we save the entire
@@ -253,10 +259,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
             {
                 "name": name,
                 "anchor": anchor,
-                "content": (
-                    "<p>Large data sets (--chunk-size argument "
-                    "used), skipped plotting.</p>"
-                ),
+                "content": ("<p>Large data sets (--chunk-size argument " "used), skipped plotting.</p>"),
             }
         )
 
@@ -266,9 +269,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
             self._add_large_data_section("Coverage", "coverage")
             return
 
-        image = self.create_embedded_png(
-            self.chromosome.plot_coverage, input_arg="filename"
-        )
+        image = self.create_embedded_png(self.chromosome.plot_coverage, input_arg="filename")
 
         self.sections.append(
             {
@@ -280,9 +281,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
                 "z-scores on a per-base level. The red lines indicates the "
                 "z-scores at plus or minus N standard deviations, where N is "
                 "chosen by the user. (default:4). Only a million point are "
-                "shown. This may explain some visual discrepancies with. </p>\n{0}".format(
-                    image
-                ),
+                "shown. This may explain some visual discrepancies with. </p>\n{0}".format(image),
             }
         )
 
@@ -292,9 +291,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
             self._add_large_data_section("Coverage histogram", "cov_barplot")
             return
 
-        image1 = self.create_embedded_png(
-            self.chromosome.plot_hist_coverage, input_arg="filename", style="width:45%"
-        )
+        image1 = self.create_embedded_png(self.chromosome.plot_hist_coverage, input_arg="filename", style="width:45%")
         image2 = self.create_embedded_png(
             self.chromosome.plot_hist_coverage,
             input_arg="filename",
@@ -345,7 +342,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
 
         # create directory
 
-        chrom_output_dir = os.sep.join([config.output_dir, str(directory), str(name)])
+        chrom_output_dir = os.sep.join([config.output_dir, str(directory), "subplots"])
         if not os.path.exists(chrom_output_dir):
             os.makedirs(chrom_output_dir)
 
@@ -354,14 +351,8 @@ class ChromosomeCoverageModule(SequanaBaseModule):
         # figure out the boundary. Indeed, you can imagine a BED file
         # that does not start at position zero, but from POS1>0 to POS2
 
-        links = [
-            "{0}/{0}_{1}_{2}.html".format(name, i, min(i + W, maxpos))
-            for i in range(shift, shift + N, W)
-        ]
-        intra_links = (
-            "{0}_{1}_{2}.html".format(name, i, min(i + W, maxpos))
-            for i in range(shift, shift + N, W)
-        )
+        links = ["subplots/{0}_{1}_{2}.html".format(name, i, min(i + W, maxpos)) for i in range(shift, shift + N, W)]
+        intra_links = ("{0}_{1}_{2}.html".format(name, i, min(i + W, maxpos)) for i in range(shift, shift + N, W))
 
         combobox = self.create_combobox(links, "sub", True)
         combobox_intra = self.create_combobox(intra_links, "sub", False)
@@ -369,13 +360,9 @@ class ChromosomeCoverageModule(SequanaBaseModule):
 
         # break the chromosome as pieces of 200,000 bp
         for i in range(shift, shift + N, W):
-            SubCoverageModule(
-                chrom, rois, combobox_intra, datatable, i, min(i + W, maxpos), directory
-            )
+            SubCoverageModule(chrom, rois, combobox_intra, datatable, i, min(i + W, maxpos), directory)
 
-        self.sections.append(
-            {"name": "Subcoverage", "anchor": "subcoverage", "content": combobox}
-        )
+        self.sections.append({"name": "Subcoverage", "anchor": "subcoverage", "content": combobox})
         return links
 
     def _init_datatable_function(self, rois):
@@ -399,11 +386,9 @@ class ChromosomeCoverageModule(SequanaBaseModule):
         stats = self.chromosome.get_stats()
 
         description = {
-            "BOC": "breadth of coverage: the proportion (in %s) "
-            + " of the genome covered by at least one read.",
+            "BOC": "breadth of coverage: the proportion (in %s) " + " of the genome covered by at least one read.",
             "CV": "the coefficient of variation.",
-            "DOC": "the sequencing depth (Depth of Coverage), that is the "
-            + "average the genome coverage.",
+            "DOC": "the sequencing depth (Depth of Coverage), that is the " + "average the genome coverage.",
             "MAD": "median of the absolute median deviation defined as median(|X-median(X)|).",
             "Median": "Median of the coverage.",
             "STD": "standard deviation.",
@@ -421,8 +406,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
             {
                 "name": "Basic stats",
                 "anchor": "basic_stats",
-                "content": "<p>Here are some basic statistics about the "
-                "genome coverage.</p>\n{0}".format(stats),
+                "content": "<p>Here are some basic statistics about the " "genome coverage.</p>\n{0}".format(stats),
             }
         )
 
@@ -502,9 +486,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
 
     def gc_vs_coverage(self):
         """3 dimensional plot of GC content versus coverage."""
-        image = self.create_embedded_png(
-            self.chromosome.plot_gc_vs_coverage, input_arg="filename"
-        )
+        image = self.create_embedded_png(self.chromosome.plot_gc_vs_coverage, input_arg="filename")
         corr = self.chromosome.get_gc_correlation()
         self.sections.append(
             {
@@ -516,9 +498,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
                 "<p>Note: the correlation coefficient has to be between -1.0 "
                 "and 1.0. A coefficient of 0 means no correlation, while a "
                 "coefficient of -1 or 1 means an existing "
-                "correlation between GC and Coverage</p>".format(
-                    corr, self.chromosome.bed.gc_window_size, image
-                ),
+                "correlation between GC and Coverage</p>".format(corr, self.chromosome.bed.gc_window_size, image),
             }
         )
 
@@ -528,9 +508,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
             self._add_large_data_section("Normalised coverage", "normalised_coverage")
             return
 
-        image = self.create_embedded_png(
-            self.chromosome.plot_hist_normalized_coverage, input_arg="filename"
-        )
+        image = self.create_embedded_png(self.chromosome.plot_hist_normalized_coverage, input_arg="filename")
         self.sections.append(
             {
                 "name": "Normalised coverage",
@@ -547,9 +525,7 @@ class ChromosomeCoverageModule(SequanaBaseModule):
             self._add_large_data_section("Z-Score distribution", "zscore_distribution")
             return
 
-        image = self.create_embedded_png(
-            self.chromosome.plot_hist_zscore, input_arg="filename"
-        )
+        image = self.create_embedded_png(self.chromosome.plot_hist_zscore, input_arg="filename")
         self.sections.append(
             {
                 "name": "Z-Score distribution",
@@ -586,15 +562,12 @@ class SubCoverageModule(SequanaBaseModule):
 
         self.start = start
         self.stop = stop
-        self.title = (
-            "Coverage analysis of chromosome {0}<br>"
-            "positions {1} and {2}".format(self.chromosome.chrom_name, start, stop)
+        self.title = "Coverage analysis of chromosome {0}<br>" "positions {1} and {2}".format(
+            self.chromosome.chrom_name, start, stop
         )
         self.create_report_content()
         self.create_html(
-            "{0}{4}{1}{4}{1}_{2}_{3}.html".format(
-                directory, self.chromosome.chrom_name, start, stop, os.sep
-            )
+            "{0}{4}subplots{4}{1}_{2}_{3}.html".format(directory, self.chromosome.chrom_name, start, stop, os.sep)
         )
 
     def create_report_content(self):
@@ -622,9 +595,7 @@ class SubCoverageModule(SequanaBaseModule):
         # create CanvasJS stuff
         cjs = CanvasJSLineGraph(csv, "cov", x_col, y_col)
         # set options
-        cjs.set_options(
-            {"zoomEnabled": "true", "zoomType": "x", "exportEnabled": "true"}
-        )
+        cjs.set_options({"zoomEnabled": "true", "zoomType": "x", "exportEnabled": "true"})
         # set title
         cjs.set_title("Genome Coverage")
         # set legend
@@ -673,7 +644,7 @@ class SubCoverageModule(SequanaBaseModule):
                 index=i,
                 data_dict={
                     "type": "line",
-                    "name": "Filtered coverage",
+                    "name": "Coverage 2",
                     "showInLegend": "true",
                     "color": "#D9534F",
                     "lineColor": "#D9534F",
