@@ -11,24 +11,23 @@
 #
 ##############################################################################
 """Pacbio QC and stats"""
-import os
 import collections
 import json
+import os
 import random
 
-from sequana.lazy import pylab
-from sequana.lazy import numpy as np
-from sequana.lazy import pandas as pd
+import colorlog
 import pysam
 
-import colorlog
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
 
 logger = colorlog.getLogger(__name__)
 
 
 from sequana.summary import Summary
 
-
 __all__ = ["PacbioMappedBAM", "PacbioSubreads", "PBSim", "BAMSimul", "Barcoding"]
 
 
@@ -68,7 +67,7 @@ class HistCumSum(object):
         pylab.grid(self.grid)
         pylab.title(self.title)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
 
@@ -109,7 +108,12 @@ class PacbioBAMBase(object):
         # are split on 80-characters length)
         from snakemake import shell
 
-        cmd = "samtools %s  -@ %s %s > %s" % (mode, threads, self.filename, output_filename)
+        cmd = "samtools %s  -@ %s %s > %s" % (
+            mode,
+            threads,
+            self.filename,
+            output_filename,
+        )
         logger.info("Please be patient")
         logger.info("This may be long depending on your input data file: ")
         logger.info("typically, a minute per  500,000 reads")
@@ -134,7 +138,16 @@ class PacbioBAMBase(object):
         self._to_fastX("fasta", output_filename, threads=threads)
 
     def hist_GC(
-        self, bins=50, alpha=0.5, hold=False, fontsize=12, grid=True, xlabel="GC %", ylabel="#", label="", title=None
+        self,
+        bins=50,
+        alpha=0.5,
+        hold=False,
+        fontsize=12,
+        grid=True,
+        xlabel="GC %",
+        ylabel="#",
+        label="",
+        title=None,
     ):
         """Plot histogram GC content
 
@@ -179,12 +192,19 @@ class PacbioBAMBase(object):
             pylab.grid(True)
         pylab.xlim([0, 100])
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
 
     def plot_GC_read_len(
-        self, hold=False, fontsize=12, bins=[200, 60], grid=True, xlabel="GC %", ylabel="#", cmap="BrBG"
+        self,
+        hold=False,
+        fontsize=12,
+        bins=[200, 60],
+        grid=True,
+        xlabel="GC %",
+        ylabel="#",
+        cmap="BrBG",
     ):
         """Plot GC content versus read length
 
@@ -218,7 +238,10 @@ class PacbioBAMBase(object):
         res = h.plot(bins=bins, contour=False, norm="log", Nlevels=6, cmap=cmap)
         pylab.xlabel("Read length", fontsize=fontsize)
         pylab.ylabel("GC %", fontsize=fontsize)
-        pylab.title("GC %% vs length \n Mean length : %.2f , Mean GC : %.2f" % (mean_len, mean_GC), fontsize=fontsize)
+        pylab.title(
+            "GC %% vs length \n Mean length : %.2f , Mean GC : %.2f" % (mean_len, mean_GC),
+            fontsize=fontsize,
+        )
         pylab.ylim([0, 100])
         if grid is True:
             pylab.grid(True)
@@ -489,7 +512,12 @@ class PacbioSubreads(PacbioBAMBase):
                         shift = np.random.randint(stride)
 
     def random_selection(
-        self, output_filename, nreads=None, expected_coverage=None, reference_length=None, read_lengths=None
+        self,
+        output_filename,
+        nreads=None,
+        expected_coverage=None,
+        reference_length=None,
+        read_lengths=None,
     ):
         """Select random reads
 
@@ -617,10 +645,30 @@ class PacbioSubreads(PacbioBAMBase):
 
         bins = pylab.linspace(0, maxSNR, bins)
 
-        pylab.hist(self._df.loc[:, "snr_A"].clip(upper=maxSNR), alpha=alpha, label="A", bins=bins)
-        pylab.hist(self._df.loc[:, "snr_C"].clip(upper=maxSNR), alpha=alpha, label="C", bins=bins)
-        pylab.hist(self._df.loc[:, "snr_G"].clip(upper=maxSNR), alpha=alpha, label="G", bins=bins)
-        pylab.hist(self._df.loc[:, "snr_T"].clip(upper=maxSNR), alpha=alpha, label="T", bins=bins)
+        pylab.hist(
+            self._df.loc[:, "snr_A"].clip(upper=maxSNR),
+            alpha=alpha,
+            label="A",
+            bins=bins,
+        )
+        pylab.hist(
+            self._df.loc[:, "snr_C"].clip(upper=maxSNR),
+            alpha=alpha,
+            label="C",
+            bins=bins,
+        )
+        pylab.hist(
+            self._df.loc[:, "snr_G"].clip(upper=maxSNR),
+            alpha=alpha,
+            label="G",
+            bins=bins,
+        )
+        pylab.hist(
+            self._df.loc[:, "snr_T"].clip(upper=maxSNR),
+            alpha=alpha,
+            label="T",
+            bins=bins,
+        )
         pylab.legend()
         pylab.xlabel(xlabel, fontsize=fontsize)
         pylab.ylabel(ylabel, fontsize=fontsize)
@@ -971,7 +1019,6 @@ class PBSim(object):
         self.bam_simul = BAMSimul(simul_bam)
 
     def target_distribution(self, xprime):
-
         """The target distribution
 
         Compute histogram. Get X, Y.  Given xprime, interpolate to get yprime
@@ -980,7 +1027,16 @@ class PBSim(object):
         """
         return np.interp(xprime, self.X[1 : self.bins + 1], self.Y)
 
-    def run(self, bins=50, xmin=0, xmax=30000, step=1000, burn=1000, alpha=1, output_filename=None):
+    def run(
+        self,
+        bins=50,
+        xmin=0,
+        xmax=30000,
+        step=1000,
+        burn=1000,
+        alpha=1,
+        output_filename=None,
+    ):
         # compute histogram of the input reads once for all to be used
         # in the target_distribution method
         self.bins = bins
@@ -1055,7 +1111,7 @@ class Barcoding:
         pylab.legend()
         pylab.ylim(ymin=0)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
 
@@ -1071,7 +1127,7 @@ class Barcoding:
         pylab.xlabel("Number of Polymerase Reads", fontsize=fontsize)
         pylab.ylabel("Number of Barcoded Samples", fontsize=fontsize)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
 
@@ -1080,7 +1136,7 @@ class Barcoding:
         pylab.xlabel("Mean Polymerase Read Length", fontsize=fontsize)
         pylab.ylabel("Number of Barcoded Samples", fontsize=fontsize)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
 
@@ -1089,7 +1145,7 @@ class Barcoding:
         pylab.xlabel("Number of subreads", fontsize=fontsize)
         pylab.ylabel("Number of Barcoded Samples", fontsize=fontsize)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
 
@@ -1098,14 +1154,17 @@ class Barcoding:
         pylab.xlabel("Mean Barcode Quality", fontsize=fontsize)
         pylab.ylabel("Number of Barcoded Samples", fontsize=fontsize)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except:
             pass
 
     def __str__(self):
         PR = self.df_barcoded["Polymerase Reads"]
         MRL = self.df_barcoded["Mean Read Length"]
-        PR_NOBC = self.df_not_barcoded["Polymerase Reads"].values[0]
+        if len(self.df_not_barcoded):
+            PR_NOBC = self.df_not_barcoded["Polymerase Reads"].values[0]
+        else:
+            PR_NOBC = 0
 
         txt = "{} unique barcodes\n".format(len(self.df_barcoded))
         txt += "{} barcoded PR reads\n".format(PR.sum())
