@@ -21,5 +21,5 @@ Other files stored in this directory will be documented here.
 #: List of adapters used in various sequencing platforms
 adapters = {
     "adapters_netflex_pcr_free_1_fwd": "adapters_netflex_pcr_free_1_fwd.fa",
-    "adapters_netflex_pcr_free_1_rev": "adapters_netflex_pcr_free_1_rev.fa"
-    }
+    "adapters_netflex_pcr_free_1_rev": "adapters_netflex_pcr_free_1_rev.fa",
+}
