@@ -10,23 +10,20 @@
 #
 ##############################################################################
 """Ribodesigner module"""
-import sys
+import datetime
 import json
+import shutil
 import subprocess
+import sys
+from itertools import product
 from pathlib import Path
 
-import pandas as pd
-import pylab
-import pysam
-import numpy as np
-import seaborn as sns
-import shutil
-import datetime
-from itertools import product
-
 from sequana import logger
-from sequana.tools import reverse_complement
 from sequana.fasta import FastA
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab, pysam
+from sequana.tools import reverse_complement
 
 logger.setLevel("INFO")
 
@@ -79,7 +76,7 @@ class RiboDesigner(object):
         else:
             try:
                 self.outdir.mkdir()
-            except FileExistsError as err:
+            except FileExistsError as err:  # pragma: no cover
                 logger.error(f"Output directory {output_directory} exists. Use --force or set force=True")
                 sys.exit(1)
 
@@ -92,7 +89,11 @@ class RiboDesigner(object):
         self.clustered_probes_bed = self.outdir / "clustered_probes.bed"
         self.output_json = self.outdir / "ribodesigner.json"
 
-        self.json = {"max_n_probes": max_n_probes, "identity_step": identity_step, "feature": seq_type}
+        self.json = {
+            "max_n_probes": max_n_probes,
+            "identity_step": identity_step,
+            "feature": seq_type,
+        }
 
     def get_rna_pos_from_gff(self):
         """Convert a GFF file into a pandas DataFrame filtered according to the
@@ -103,14 +104,23 @@ class RiboDesigner(object):
             self.gff,
             sep="\t",
             comment="#",
-            names=["seqid", "source", "seq_type", "start", "end", "score", "strand", "phase", "attributes"],
+            names=[
+                "seqid",
+                "source",
+                "seq_type",
+                "start",
+                "end",
+                "score",
+                "strand",
+                "phase",
+                "attributes",
+            ],
         )
 
         filtered_gff = gff.query("seq_type == @self.seq_type")
 
         with pysam.Fastafile(self.fasta) as fas:
             with open(self.ribo_sequences_fasta, "w") as fas_out:
-
                 for row in filtered_gff.itertuples():
                     region = f"{row.seqid}:{row.start}-{row.end}"
                     seq_record = f">{region}\n{fas.fetch(region=region)}\n"
@@ -124,6 +134,49 @@ class RiboDesigner(object):
 
         filtered_gff.to_csv(self.filtered_gff)
 
+    def _get_probe_and_step_len_greedy(self, seq):
+        """Modified version of _get_probe_and_step_len"""
+        seq_len = len(seq.sequence)
+
+        # sequences below 92 base fail when scanning the parameter space.
+        # in such case, one probe or two overlapping probes should do it.
+
+        if seq_len < 50:
+            return 50, 15
+        elif seq_len < 100:
+            return 40, 10
+
+        probe_lens = range(60, 40, -1)
+        inter_probe_space = range(20, 10, -1)
+
+        for probe_len, inter_probe_space in product(probe_lens, inter_probe_space):
+            if ((seq_len + inter_probe_space) / (probe_len + inter_probe_space)).is_integer():
+                return probe_len, inter_probe_space
+
+        # 4% of sequence length are not found in the parameter space [60-40] x [10-20]
+        # Using 70-40 x 30-10 gives 0 fails for sequences up to 200,000 bases
+        probe_lens = range(70, 40, -1)
+        inter_probe_space = range(30, 10, -1)
+
+        for probe_len, inter_probe_space in product(probe_lens, inter_probe_space):
+            X = (seq_len + inter_probe_space) / (probe_len + inter_probe_space)
+            if X.is_integer():
+                return probe_len, inter_probe_space
+
+        # 34 of sequence length are not found in the parameter space [60-40] x [10-20]
+        # Using 80-40 x 35-10 gives 0 fails for sequences up to 200,000 bases
+        probe_lens = range(80, 40, -1)
+        inter_probe_space = range(35, 10, -1)
+
+        for probe_len, inter_probe_space in product(probe_lens, inter_probe_space):
+            X = (seq_len + inter_probe_space) / (probe_len + inter_probe_space)
+            if X.is_integer():
+                return probe_len, inter_probe_space
+
+        raise ValueError(
+            f"No correct probe length/inter probe space combination was found for {seq.name}"
+        )  # pragma: no cover
+
     def _get_probe_and_step_len(self, seq):
         """Calculates the probe_len and inter_probe_space for a ribosomal sequence.
 
@@ -141,9 +194,58 @@ class RiboDesigner(object):
             if ((seq_len + inter_probe_space) / (probe_len + inter_probe_space)).is_integer():
                 return probe_len, inter_probe_space
 
-        raise ValueError(f"No correct probe length/inter probe space combination was found for {seq.name}")
+        raise ValueError(
+            f"No correct probe length/inter probe space combination was found for {seq.name}"
+        )  # pragma: no cover
 
-    def _get_probes_df(self, seq, probe_len, step_len):
+    def _get_probe_and_step_len_simple(self, seq):
+        seq_len = len(seq.sequence)
+        if seq_len < 50:
+            return 50, 15
+        elif seq_len < 100:
+            return 40, 10
+
+        probe_len = 50
+        inter_probe_space = 15
+
+        # starts = arange(0, seq_len, probe_len+inter_probe_space)
+        return 50, 15
+
+    def _get_probe_and_step_len_spiral(self, seq):
+        # much slower than original and greedy but ensure that probes are closer to the
+        # expected value
+        seq_len = len(seq.sequence)
+        if seq_len < 50:
+            return 50, 15
+        elif seq_len < 100:
+            return 40, 10
+
+        def spiral(X, Y, x0, y0):
+            items = []
+            x = y = 0
+            dx = 0
+            dy = -1
+            for i in range(max(X, Y) ** 2):
+                if (-X / 2 - 1 < x <= X / 2) and (-Y / 2 - 1 < y <= Y / 2):
+                    items.append((x, y))
+                if x == y or (x < 0 and x == -y) or (x > 0 and x == 1 - y):
+                    dx, dy = -dy, dx
+                x, y = x + dx, y + dy
+            items = [(x + X / 2 + x0, y + Y / 2 + y0) for x, y in items]
+            return items
+
+        # set of points from 40 to 60 (40+21) and from 10 to 20 (10+11)
+        positions = spiral(40, 10, 40, 10)
+
+        for probe_len, inter_probe_space in positions:
+            if ((seq_len + inter_probe_space) / (probe_len + inter_probe_space)).is_integer():
+                return int(probe_len), int(inter_probe_space)
+
+        raise ValueError(
+            f"No correct probe length/inter probe space combination was found for {seq.name}"
+        )  # pragma: no cover
+
+    def _get_probes_df(self, seq, probe_len, step_len, mode="generic"):
         """Generate the Dataframe with probes information.
 
         Design probes to have end-to-end coverage on the + strand and fill the inter_probe_space present on the + strand with probes designed on the - strand.
@@ -158,7 +260,15 @@ class RiboDesigner(object):
         starts = [start for start in range(0, len(seq.sequence) - probe_len + 1, probe_len + step_len)]
         stops = [start + probe_len for start in starts]
 
-        df = pd.DataFrame({"name": seq.name, "start": starts, "stop": stops, "strand": "+", "score": 0})
+        df = pd.DataFrame(
+            {
+                "name": seq.name,
+                "start": starts,
+                "stop": stops,
+                "strand": "+",
+                "score": 0,
+            }
+        )
         df["sequence"] = [seq.sequence[row.start : row.stop] for row in df.itertuples()]
         df["seq_id"] = df["name"] + f"_+_" + df["start"].astype(str) + "_" + df["stop"].astype(str)
 
@@ -168,7 +278,19 @@ class RiboDesigner(object):
         rev_starts = [int((starts[i + 1] + starts[i]) / 2) for i in range(0, len(starts) - 1)]
         rev_stops = [start + probe_len for start in rev_starts]
 
-        df_rev = pd.DataFrame({"name": seq.name, "start": rev_starts, "stop": rev_stops, "strand": "-", "score": 0})
+        if mode == "simple":
+            rev_starts = [x for x in starts]
+            rev_stops = [start + probe_len for start in rev_starts]
+
+        df_rev = pd.DataFrame(
+            {
+                "name": seq.name,
+                "start": rev_starts,
+                "stop": rev_stops,
+                "strand": "-",
+                "score": 0,
+            }
+        )
         df_rev["sequence"] = [sequence[row.start : row.stop] for row in df_rev.itertuples()]
         df_rev["seq_id"] = df_rev["name"] + f"_-_" + df_rev["start"].astype(str) + "_" + df_rev["stop"].astype(str)
 
@@ -179,7 +301,7 @@ class RiboDesigner(object):
 
         return pd.concat([df, df_rev])
 
-    def get_all_probes(self):
+    def get_all_probes(self, method="original"):
         """Run all probe design and concatenate results in a single DataFrame."""
 
         probes_dfs = []
@@ -187,8 +309,20 @@ class RiboDesigner(object):
         with pysam.FastxFile(self.ribo_sequences_fasta) as fas:
             for seq in fas:
 
-                probe_len, step_len = self._get_probe_and_step_len(seq)
-                probes_dfs.append(self._get_probes_df(seq, probe_len, step_len))
+                if method == "greedy":
+                    probe_len, step_len = self._get_probe_and_step_len_greedy(seq)
+                    df = self._get_probes_df(seq, probe_len, step_len)
+                elif method == "original":
+                    probe_len, step_len = self._get_probe_and_step_len(seq)
+                    df = self._get_probes_df(seq, probe_len, step_len)
+                elif method == "spiral":
+                    probe_len, step_len = self._get_probe_and_step_len_spiral(seq)
+                    df = self._get_probes_df(seq, probe_len, step_len)
+                elif method == "simple":
+                    probe_len, step_len = self._get_probe_and_step_len_simple(seq)
+                    df = self._get_probes_df(seq, probe_len, step_len, mode="simple")
+
+                probes_dfs.append(df)
 
         self.probes_df = pd.concat(probes_dfs)
         self.probes_df["kept_after_clustering"] = True
@@ -229,7 +363,6 @@ class RiboDesigner(object):
         res_dict = {"seq_id_thres": [], "n_probes": []}
 
         for seq_id_thres in np.arange(0.8, 1, self.identity_step).round(3):
-
             tmp_fas = outdir / f"clustered_{seq_id_thres}.fas"
             cmd = f"cd-hit-est -i {self.probes_fasta} -o {tmp_fas} -c {seq_id_thres} -n {self.threads}"
             logger.debug(f"Clustering probes with command: {cmd} (log in '{log_file}').")
@@ -249,8 +382,17 @@ class RiboDesigner(object):
         # Dataframe with number of probes for each cdhit identity threshold
         pylab.clf()
         df = pd.DataFrame(res_dict)
+
+        import seaborn as sns  # local import to speed up imports
+
         p = sns.lineplot(data=df, x="seq_id_thres", y="n_probes", markers=["o"])
-        p.axhline(self.max_n_probes, alpha=0.8, linestyle="--", color="red", label="max number of probes requested")
+        p.axhline(
+            self.max_n_probes,
+            alpha=0.8,
+            linestyle="--",
+            color="red",
+            label="max number of probes requested",
+        )
         pylab.xlabel("Sequence identity", fontsize=16)
         pylab.ylabel("Number of probes", fontsize=16)
 
@@ -297,16 +439,30 @@ class RiboDesigner(object):
             sep="\t",
             index=False,
             header=None,
-            columns=["name", "start", "stop", "sequence", "score", "strand", "start", "stop", "bed_color"],
+            columns=[
+                "name",
+                "start",
+                "stop",
+                "sequence",
+                "score",
+                "strand",
+                "start",
+                "stop",
+                "bed_color",
+            ],
         )
 
     def export_to_json(self):
         with open(self.output_json, "w") as fout:
             json.dump(self.json, fout, indent=4, sort_keys=True)
 
-    def run(self):
-        self.get_rna_pos_from_gff()
-        self.get_all_probes()
+    def run(self, method="greedy"):
+        if self.gff:
+            self.get_rna_pos_from_gff()
+        else:
+            shutil.copy(self.fasta, self.ribo_sequences_fasta)
+
+        self.get_all_probes(method=method)
         self.export_to_fasta()
         self.export_to_csv_bed()
         self.export_to_json()
