@@ -10,27 +10,25 @@
 #  documentation: http://sequana.readthedocs.io
 #
 ##############################################################################
-import sys
 import subprocess
-from pathlib import Path
+import sys
 from itertools import combinations
-
-from jinja2 import Environment, PackageLoader
-import seaborn as sns
-import upsetplot as upset
-
-from sequana.lazy import pandas as pd
-from sequana.lazy import pylab
-from sequana.lazy import numpy as np
-from sequana.gff3 import GFF3
-from sequana.viz import Volcano
-from sequana.enrichment import PantherEnrichment
-from sequana.enrichment import KEGGPathwayEnrichment
-from sequana.featurecounts import FeatureCount
-
-from easydev import AttrDict, cmd_exists
+from pathlib import Path
 
 import colorlog
+import seaborn as sns
+import upsetplot as upset
+from easydev import AttrDict
+from jinja2 import Environment, PackageLoader
+from upsetplot.plotting import _process_data
+
+from sequana.enrichment import KEGGPathwayEnrichment, PantherEnrichment
+from sequana.featurecounts import FeatureCount
+from sequana.gff3 import GFF3
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
+from sequana.viz import Volcano
 
 logger = colorlog.getLogger(__name__)
 
@@ -38,13 +36,6 @@ logger = colorlog.getLogger(__name__)
 __all__ = ["RNADiffAnalysis", "RNADiffResults", "RNADiffTable", "RNADesign"]
 
 
-def strip(text):
-    try:
-        return text.strip()
-    except AttributeError:
-        return text
-
-
 class RNADesign:
     """Simple RNA design handler"""
 
@@ -53,14 +44,62 @@ class RNADesign:
         self.condition_col = condition_col
         # \s to strip the white spaces
         self.df = pd.read_csv(filename, sep=sep, engine="python", comment="#", dtype={"label": str})
-        if reference and reference not in self.conditions:
-            raise ValueError(
-                f"{reference} condition (for the reference) not found in the conditions of your design file"
-            )
         self.reference = reference
 
-    def _get_conditions(self):
+    def checker(self):
+        from sequana.utils.checker import Checker
 
+        c = Checker()
+        c.tryme(self._check_condition)
+        c.tryme(self._check_condition_col_name)
+        c.tryme(self._check_label_col_name)
+        return c.results
+
+    def validate(self):
+        checks = self.checker()
+        # Stop after first error
+        for check in checks:
+            if check["status"] == "Error":
+                sys.exit("\u274C " + check["msg"] + self.filename)
+
+    def _check_condition(self):
+
+        if self.condition_col not in self.df.columns:
+            return {"msg": f"Cannot check the conditions. Header is missing {self.condition_col}", "status": "Error"}
+
+        conds = sorted(self.df[self.condition_col].unique())
+        C = len(conds)
+        if C == 0:
+            return {"msg": f"Found no conditions", "status": "Error"}
+        elif C == 1:
+            return {"msg": f"Found only one condition {conds}", "status": "Error"}
+        else:
+
+            # checks whether a conditon has only 1 replicate. Forbidden by DeSeq2
+            for cond in conds:
+                if sum(self.df[self.condition_col] == cond) == 1:
+                    return {
+                        "msg": f"Found condition {cond} with only one replicate. Forbidden by DeSeq2",
+                        "status": "Error",
+                    }
+            if len(self.df) % C == 0:
+                return {"msg": f"Found {C} conditions and {len(self.df)} samples", "status": "Success"}
+            else:
+                return {"msg": f"Found {C} conditions but {len(self.df)} samples (uneven?)", "status": "Warning"}
+
+    def _check_label_col_name(self):
+        if "label" not in self.df.columns:
+            return {"msg": "Incorrect header. Expected 'label' but not found", "status": "Error"}
+        else:
+            return {"msg": "Found name 'label' in the Header", "status": "Success"}
+
+    def _check_condition_col_name(self):
+        if self.condition_col not in self.df.columns:
+            return {"msg": f"Incorrect header. Expected {self.condition_col} but not found", "status": "Error"}
+        else:
+            return {"msg": f"Found name '{self.condition_col}' in the Header", "status": "Success"}
+
+    def _get_conditions(self):
         try:
             return sorted(self.df[self.condition_col].unique())
         except KeyError:
@@ -96,7 +135,7 @@ class RNADiffAnalysis:
         be specified (not tested yet). Each name in this function should refer to column
         names in groups_tsv.
     :param comparisons: A list of tuples indicating comparisons to be made e.g A vs B would be [("A", "B")]
-    :param batch: None for no batch effect or name of a column in groups_tsv to add a batch effec.
+    :param batch: None for no batch effect or name of a column in groups_tsv to add a batch effect.
     :param keep_all_conditions: if user set comparisons, it means will only want
         to include some comparisons and therefore their conditions. Yet,
         sometimes, you may still want to keep all conditions in the diffential
@@ -130,7 +169,8 @@ class RNADiffAnalysis:
     """
 
     _template_file = "rnadiff_light_template.R"
-    _template_env = Environment(loader=PackageLoader("sequana", "resources/templates"))
+    _template_file_batch_vst = "rnadiff_batch_vst.R"
+    _template_env = Environment(loader=PackageLoader("sequana", "resources/scripts"))
     template = _template_env.get_template(_template_file)
 
     def __init__(
@@ -157,8 +197,8 @@ class RNADiffAnalysis:
         sep_design=r"\s*,\s*",
         minimum_mean_reads_per_gene=0,
         minimum_mean_reads_per_condition_per_gene=0,
+        model=None,
     ):
-
         # if set, we can filter genes that have low counts (on average)
         self.minimum_mean_reads_per_gene = minimum_mean_reads_per_gene
         self.minimum_mean_reads_per_condition_per_gene = minimum_mean_reads_per_condition_per_gene
@@ -167,10 +207,12 @@ class RNADiffAnalysis:
         self.outdir = Path(outdir)
         self.counts_dir = self.outdir / "counts"
         self.code_dir = self.outdir / "code"
+        self.images_dir = self.outdir / "images"
 
         self.outdir.mkdir(exist_ok=True)
         self.code_dir.mkdir(exist_ok=True)
         self.counts_dir.mkdir(exist_ok=True)
+        self.images_dir.mkdir(exist_ok=True)
 
         self.usr_counts = counts_file
 
@@ -178,6 +220,14 @@ class RNADiffAnalysis:
 
         # Read and check the design file. Filtering if comparisons is provided
         self.design = RNADesign(design_file, sep=sep_design, condition_col=condition, reference=reference)
+        for check in self.design.checker():
+            if check["status"] == "Error":
+                logger.error(f"Found an error while parsing the design file {design_file}:")
+                logger.error(f"{check['msg']}")
+                sys.exit(1)
+            elif check["status"] == "Warning":
+                logger.warning(check["msg"])
+
         self.comparisons = comparisons if comparisons else self.design.comparisons
 
         _conditions = {x for comp in self.comparisons for x in comp}
@@ -197,7 +247,6 @@ class RNADiffAnalysis:
 
         # the name of the condition in the design file
         self.condition = condition
-        self.check_condition()
 
         # Reads and check the count file
         self.counts = self.check_and_save_input_tables(sep_counts)
@@ -214,6 +263,11 @@ class RNADiffAnalysis:
         self.batch = batch
         self.model = f"~{batch + '+' + condition if batch else condition}"
 
+        # if user provides a model, reset the default one
+        if model:
+            self.model = model
+
+        logger.info(f"model: {self.model}")
         self.fit_type = fit_type
         self.beta_prior = "TRUE" if beta_prior else "FALSE"
         self.independent_filtering = "TRUE" if independent_filtering else "FALSE"
@@ -235,14 +289,15 @@ class RNADiffAnalysis:
             "independent_filtering",
             "cooks_cutoff",
             "code_dir",
+            "images_dir",
             "outdir",
             "counts_dir",
             "beta_prior",
             "threads",
         ):
-            try:
+            try:  # pragma: no cover
                 getattr(self, attr)
-            except AttributeError as err:
+            except AttributeError as err:  # pragma: no cover
                 logger.error(f"Attribute {attr} missing in the RNADiffAnalysis class. cannot go further")
                 raise Exception(err)
 
@@ -258,7 +313,6 @@ Design overview:\n\
         return info
 
     def check_and_save_input_tables(self, sep_counts):
-
         # input may be an existing rnadiff.csv file create with FeatureCount
         # class, or (if it fails) a feature count file (tabulated with
         # Chr/Start/Geneid columns)
@@ -271,8 +325,12 @@ Design overview:\n\
                 comment="#",
                 low_memory=False,
             )
-        except ValueError:
-            counts = FeatureCount(self.usr_counts).df
+        except ValueError:  # pragma: no cover
+            try:
+                counts = FeatureCount(self.usr_counts).df
+            except:
+                # could read any CSV file (useful with simulated data)
+                counts = pd.read_csv(self.usr_counts)
 
         Ncounts = len(counts)
         logger.info(f"Found {Ncounts} counts. ")
@@ -310,18 +368,6 @@ Design overview:\n\
 
         return counts
 
-    def check_condition(self):
-        # set condition of the statistical model
-
-        columns = ",".join(self.design.columns)
-        if self.condition not in columns:
-            logger.error(
-                f"""Your condition named '{condition}' is expected to
-be in the header of your design file but was not found. Candidates are:
-    {columns}"""
-            )
-            sys.exit(1)
-
     def check_comparisons(self):
         # let us check the consistenct of the design and comparisons
         valid_conditions = ",".join(set(self.design[self.condition].values))
@@ -379,11 +425,11 @@ or comparisons. possible values are {valid_conditions}"""
             ]
 
             data = f.read()
-            for msg in messages:
+            for msg in messages:  # pragma: no cover
                 if msg[0] in data:
                     logger.critical(msg[0] + msg[1])
 
-        logger.info("DGE analysis done.")
+        logger.info("DGE analysis done. Processing the results")
         results = RNADiffResults(
             self.outdir,
             condition=self.condition,
@@ -396,7 +442,15 @@ or comparisons. possible values are {valid_conditions}"""
 
 
 class RNADiffTable:
-    def __init__(self, path, alpha=0.05, log2_fc=0, sep=",", condition="condition", shrinkage=True):
+    def __init__(
+        self,
+        path,
+        alpha=0.05,
+        log2_fc=0,
+        sep=",",
+        condition="condition",
+        shrinkage=True,
+    ):
         """A representation of the results of a single rnadiff comparison
 
         Expect to find output of RNADiffAnalysis file named after condt1_vs_cond2_degs_DESeq2.csv
@@ -420,7 +474,8 @@ class RNADiffTable:
         self._log2_fc = log2_fc
 
         self.df = pd.read_csv(self.path, index_col=0, sep=sep)
-        self.df.padj[self.df.padj == 0] = 1e-50
+
+        self.df.loc[self.df.padj == 0, "padj"] = 1e-50
         self.condition = condition
 
         self.filt_df = self.filter()
@@ -458,7 +513,6 @@ class RNADiffTable:
         return filt_df
 
     def set_gene_lists(self):
-
         only_drgs_df = self.filt_df.dropna(how="all")
 
         self.gene_lists = {
@@ -468,7 +522,6 @@ class RNADiffTable:
         }
 
     def summary(self):
-
         return pd.DataFrame(
             {
                 "log2_fc": self._log2_fc,
@@ -507,16 +560,18 @@ class RNADiffTable:
             from plotly import express as px
 
             df = self.df.copy()
+            # ignore genes with undefined pvalues
+            df = df[~df.padj.isnull()]
 
             if annotations is not None:
                 try:
-                    df = pd.concat([df, annotations.annotation], axis=1)
-                except Exception as err:
+                    df = pd.concat([df, annotations], axis=1)
+                except Exception as err:  # pragma: no cover
                     logger.warning(f"Could not merge rnadiff table with annotation. Full error is: {err}")
             df["log_adj_pvalue"] = -pylab.log10(df.padj)
             df["significance"] = ["<{}".format(padj) if x else ">={}".format(padj) for x in df.padj < padj]
 
-            if hover_name is not None:
+            if hover_name is not None:  # pragma: no cover
                 if hover_name not in df.columns:
                     logger.warning(f"hover_name {hover_name} not in the GFF attributes. Switching to automatic choice")
                     hover_name = None
@@ -607,15 +662,19 @@ class RNADiffTable:
             bax.xlabel("fold change")
             bax.ylabel("log10 adjusted p-value")
 
-        m1 = abs(min(self.df[self.l2fc_name]))
-        m2 = max(self.df[self.l2fc_name])
+        # we set the limits by finding max and min fold change.
+        # Note, however, that we should ignore null pvalue
+        l2fc = self.df[~self.df.padj.isnull()][self.l2fc_name]
+        m1 = abs(min(l2fc))
+        m2 = max(l2fc)
 
         limit = max(m1, m2)
-        try:
+        try:  # pragma: no cover
             bax.set_xlim([-limit, limit])
         except Exception:
             bax.xlim([-limit, limit])
-        try:
+
+        try:  # pragma: no cover
             y1, _ = bax.get_ylim()
             ax1 = bax.axs[0].set_ylim([br2, y1[1] * 1.1])
         except Exception:
@@ -623,20 +682,14 @@ class RNADiffTable:
             bax.ylim([0, y2])
         bax.axhline(-np.log10(0.05), lw=2, ls="--", color="r", label="pvalue threshold (0.05)")
 
-    def plot_pvalue_hist(self, bins=60, fontsize=16, rotation=0):
-
-        pylab.hist(self.df.pvalue.dropna(), bins=bins, ec="k")
-        pylab.xlabel("raw p-value")
-        pylab.ylabel("Occurences")
-
     def plot_pvalue_hist(self, bins=60, fontsize=16, rotation=0):
         pylab.hist(self.df.pvalue.dropna(), bins=bins, ec="k")
         pylab.grid(True)
         pylab.xlabel("raw p-value", fontsize=fontsize)
         pylab.ylabel("Occurences", fontsize=fontsize)
         try:
-            pylab.tight_layout()
-        except Exception:
+            pylab.gcf().set_layout_engine("tight")
+        except Exception:  # pragma: no cover
             pass
 
     def plot_padj_hist(self, bins=60, fontsize=16):
@@ -645,8 +698,8 @@ class RNADiffTable:
         pylab.xlabel("Adjusted p-value", fontsize=fontsize)
         pylab.ylabel("Occurences", fontsize=fontsize)
         try:
-            pylab.tight_layout()
-        except Exception:
+            pylab.gcf().set_layout_engine("tight")
+        except Exception:  # pragma: no cover
             pass
 
 
@@ -689,6 +742,12 @@ class RNADiffResults:
         self.counts_vst = pd.read_csv(self.path / "counts" / "counts_vst_norm.csv", index_col=0, sep=",")
         self.counts_vst.sort_index(axis=1, inplace=True)
 
+        try:
+            self.counts_vst_batch = pd.read_csv(self.path / "counts" / "counts_vst_batch.csv", index_col=0, sep=",")
+            self.counts_vst_batch.sort_index(axis=1, inplace=True)
+        except:
+            self.counts_vst_batch = None
+
         self.dds_stats = pd.read_csv(self.path / "code" / "overall_dds.csv", index_col=0, sep=",")
         self.condition = condition
 
@@ -704,8 +763,15 @@ class RNADiffResults:
                 logger.warning("Since you provided a GFF file you must provide the feature and attribute to be used.")
             self.annotation = self.read_annot(gff)
         else:
-            self.annotation = pd.read_csv(self.path / "rnadiff.csv", index_col=0, header=[0, 1])
-            self.annotation = self.annotation["annotation"]
+
+            try:
+                annots = pd.read_csv(self.path / "rnadiff.csv", index_col=0, header=[0, 1])
+                self.annotation = annots.loc[:, "annotation"]
+            except Exception as err:
+                logger.warning(
+                    "annotation from input GFF or existing rnadiff.csv not available. No annotaion will be used."
+                )
+                self.annotation = None
 
         # some filtering attributes
         self._alpha = alpha
@@ -749,7 +815,6 @@ class RNADiffResults:
         self.df = pd.read_csv(filename, index_col=0, header=[0, 1])
 
     def import_tables(self):
-
         data = {
             compa.stem.replace("_degs_DESeq2", "").replace("-", "_"): RNADiffTable(
                 compa,
@@ -770,8 +835,8 @@ class RNADiffResults:
         :param gff: a input GFF filename or an existing instance of GFF3
         """
 
-        # if gff is already instanciate, we can just make a copy otherwise
-        # we read it indeed.
+        # if gff is already instanciated, we can just make a copy. Otherwise
+        # we read it.
         if not hasattr(gff, "df"):
             gff = GFF3(gff)
 
@@ -793,9 +858,6 @@ class RNADiffResults:
         # It may happen that a GFF has duplicated IDs ! For instance ecoli
         # has 20 duplicated ID that are part 1 and 2 of the same gene
         df = df[~df.index.duplicated(keep="last")]
-
-        df.columns = pd.MultiIndex.from_product([["annotation"], df.columns])
-
         return df
 
     def _get_total_df(self, filtered=False):
@@ -829,8 +891,10 @@ class RNADiffResults:
         )
         df.loc[:, ("statistics", "significative_comparisons")] = sign_compa
 
-        if self.annotation is not None and self.fc_attribute and self.fc_feature:
-            df = pd.concat([self.annotation, df], axis=1)
+        if self.annotation is not None:
+            annot = self.annotation.copy()
+            annot.columns = pd.MultiIndex.from_product([["annotation"], annot.columns])
+            df = pd.concat([annot, df], axis=1)
 
         return df
 
@@ -838,7 +902,6 @@ class RNADiffResults:
         return pd.concat(res.summary() for compa, res in self.comparisons.items())
 
     def report(self):
-
         template_file = "rnadiff_report.html"
         template_env = Environment(loader=PackageLoader("sequana", "resources/templates"))
         template = template_env.get_template(template_file)
@@ -847,7 +910,6 @@ class RNADiffResults:
             f.write(template.render({"table": self.summary().to_html(classes="table table-striped")}))
 
     def get_gene_lists(self, annot_col="index", Nmax=None, dropna=False):  # pragma: no cover
-
         gene_lists_dict = {}
 
         for compa in self.comparisons.keys():
@@ -855,7 +917,8 @@ class RNADiffResults:
             df = df.droplevel(0, axis=1)
 
             # Let us add the annotation columns
-            df = pd.concat([df, self.annotation.loc[df.index]], axis=1)
+            if self.annotation is not None:
+                df = pd.concat([df, self.annotation.loc[df.index]], axis=1)
 
             fc_filt = df["log2FoldChange"].abs() >= self._log2_fc
             fdr_filt = df["padj"] <= self._alpha
@@ -864,7 +927,7 @@ class RNADiffResults:
             df.reset_index(inplace=True)
 
             if annot_col not in df.columns:
-                logger.error(f"{annot_col} not found in input file. Use one of {df.columns}")
+                logger.error(f"attribute '{annot_col}' not found in input file. Use one of {df.columns}")
                 sys.exit(1)
 
             if Nmax:
@@ -930,10 +993,11 @@ class RNADiffResults:
         pylab.xlabel(xlabel)
         pylab.ylabel(ylabel)
 
-    def get_specific_commons(self, direction, compas=None, annot_col="index"):
+    # Probably not used anywhere.
+    def __get_specific_commons(self, direction, compas=None, annot_col="index"):  # pragma: no cover
         """Extract gene lists for all comparisons.
 
-        Genes are common (but specific, ie a gene appear only appears in the
+        Genes are in common (but specific, ie a gene  only appears in the
         combination considered) comparing all combinations of comparisons.
 
         :param direction: The regulation direction (up, down or all) of the gene
@@ -942,7 +1006,6 @@ class RNADiffResults:
             names can be found with self.comparisons.keys()).
 
         """
-
         common_specific_dict = {}
 
         total_gene_lists = self.get_gene_lists(annot_col=annot_col)
@@ -1010,7 +1073,7 @@ class RNADiffResults:
         pylab.title("Total read count per sample", fontsize=fontsize)
         pylab.xticks(rotation=rotation, ha="right", fontsize=xticks_fontsize)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except Exception:
             pass
 
@@ -1050,7 +1113,7 @@ class RNADiffResults:
         pylab.ylabel("Proportion of null counts (%)")
         pylab.grid(True, zorder=0)
         try:
-            pylab.tight_layout()
+            pylab.gcf().set_layout_engine("tight")
         except Exception:
             pass
 
@@ -1063,8 +1126,9 @@ class RNADiffResults:
         genes_to_remove=[],
         fontsize=10,
         adjust=True,
+        transform_method="none",  # already done if count_mode == 'vst' or 'vst_batch'
+        count_mode="vst",
     ):
-
         """
 
         .. plot::
@@ -1086,16 +1150,24 @@ class RNADiffResults:
         """
         from sequana.viz import PCA
 
-        # Get most variable genes (n=max_features)
-        top_features = self.counts_vst.var(axis=1).sort_values(ascending=False).index[:max_features]
+        if count_mode == "vst":
+            counts = self.counts_vst
+        elif count_mode == "vst_batch":
+            if self.counts_vst_batch is not None:
+                counts = self.counts_vst_batch
+        else:
+            logger.error("count_mode must be vst or vst_batch")
 
+        # let us use filter out genes to be ignored
+        top_features = counts.index
         if genes_to_remove:
             top_features = [x for x in top_features if x not in genes_to_remove]
+        counts_top_features = counts.loc[top_features, :]
 
-        counts_top_features = self.counts_vst.loc[top_features, :]
-
+        # We create the PCA instance here
         p = PCA(counts_top_features)
 
+        # and the plotting
         if plotly is True:
             assert n_components == 3
             variance = p.plot(
@@ -1103,6 +1175,7 @@ class RNADiffResults:
                 colors=colors,
                 show_plot=False,
                 max_features=max_features,
+                transform=transform_method,
             )
 
             from plotly import express as px
@@ -1135,12 +1208,12 @@ class RNADiffResults:
                 color="group_color",
                 color_discrete_sequence=colors,
                 labels={
-                    "PC1": "PC1 ({}%)".format(round(100 * variance[0], 2)),
-                    "PC2": "PC2 ({}%)".format(round(100 * variance[1], 2)),
-                    "PC3": "PC3 ({}%)".format(round(100 * variance[2], 2)),
+                    "PC1": "PC1 ({}%)".format(round(100 * variance[0], 1)),
+                    "PC2": "PC2 ({}%)".format(round(100 * variance[1], 1)),
+                    "PC3": "PC3 ({}%)".format(round(100 * variance[2], 1)),
                 },
                 height=800,
-                text="label",
+                hover_name="label",
             )
             return fig
         else:
@@ -1150,6 +1223,7 @@ class RNADiffResults:
                 max_features=max_features,
                 fontsize=fontsize,
                 adjust=adjust,
+                transform=transform_method,
             )
 
         return variance
@@ -1160,10 +1234,6 @@ class RNADiffResults:
         from sequana.viz.mds import MDS
 
         p = MDS(self.counts_vst)  # [self.sample_names])
-        # if colors is None:
-        #    colors = {}
-        #    for sample in self.sample_names:
-        #        colors[sample] = self.colors[self.get_cond_from_sample(sample)]
         p.plot(n_components=n_components, colors=self.design_df.group_color, clf=clf)
 
     def plot_isomap(self, n_components=2, colors=None):
@@ -1172,10 +1242,6 @@ class RNADiffResults:
         from sequana.viz.isomap import Isomap
 
         p = Isomap(self.counts_vst)
-        # if colors is None:
-        #    colors = {}
-        #    for sample in self.sample_names:
-        #        colors[sample] = self.colors[self.get_cond_from_sample(sample)]
         p.plot(n_components=n_components, colors=self.design_df.group_color)
 
     def plot_density(self):
@@ -1191,6 +1257,46 @@ class RNADiffResults:
             ylabel="Density",
         )
 
+    def plot_most_expressed_features(self, N=20):
+        pylab.clf()
+
+        # we will normalise to get pourcentage
+        S = self.counts_raw.sum(axis=0)
+
+        # let us make a copy
+        dd = self.counts_raw.copy()
+        dd = dd.divide(S) * 100  # percentage
+
+        # average of each genes to ordered them by expression
+        ordered_genes = dd.mean(axis=1).sort_values(ascending=False).index
+        subdf = dd.loc[ordered_genes[0:N]]
+
+        conditions = sorted(self.design_df.condition.unique())
+        for condition in conditions:
+            for (
+                i,
+                sample,
+            ) in enumerate(self.design_df.query("condition == @condition").index):
+                if i == 0:
+                    pylab.plot(
+                        subdf[sample],
+                        color=self.design_df.loc[sample].group_color,
+                        label=condition,
+                    )
+                else:
+                    pylab.plot(subdf[sample], color=self.design_df.loc[sample].group_color)
+
+        pylab.legend()
+
+        self._format_plot(title="", xlabel="Most expressed genes", ylabel="Percentage (%)")
+
+        pylab.xticks(range(0, len(subdf)), subdf.index, rotation=90)
+        try:
+            pylab.gcf().set_layout_engine("tight")
+        except:
+            pass
+        return subdf
+
     def plot_feature_most_present(self, fontsize=None, xticks_fontsize=None):
         """"""
         if fontsize is None:
@@ -1201,7 +1307,6 @@ class RNADiffResults:
         df = []
 
         for x, y in self.counts_raw.idxmax().items():
-
             most_exp_gene_count = self.counts_raw.stack().loc[y, x]
             total_sample_count = self.counts_raw.sum().loc[x]
 
@@ -1253,34 +1358,35 @@ class RNADiffResults:
 
         pylab.sca(ax)
 
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
 
+    # for back compatibility, we stick to transform_method = log
+    # max_features = 5000, count_mode = count_norm.
     def plot_dendogram(
-        self,
-        max_features=5000,
-        transform_method="log",
-        method="ward",
-        metric="euclidean",
+        self, max_features=5000, transform_method="log", method="ward", metric="euclidean", count_mode="norm"
     ):
         # for info about metric and methods: https://tinyurl.com/yyhk9cl8
+        from sequana.viz import clusterisation, dendogram
 
-        assert transform_method in ["log", "anscombe", None]
-        # first we take the normalised data
-        from sequana.viz import clusterisation
-        from sequana.viz import dendogram
-
-        cluster = clusterisation.Cluster(self.counts_norm)
-        # cluster = clusterisation.Cluster(self.df[self.sample_names])
-        if transform_method is not None:
-            data = cluster.scale_data(transform_method=transform_method, max_features=max_features)
-            df = pd.DataFrame(data[0])
-            df.index = data[1]
-            df.columns = self.counts_norm.columns
+        if count_mode == "norm":
+            cluster = clusterisation.Cluster(self.counts_norm)
+        elif count_mode == "vst":
+            cluster = clusterisation.Cluster(self.counts_vst)
+        elif count_mode == "vst_batch":
+            cluster = clusterisation.Cluster(self.counts_vst_batch)
+        elif count_mode == "raw":
+            cluster = clusterisation.Cluster(self.counts_raw)
         else:
-            df = pd.DataFrame(self.counts_norm)
-            # df.index = data[1]
-            df.columns = self.counts_norm.columns
+            raise ValueError(f"counts_mode is incorrect {count_mode}")
 
+        # scaling
+        data = cluster.scale_data(transform_method=transform_method)
+
+        # slect the best features only
+        tokeep = data.std(axis=1).sort_values(ascending=False).index[0:max_features]
+        df = pd.DataFrame(data.loc[tokeep])
+
+        # actual computation
         d = dendogram.Dendogram(
             df.T,
             metric=metric,
@@ -1302,7 +1408,6 @@ class RNADiffResults:
         xticks_fontsize=None,
         **kwargs,
     ):
-
         import seaborn as sbn
 
         if fontsize is None:
@@ -1314,7 +1419,7 @@ class RNADiffResults:
             data=self.counts_raw.clip(1),
             linewidth=linewidth,
             fliersize=fliersize,
-            palette=self.design_df.group_color,
+            palette=[self.design_df.group_color.loc[x] for x in self.counts_raw.columns],
             **kwargs,
         )
         pos, labs = pylab.xticks()
@@ -1322,7 +1427,7 @@ class RNADiffResults:
         ax.set_ylabel("Counts (raw) in log10 scale")
         ax.set_yscale("log")
         self._format_plot(ylabel="Raw count distribution", fontsize=xticks_fontsize)
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
 
     def plot_boxplot_normeddata(
         self,
@@ -1333,7 +1438,6 @@ class RNADiffResults:
         xticks_fontsize=None,
         **kwargs,
     ):
-
         import seaborn as sbn
 
         if fontsize is None:
@@ -1345,17 +1449,16 @@ class RNADiffResults:
             data=self.counts_norm.clip(1),
             linewidth=linewidth,
             fliersize=fliersize,
-            palette=self.design_df.group_color,
+            palette=[self.design_df.group_color.loc[x] for x in self.counts_norm.columns],
             **kwargs,
         )
         pos, labs = pylab.xticks()
         pylab.xticks(pos, labs, rotation=rotation)
         ax.set(yscale="log")
         self._format_plot(ylabel="Normalised count distribution")
-        pylab.tight_layout()
+        pylab.gcf().set_layout_engine("tight")
 
     def plot_dispersion(self):
-
         pylab.plot(
             self.dds_stats.baseMean,
             self.dds_stats.dispGeneEst,
@@ -1418,7 +1521,6 @@ class RNADiffResults:
         figsize=(10, 15),
         annotation_column=None,
     ):
-
         assert comp in self.comparisons.keys()
         from sequana.viz import heatmap
 
@@ -1429,7 +1531,7 @@ class RNADiffResults:
         logger.info(f"Using {len(data)} DGE genes")
 
         # replace the indices with the proper annotation if required.
-        if annotation_column:
+        if self.annotation and annotation_column:
             data = self._replace_index_with_annotation(data, annotation_column)
             counts.index = data.index
 
@@ -1442,8 +1544,13 @@ class RNADiffResults:
 
         return ax
 
-    def plot_upset(self, force=False):
-        """Plot the upset plot (alternative to venn diagram)."""
+    def plot_upset(self, force=False, max_subsets=20):
+        """Plot the upset plot (alternative to venn diagram).
+
+
+        with many comparisons, plots may be quite large. We can reduce the width
+        by ignoring the small subsets. We fix the max number of subsets to 20 for now.
+        """
 
         if len(self.comparisons) > 6 and not force:
             logger.warning("Upset plots are not computed for more than 6 comparisons.")
@@ -1463,4 +1570,28 @@ class RNADiffResults:
         # From a dataframe of booleans, get data structure needed for upset
         # ie a dictionnary with comparisons as keys and list of DEG as values.
         data = df.apply(lambda x: list(x.index[x])).to_dict()
-        upset.UpSet(upset.from_contents(data), subset_size="count", sort_by="cardinality").plot()
+
+        # let us figure out how many subsets we will have
+        updata = _process_data(
+            upset.from_contents(data),
+            sort_by="cardinality",
+            subset_size="count",
+            sum_over=None,
+            sort_categories_by="cardinality",
+        )
+        subsets = updata[2]
+
+        if len(subsets) > max_subsets:
+            min_subset_size = updata[2].values[max_subsets]
+        else:
+            min_subset_size = None
+
+        # now let us do the plotting
+        upset.UpSet(
+            upset.from_contents(data),
+            subset_size="count",
+            sort_by="cardinality",
+            totals_plot_elements=4,
+            intersection_plot_elements=len(data),
+            min_subset_size=min_subset_size,
+        ).plot()
