@@ -20,9 +20,9 @@
 
 """
 from bisect import bisect_left, insort
-import numpy as np
 
 import colorlog
+import numpy as np
 
 logger = colorlog.getLogger(__name__)
 
@@ -50,7 +50,7 @@ class RunningMedian:
     as proposed in https://gist.github.com/f0k/2f8402e4dfb6974bfcf1 and was
     adapted to our needs included object oriented implementation.
 
-    .. note:: a circular running median is implemented in :class:`sequana.bedtools.GenomeCov`
+    .. note:: a circular running median is implemented in :class:`sequana.bedtools.SequanaCoverage`
 
     ::
 
@@ -151,7 +151,6 @@ class RunningMedian:
         return self.run()
 
     def run(self):
-
         # initialise with first W values and sort the values
         lc = self.container(self.data[: self.W])
         lc.sort()  #
