@@ -11,12 +11,11 @@
 #
 ##############################################################################
 
+import colorlog
 import pandas as pd
 
 from sequana.gff3 import GFF3
 
-import colorlog
-
 logger = colorlog.getLogger(__name__)
 
 
@@ -44,7 +43,6 @@ class Salmon:
         # genes2trs is a dict with one gene sas key and a list of transcripts
 
     def get_feature_counts(self, feature=None, attribute=None):
-
         if self.df.Name.iloc[0].startswith("transcript:"):
             logger.info("salmon results start with transcript: tag. Eukaryotes mode")
             logger.info("Identifying the mapping transcript vs genes")
@@ -56,7 +54,6 @@ class Salmon:
         return results
 
     def get_feature_counts_eukaryotes(self, feature=None, attribute=None):
-
         if feature is None:
             feature = "gene"
 
@@ -99,10 +96,6 @@ class Salmon:
         strands = dd["strand"].values
         seqids = dd["seqid"].values
 
-        from easydev import Progress
-
-        pb = Progress(len(counts_on_genes))
-
         S = 0
 
         logger.info("Grouping")
@@ -110,7 +103,7 @@ class Salmon:
         efflength_null = df.groupby("Gene").apply(lambda group: group["EffectiveLength"].mean())
 
         groups = df.groupby("Gene")
-        for i, name in enumerate(counts_on_genes.index):
+        for i, name in tqdm.tqdm(enumerate(counts_on_genes.index)):
             # Since we use ID, there should be only one hit. we select the first
             # one to convert to a Series
 
@@ -137,12 +130,11 @@ class Salmon:
                 results += f"\n{name}\t{seqid}\t{start}\t{stop}\t{strand}\t{length}\t{NumReads}"
             else:
                 pass
-            pb.animate(i)
         return results
         """
 
 In [179]: genes2trs['gene:ENSMUSG00000000028']
-Out[179]: 
+Out[179]:
 ['transcript:ENSMUST00000000028',
  'transcript:ENSMUST00000096990',
  'transcript:ENSMUST00000115585']
@@ -229,7 +221,7 @@ star:
 
             if abs(length - length2) > 5:
                 logger.warning(f"GFF and salmon length for for {name} are quite different: {length} and {length2}")
-                #raise ValueError("length in gff and quant not the same")
+                # raise ValueError("length in gff and quant not the same")
             NumReads = int(self.df.query("Name==@name")["NumReads"].values[0])
             if name.startswith("gene"):
                 results += f"\n{name}\t{seqid}\t{starts}\t{stops}\t{strands}\t{length}\t{NumReads}"
