@@ -11,9 +11,9 @@
 ##############################################################################
 import click
 import colorlog
+import rich_click as click
 
-from .utils import CONTEXT_SETTINGS, common_logger
-
+from sequana.scripts.utils import CONTEXT_SETTINGS, common_logger
 
 logger = colorlog.getLogger(__name__)
 
