@@ -11,17 +11,16 @@
 ##############################################################################
 import os
 import sys
+from pathlib import Path
 
-import click
 import colorlog
+import rich_click as click
 
 from sequana.modules_report import ModulePantherEnrichment
 from sequana.rnadiff import RNADiffResults
+from sequana.scripts.utils import CONTEXT_SETTINGS, OptionEatAll, common_logger
 from sequana.utils import config
 
-from .utils import CONTEXT_SETTINGS, common_logger, OptionEatAll
-
-
 logger = colorlog.getLogger(__name__)
 
 
@@ -30,7 +29,7 @@ logger = colorlog.getLogger(__name__)
 # we should have corresponding option that starts with the module's name
 # This can also takes as input various types of data (e.g. FastA)
 @click.command(context_settings=CONTEXT_SETTINGS)
-@click.argument("name", type=click.Path(exists=True), nargs=1)
+@click.argument("rnadiff_directory", type=click.Path(exists=True, file_okay=False, dir_okay=True), nargs=1)
 @click.option(
     "--annotation-attribute",
     type=click.STRING,
@@ -81,6 +80,7 @@ logger = colorlog.getLogger(__name__)
 )
 @click.option(
     "--ontologies",
+    type=click.STRING,
     default=("MF", "BP", "CC"),
     help="""Provide the ontologies to be included in the analysis and HTML report.
 Valid choices are: from MF, BP, CC, SLIM_MF, SLIM_BP, SLIM_CC, PROTEIN,
@@ -96,6 +96,12 @@ PANTHER_PATHWAY, REACTOME_PATHWAY""",
     help="""Max number of enriched go terms to show in the plots (most
 enriched). All enriched GO terms are stored in tables""",
 )
+@click.option(
+    "--condition",
+    type=click.STRING,
+    default="condition",
+    help="""The name of the column used in the design file to define groups.""",
+)
 @click.option("--output-directory", show_default=True, default="enrichment_panther")
 @common_logger
 def enrichment_panther(**kwargs):
@@ -107,15 +113,15 @@ def enrichment_panther(**kwargs):
     Example for the enrichment module:
 
         sequana enrichment-panther rnadiff.csv --panther-taxon 10090
-            --log2-foldchange-cutoff 2 
+            --log2-foldchange-cutoff 2
 
         sequana enrichment rnadiff/rnadiff.csv
             --panther-taxon 189518 \
-            --log2-foldchange-cutoff 2 
+            --log2-foldchange-cutoff 2
             --ontologies MF SLIM_MF
 
     \b
-    Valid ontologies are: MF, BP, CC, SLIM_MF, SLIM_BP, SLIM_CC, 
+    Valid ontologies are: MF, BP, CC, SLIM_MF, SLIM_BP, SLIM_CC,
     PROTEIN, "PANTHER_PATHWAY", "REACTOME_PATHWAY"
 
 
@@ -154,9 +160,8 @@ def enrichment_panther(**kwargs):
         "plot_compute_levels": kwargs["compute_levels"],
     }
 
-    logger.info(f"Reading RNAdiff results from {kwargs['name']}")
-    dirpath = os.path.dirname(os.path.abspath(kwargs["name"]))
-    rnadiff = RNADiffResults(dirpath, index_col=0, header=[0, 1])
+    logger.info(f"Reading RNAdiff results from {kwargs['rnadiff_directory']}")
+    rnadiff = RNADiffResults(kwargs["rnadiff_directory"], condition=kwargs["condition"])
 
     # now that we have loaded all results from a rnadiff analysis, let us
     # perform the enrichment for each comparison found in the file
@@ -184,3 +189,9 @@ def enrichment_panther(**kwargs):
             command=" ".join(["sequana"] + sys.argv[1:]),
             ontologies=ontologies,
         )
+
+    p = Path(f"{output_directory}/.sequana")
+    p.mkdir(exist_ok=True)
+    with open(p / "info.txt", "w") as fout:
+        command = " ".join(["sequana"] + sys.argv[1:])
+        fout.write(command)
