@@ -9,13 +9,11 @@
 #  documentation: http://sequana.readthedocs.io
 #
 ##############################################################################
-import click
 import colorlog
+import rich_click as click
 
 from sequana.gtf_fixer import GTFFixer
-
-from .utils import CONTEXT_SETTINGS
-
+from sequana.scripts.utils import CONTEXT_SETTINGS
 
 logger = colorlog.getLogger(__name__)
 
@@ -26,6 +24,5 @@ logger = colorlog.getLogger(__name__)
 def gtf_fixer(**kwargs):
     """Reads GTF and fix known issues (exon and genes uniqueness)"""
     gtf = GTFFixer(kwargs["input"])
-    res = gtf.fix_exons_uniqueness(kwargs["output"])
-    # res = gtf.fix_exons_uniqueness(kwargs['output'])
+    res = gtf.fix(kwargs["output"])
     print(res)
