@@ -9,30 +9,29 @@
 #  documentation: http://sequana.readthedocs.io
 #
 ##############################################################################
-import sys
 import pathlib
-
-import click
-import colorlog
 import shutil
+import sys
+
+import colorlog
+import rich_click as click
 
 from sequana.ribodesigner import RiboDesigner
 from sequana.scripts.common import teardown
-
-from .utils import CONTEXT_SETTINGS
-
+from sequana.scripts.utils import CONTEXT_SETTINGS
 
 logger = colorlog.getLogger(__name__)
 
 
-
-
 # =====================================================================================
 # Ribodepletion custom probes designer
 # =====================================================================================
 @click.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("fasta", type=click.Path(exists=True))
-@click.argument("gff", type=click.Path(exists=True))
+@click.argument("gff", type=click.Path(exists=True), default=None, required=False)
+@click.option(
+    "--method", type=click.Choice(["original", "greedy", "spiral", "simple"]), default="original", required=False
+)
 @click.option("--output-directory", show_default=True, default="out_ribodesigner", type=click.Path(exists=False))
 @click.option(
     "--seq-type", default="rRNA", show_default=True, help="The annotation type (column 3 in gff) to target for probes."
@@ -48,7 +47,7 @@ logger = colorlog.getLogger(__name__)
     default=0.01,
     show_default=True,
     type=click.FLOAT,
-    help="The number of threads to use for cd-hit-est.",
+    help="The identity parameters used by cd-hit-est.",
 )
 @click.option("--output-image", default=None)
 @click.option(
@@ -70,11 +69,10 @@ def ribodesigner(**kwargs):
         logger.error("cd-hit-est not found in PATH.")
         sys.exit(1)
 
-    RiboDesigner(**kwargs).run()
+    RiboDesigner(**kwargs).run(method=kwargs["method"])
     if kwargs["output_image"]:
         from pylab import savefig
 
         savefig("/".join([kwargs["output_directory"], kwargs["output_image"]]))
 
-
     teardown(kwargs["output_directory"])
