@@ -9,14 +9,12 @@
 #  documentation: http://sequana.readthedocs.io
 #
 ##############################################################################
-import click
 import colorlog
+import rich_click as click
 from pylab import savefig
 
 from sequana.compare import RNADiffCompare
-
-from .utils import CONTEXT_SETTINGS, common_logger
-
+from sequana.scripts.utils import CONTEXT_SETTINGS, common_logger
 
 logger = colorlog.getLogger(__name__)
 
