@@ -9,20 +9,19 @@
 #  documentation: http://sequana.readthedocs.io
 #
 ##############################################################################
-import click
 import colorlog
+import rich_click as click
 
 from sequana.iem import IEM
-
-from .utils import CONTEXT_SETTINGS
-
+from sequana.scripts.utils import CONTEXT_SETTINGS
 
 logger = colorlog.getLogger(__name__)
 
 
 @click.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("name", type=click.STRING)
-@click.option("--check", is_flag=True)
+@click.option("--check", is_flag=True, help="")
+@click.option("--full-check", is_flag=True)
 @click.option("--extract-adapters", is_flag=True)
 @click.option("--quick-fix", is_flag=True)
 @click.option("--output", default=None)
@@ -33,14 +32,35 @@ def samplesheet(**kwargs):
         iem = IEM(name)
         iem.validate()
         logger.info("SampleSheet looks correct")
+    elif kwargs["full_check"]:
+        iem = IEM(name)
+
+        try:
+            iem.validate()
+        except SystemExit:
+            pass
+
+        checks = iem.checker()
+        for check in checks:
+            if check["status"] == "Error":
+                print(f"\u274C {check['status']}, {check['msg']}")
+
+        for check in checks:
+            if check["status"] == "Warning":
+                print(f"\u26A0 {check['status']}, {check['msg']}")
+
+        for check in checks:
+            if check["status"] == "Success":
+                print(f"\u2714 {check['status']}, {check['msg']}")
+
     elif kwargs["extract_adapters"]:
         iem = IEM(name)
         iem.to_fasta()
     elif kwargs["quick_fix"]:
-        iem = IEM(name, tryme=True)
+        iem = IEM(name)
         if kwargs["output"]:
             filename = kwargs["output"]
-        else: #pragma: no cover
+        else:  # pragma: no cover
             filename = name + ".fixed"
         logger.info("Saving fixed version in {}".format(filename))
         iem.quick_fix(output_filename=filename)
