@@ -14,15 +14,13 @@ import string
 import subprocess
 from collections import Counter, deque
 
-from sequana.fasta import FastA
-from sequana.lazy import pandas as pd
-from sequana.lazy import numpy as np
-from sequana.lazy import pylab
-
-from easydev import do_profile
-
 import colorlog
 
+from sequana.fasta import FastA
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pylab
+
 logger = colorlog.getLogger(__name__)
 
 
@@ -183,7 +181,6 @@ class DNA(Sequence):
         codons_start=["ATG"],
         codons_start_rev=["CAT"],
     ):
-
         super(DNA, self).__init__(sequence, complement_in=b"ACGT", complement_out=b"TGCA", letters="ACGTN")
 
         self._window = None
@@ -264,7 +261,6 @@ class DNA(Sequence):
                 cumul[self._dict_nuc[nuc]][j] += 1
         self._cumul = cumul
 
-    # @do_profile()
     def _compute_skews(self):
         ### initialisation =  Calculating GC skew and AT skew for first window
         self._init_sliding_window()
@@ -295,7 +291,7 @@ class DNA(Sequence):
 
             i += 1
 
-            if i % 500000 == 0: #pragma: no cover
+            if i % 500000 == 0:  # pragma: no cover
                 logger.info("%d / %d" % (i, self.__len__()))
             # if in and out are the same : do nothing, append same result
             if out_nuc != in_nuc:
@@ -354,7 +350,7 @@ class DNA(Sequence):
         self._ignored_nuc = 1.0 - GC_content_total - AT_content_total
 
     def _get_AT_skew(self):
-        if self._AT_skew_slide is None: #pragma: no cover
+        if self._AT_skew_slide is None:  # pragma: no cover
             raise AttributeError("Please set a valid window to compute skew")
         else:
             return self._AT_skew_slide
@@ -362,19 +358,19 @@ class DNA(Sequence):
     AT_skew = property(_get_AT_skew)
 
     def _get_GC_skew(self):
-        if self._GC_skew_slide is None: #pragma: no cover
+        if self._GC_skew_slide is None:  # pragma: no cover
             raise AttributeError("Please set a valid window to compute skew")
         else:
             return self._GC_skew_slide
 
     GC_skew = property(_get_GC_skew)
 
-    def _create_template_fft(self, M=1000): #pragma: no cover
+    def _create_template_fft(self, M=1000):  # pragma: no cover
         M_3 = int(M / 3)
         W = [-0.5] * M_3 + list(np.linspace(-0.5, 0.5, M - 2 * M_3)) + [0.5] * M_3
         return list(W * np.hanning(M))
 
-    def _myfft_gc_skew(self, M): #pragma: no cover
+    def _myfft_gc_skew(self, M):  # pragma: no cover
         """
         x : GC_skew vector (list)
         param N: length of the GC skew vector
@@ -399,7 +395,7 @@ class DNA(Sequence):
         self._c_fft = c * 2.0 / N
 
     def plot_all_skews(self, figsize=(10, 12), fontsize=16, alpha=0.5):
-        if self._window is None: #pragma: no cover
+        if self._window is None:  # pragma: no cover
             raise AttributeError("Please set a valid window to compute skew")
 
         # create figure
@@ -490,7 +486,14 @@ class DNA(Sequence):
                     len_ORF = d_vars["end_f"][j] - d_vars["begin_f"][j]
                     len_CDS = d_vars["end_f"][j] - d_vars["pos_ATG_f"][j]
                     self._ORF_pos.append(
-                        [d_vars["begin_f"][j], d_vars["end_f"][j], frame + 1, d_vars["pos_ATG_f"][j], len_ORF, len_CDS]
+                        [
+                            d_vars["begin_f"][j],
+                            d_vars["end_f"][j],
+                            frame + 1,
+                            d_vars["pos_ATG_f"][j],
+                            len_ORF,
+                            len_CDS,
+                        ]
                     )
                 d_vars["begin_f"][j] = i + 1
                 d_vars["pos_ATG_f"][j] = np.nan
@@ -563,7 +566,14 @@ class DNA(Sequence):
 
         # convert result to dataframe
         self._ORF_pos = pd.DataFrame(self._ORF_pos)
-        self._ORF_pos.columns = ["begin_pos", "end_pos", "frame", "pos_ATG", "len_ORF", "len_CDS"]
+        self._ORF_pos.columns = [
+            "begin_pos",
+            "end_pos",
+            "frame",
+            "pos_ATG",
+            "len_ORF",
+            "len_CDS",
+        ]
 
     def _get_ORF_pos(self):
         if self._ORF_pos is None:
@@ -619,8 +629,18 @@ class DNA(Sequence):
         n_CDS = self._ORF_pos["len_CDS"].dropna().shape[0]
 
         # plot for all ORF and CDS
-        pylab.hist(self._ORF_pos["len_ORF"].dropna(), alpha=alpha, label="ORF, N = " + str(n_ORF), bins=bins)
-        pylab.hist(self._ORF_pos["len_CDS"].dropna(), alpha=alpha, label="CDS, N = " + str(n_CDS), bins=bins)
+        pylab.hist(
+            self._ORF_pos["len_ORF"].dropna(),
+            alpha=alpha,
+            label="ORF, N = " + str(n_ORF),
+            bins=bins,
+        )
+        pylab.hist(
+            self._ORF_pos["len_CDS"].dropna(),
+            alpha=alpha,
+            label="CDS, N = " + str(n_CDS),
+            bins=bins,
+        )
         pylab.xlabel(xlabel)
         pylab.ylabel(ylabel)
         pylab.legend()
@@ -642,10 +662,18 @@ class DNA(Sequence):
             nb_res_CDS.append(self._ORF_pos[self._ORF_pos["frame"] == fr]["len_CDS"].dropna().shape[0])
 
         pylab.bar(
-            np.array(frames) - (bar_width / 2), nb_res_ORF, bar_width, alpha=alpha, label="ORF N = %d" % sum(nb_res_ORF)
+            np.array(frames) - (bar_width / 2),
+            nb_res_ORF,
+            bar_width,
+            alpha=alpha,
+            label="ORF N = %d" % sum(nb_res_ORF),
         )
         pylab.bar(
-            np.array(frames) + (bar_width / 2), nb_res_CDS, bar_width, alpha=alpha, label="CDS N = %d" % sum(nb_res_CDS)
+            np.array(frames) + (bar_width / 2),
+            nb_res_CDS,
+            bar_width,
+            alpha=alpha,
+            label="CDS N = %d" % sum(nb_res_CDS),
         )
         pylab.xlabel(xlabel)
         pylab.ylabel(ylabel)
