@@ -11,17 +11,16 @@
 #
 ##############################################################################
 """Sniffer"""
-from sequana.bamtools import is_bam, is_sam, is_cram
-from sequana.fastq import is_fastq
-from sequana.fasta import is_fasta
-
 import colorlog
 
+from sequana.bamtools import is_bam, is_cram, is_sam
+from sequana.fasta import is_fasta
+from sequana.fastq import is_fastq
+
 logger = colorlog.getLogger(__name__)
 
 
 def sniffer(filename):
-
     try:
         if is_sam(filename):
             return "SAM"
