@@ -12,17 +12,17 @@
 #
 ##############################################################################
 """ Tools to launch snpEff."""
-import re
-import sys
 import os
+import re
 import shutil
 import subprocess as sp
+import sys
 
-from sequana.resources import snpeff
-from sequana import sequana_data
-from sequana import FastA
 import colorlog
 
+from sequana import FastA, sequana_data
+from sequana.resources import snpeff
+
 logger = colorlog.getLogger(__name__)
 
 
@@ -48,8 +48,14 @@ class SnpEff(object):
     snpeff_datadir).
     """
 
-    def __init__(self, annotation, log=None, snpeff_datadir="data", fastafile=None, build_options=""):
-
+    def __init__(
+        self,
+        annotation,
+        log=None,
+        snpeff_datadir="data",
+        fastafile=None,
+        build_options="",
+    ):
         """.. rubric:: Constructor
 
         :param annotation: annotation reference.
@@ -150,7 +156,7 @@ class SnpEff(object):
         rc = snp_build.returncode
 
         if rc != 0:  # pragma: no cover
-            logger.error("snpEff build return a non-zero code")
+            logger.error(f"snpEff build return a non-zero code. See {self.log_file} for details")
             sys.exit(rc)
 
     def _add_db_in_config(self):
