@@ -10,19 +10,24 @@
 #  documentation: http://sequana.readthedocs.io
 #
 ##############################################################################
+import ftplib
+import gzip
 import os
 import re
+import shutil
+import tarfile
+import tempfile
 from collections import Counter
 from functools import wraps
+from pathlib import Path
+
+import colorlog
+from tqdm import tqdm
 
 from sequana import sequana_config_path
 from sequana.lazy import pandas as pd
-from sequana.utils.singleton import Singleton
 from sequana.misc import wget
-
-from easydev import TempFile
-
-import colorlog
+from sequana.utils.singleton import Singleton
 
 logger = colorlog.getLogger(__name__)
 
@@ -49,17 +54,18 @@ class NCBITaxonomy:
         if os.path.exists(nodes):
             self.df_nodes = pd.read_csv(nodes, sep="|", header=None)
         else:
-            with TempFile() as fout_nodes:
+            with tempfile.TemporaryFile() as fout_nodes:
                 logger.info("Loading nodes.dmp from an URL {}".format(nodes))
                 wget(nodes, fout_nodes.name)
                 self.df_nodes = pd.read_csv(fout_nodes.name, sep="|", header=None)
+
         for i, _type in enumerate(self.df_nodes.dtypes):
             if _type == "O":
                 self.df_nodes[i] = self.df_nodes[i].str.strip("\t")
         """
         tax_id                  -- node id in GenBank taxonomy database
         parent tax_id               -- parent node id in GenBank taxonomy database
-        rank                    -- rank of this node (superkingdom, kingdom, ...) 
+        rank                    -- rank of this node (superkingdom, kingdom, ...)
         embl code               -- locus-name prefix; not unique
         division id             -- see division.dmp file
         inherited div flag  (1 or 0)        -- 1 if node inherits division from parent
@@ -73,9 +79,24 @@ class NCBITaxonomy:
         """
 
         try:
-            self.df_nodes.columns = ["taxid", "parent", "rank", 4, 5, "gc_id", "mt_id", 7, 8, 9, 10, 11, 12, 13]
+            self.df_nodes.columns = [
+                "taxid",
+                "parent",
+                "rank",
+                4,
+                5,
+                "gc_id",
+                "mt_id",
+                7,
+                8,
+                9,
+                10,
+                11,
+                12,
+                13,
+            ]
             del self.df_nodes[13]
-        except:
+        except Exception:  # pragma: no cover
             self.df_nodes.columns = ["taxid", "parent", "rank", 4, 5]
             del self.df_nodes[5]
 
@@ -87,8 +108,8 @@ class NCBITaxonomy:
         if os.path.exists(names):
             self.df_names = pd.read_csv(names, sep="|", header=None)
         else:
-            with TempFile() as fout_names:
-                logger.info("Loading names.dmp from an URL {}".format(names))
+            with tempfile.TemporaryFile() as fout_names:
+                logger.info(f"Loading names.dmp from an URL {names}")
                 wget(names, fout_names.name)
                 self.df_names = pd.read_csv(fout_names.name, sep="|", header=None)
 
@@ -99,35 +120,32 @@ class NCBITaxonomy:
         self.df_names.columns = ["taxid", "name", "unique_name", "key"]
         self.df_names.set_index("taxid", inplace=True)
 
-    def create_taxonomy_file(self, filename="taxonomy.dat"):
-        logger.info("Please wait while creating the output file. " "This may take a few minutes")
-        from easydev import Progress
+    def create_taxonomy_file(self, filename="taxonomy.csv.gz"):
+
+        filename = Path(filename)
+        logger.info("Please wait while creating the output file. This may take a few minutes")
+        if filename.suffixes != [".csv", ".gz"]:
+            raise ValueError(f"{filename} extension must be '.csv.gz'")
 
-        pb = Progress(len(self.df_nodes))
         count = 0
         df_names = self.df_names.query("key == 'scientific name'").copy()
-        with open(filename, "w") as fout:
 
-            for taxid in self.df_nodes.index:
+        # first we create the CSV file
+        logger.info("Creating CSV file")
+        with filename.with_suffix("").open(mode="w") as fout:
+            fout.write("id,parent,rank,scientific_name\n")
+
+            for taxid in tqdm(self.df_nodes.index):
                 row = self.df_nodes.loc[taxid]
-                fout.write("ID                        : {}\n".format(taxid))
-                fout.write("PARENT ID                 : {}\n".format(row.parent))
-                fout.write("RANK                      : {}\n".format(row["rank"]))
+                sc = df_names.loc[taxid, "name"]
+                fout.write(f"{taxid},{row.parent},{row['rank']},{sc}\n")
 
-                # names = df_names.loc[taxid]
-                # print(
-                fout.write("{:26s}: {}\n".format("SCIENTIFIC NAME", df_names.loc[taxid, "name"]))
-                """    len(names)
-                    for k,v in zip(names['key'], names['name']):
-                        if k.upper() in ['SCIENTIFIC NAME', 'SYNONYM']:
-                            fout.write("{:26s}: {}\n".format(k.upper(), v))
-                except:
-                    k, v = names['key'], names['name']
-                    fout.write("{:26s}: {}\n".format(k.upper(), v))
-                """
-                fout.write("//\n")
-                count += 1
-                pb.animate(count)
+        # second, we gzip it. input must be read as binary
+        logger.info("Compressing CSV file")
+        with filename.with_suffix("").open(mode="rb") as fin:
+            bindata = fin.read()
+            with gzip.open(filename, "wb") as f:
+                f.write(bindata)
 
 
 def load_taxons(f):
@@ -173,6 +191,9 @@ class Taxonomy(metaclass=Singleton):
     ranks are about lineage. For a given rank, e.g. kingdom, you may have sub division such
     as superkingdom and subkingdom. order has even more subdivisions (infra, parv, sub, super)
 
+    Since version 0.8.3 we use NCBI that is updated more often than the ebi
+    ftp according to their README. ftp://ncbi.nlm.nih.gov/pub/taxonomy/
+    We use Ensembl to retrieve various information regarding taxons.
     """
 
     def __init__(self, filename=None, verbose=True, online=True, source="ncbi"):
@@ -182,7 +203,6 @@ class Taxonomy(metaclass=Singleton):
             may hang for a while and fail. If so, set **offline** to True
         :param from: download taxonomy databases from ncbi
         """
-
         assert source in ["ncbi", "ena"]
         self.source = source
 
@@ -195,44 +215,24 @@ class Taxonomy(metaclass=Singleton):
         self.verbose = verbose
 
         if filename is None:
-            self._dbname = "taxonomy.dat"
+            self._dbname = "taxonomy.csv.gz"
             self.database = sequana_config_path + os.sep + self._dbname
         else:
+            assert str(filename).endswith(".csv.gz")
             self.database = filename
 
         self._custom_db = sequana_config_path
-        self._custom_db += "/taxonomy/taxonomy_custom.dat"
-
-    def _update_custom_taxonomy_bases(self, taxid):  # pragma: no cover
-        """ """
-        taxid = str(taxid)
-        self.eutils = EUtils(verbose=False)
-        res = self.eutils.taxonomy_summary(taxid)
-        if "error" in res[taxid]:
-            print("not found in NCBI (EUtils)")
-        else:
-            print("found in NCBI (EUtils) and added to local databases")
-            with open(self.custom_db, "w") as fout:
-                data = res[taxid]
-                fout.write("ID : {}\n".format(taxid))
-                # fout.write("PARENT ID : {}\n".format(taxid))
-                fout.write("RANK : {}\n".format(data["rank"]))
-                # fout.write("GC ID : {}\n".format(data['']))
-                fout.write("SCIENTIFIC NAME : {}\n".format(data["scientificname"]))
+        self._custom_db += "/taxonomy/taxonomy_custom.csv.gz"
 
     def download_taxonomic_file(self, overwrite=False):  # pragma: no cover
-        """Loads entire flat file from EBI
+        """Loads entire flat file from NCBI
 
         Do not overwrite the file by default.
         """
-        import ftplib
-        from sequana import sequana_config_path
 
         if os.path.exists(self.database) and overwrite is False:
-            logger.info("Found taxonomy.dat file in sequana your path {}".format(sequana_config_path))
+            logger.info(f"Found {self.database} file in sequana your path {sequana_config_path}")
             return
-        else:
-            logger.info("Downloading and extracting the taxonomy file from the web. Please be patient.")
 
         if self.source == "ena":
             url = "ftp.ebi.ac.uk"
@@ -246,76 +246,48 @@ class Taxonomy(metaclass=Singleton):
             self.ftp.cwd("pub")
             self.ftp.cwd("databases")
             self.ftp.cwd("taxonomy")
-            logger.warning(
-                "Downloading and saving in %s. This is from ebi and may be behind the NCBI taxonomy" % self.database
-            )
+            logger.warning("Downloading and saving data in {self.database}")
             self.ftp.retrbinary("RETR taxonomy.dat", open(self.database, "wb").write)
             ftp.close()
         else:
             self.ftp.cwd("pub")
             self.ftp.cwd("taxonomy")
-            logger.warning("Downloading and saving in %s from ncbi ftp" % self.database)
-            import tempfile
-            import shutil
+            logger.warning(f"Downloading and saving data in {self.database}")
 
             with tempfile.TemporaryDirectory() as tmpdir:
                 filename = tmpdir + os.sep + "taxdump.tar.gz"
                 self.ftp.retrbinary("RETR taxdump.tar.gz", open(filename, "wb").write)
-                import tarfile
 
                 tf = tarfile.open(filename)
                 assert "nodes.dmp" in tf.getnames()
                 assert "names.dmp" in tf.getnames()
+                logger.info("Extracting nodes.dmp")
                 tf.extract("nodes.dmp", tmpdir)
+                logger.info("Extracting names.dmp")
                 tf.extract("names.dmp", tmpdir)
+
+                logger.info("Extracting and building local database")
                 ncbi = NCBITaxonomy(tmpdir + os.sep + "names.dmp", tmpdir + os.sep + "nodes.dmp")
-                ncbi.create_taxonomy_file(tmpdir + os.sep + "taxonomy.dat")
-                shutil.move(tmpdir + os.sep + "taxonomy.dat", self.database)
+
+                tmp_taxfile = tmpdir + os.sep + "taxonomy.csv.gz"
+                ncbi.create_taxonomy_file(tmp_taxfile)
+                shutil.move(tmp_taxfile, self.database)
+
             self.ftp.close()
 
     def load_records(self, overwrite=False):
-        """Load a flat file and store records in :attr:`records`
-
-        Since version 0.8.3 we use NCBI that is updated more often than the ebi
-        ftp according to their README.
-
-        ftp://ncbi.nlm.nih.gov/pub/taxonomy/
-
-        """
+        """Load a flat file and store records in :attr:`records`"""
         self.download_taxonomic_file(overwrite=overwrite)
-        self.records = {}
 
-        # TODO: check if it exists otherwise, load it ?
-        if os.path.exists(self.database) is False:
-            self.load()
+        # for usecols=range(4) cause last column may contain extra commas
+        try:
+            self.records = pd.read_csv(self.database, index_col=0, compression="gzip", usecols=range(4))
+        except gzip.BadGzipFile:
+            logger.error(f"input file {self.database} should be gzipped")
+            raise gzip.BadGzipFile
 
-        with open(self.database) as f:
-            data = f.read().strip()
-
-        # This is fast. tried parse package, much slower. cost of progress bar
-        # is not important.
-        data = data.split("//\n")  # the sep is //\n
-        self._child_match = re.compile(r"ID\s+\:\s*(\d+)\s*")
-        self._parent_match = re.compile(r"PARENT ID\s+\:\s*(\d+)\s*")
-        self._rank_match = re.compile(r"RANK\s+\:\s*([^\n]+)\s*")
-        self._name_match = re.compile(r"SCIENTIFIC NAME\s+\:\s*([^\n]+)\s*")
-
-        from easydev import Progress
-
-        pb = Progress(len(data))
-
-        logger.info("Loading all taxon records.")
-        for i, record in enumerate(data[0:]):
-            dd = {"raw": record}
-            dd["id"] = int(self._child_match.search(record).group(1))
-            dd["parent"] = int(self._parent_match.search(record).group(1))
-            dd["scientific_name"] = self._name_match.search(record).group(1)
-            dd["rank"] = self._rank_match.search(record).group(1)
-            self.records[dd["id"]] = dd
-            if self.verbose:
-                pb.animate(i + 1)
-        if self.verbose:
-            print()
+    def load_records_from_csv(self, filename):
+        df = pd.read_csv(filename)
 
     def find_taxon(self, taxid, mode="ncbi"):
         taxid = str(taxid)
@@ -371,17 +343,15 @@ class Taxonomy(metaclass=Singleton):
 
         """
         # important to reinit the second argument to []
-        taxon = int(taxon)
         lineage = self._gen_lineage_and_rank(taxon, [])
-        lineage = [x[0] for x in lineage]
-        return lineage
+        return [x[0] for x in lineage]
 
     @load_taxons
     def _gen_lineage_and_rank(self, taxon, lineage_rank=[]):
         # recursively filling the lineage argument
 
         try:
-            record = self.records[taxon]
+            record = self.records.loc[taxon]
         except:
             return [("unknown_taxon:{}".format(taxon), "no rank")]
 
@@ -397,12 +367,12 @@ class Taxonomy(metaclass=Singleton):
 
     @load_taxons
     def get_parent_taxon(self, taxon):
-        return self.records[taxon]["parent"]
+        return self.records.loc[taxon, "parent"]
 
     @load_taxons
     def get_parent_name(self, taxon):
         taxid = self.get_parent_taxon(taxon)
-        return self.records[taxid]["scientific_name"]
+        return self.records.loc[taxid, "scientific_name"]
 
     @load_taxons
     def get_lineage_and_rank(self, taxon):
@@ -413,63 +383,26 @@ class Taxonomy(metaclass=Singleton):
             The list is the lineage for to the input taxon.
 
         """
-        taxon = int(taxon)
-        lineage = self._gen_lineage_and_rank(taxon, [])
-        return lineage
+        return self._gen_lineage_and_rank(taxon, [])
 
     @load_taxons
     def get_ranks(self):
-        return Counter([x["rank"] for x in self.records.values()])
+        return self.records.groupby("rank").count().parent.sort_values()
 
-    @load_taxons
-    def get_record_for_given_rank(self, rank):
-        return [x for x in self.records.values() if x["rank"] == rank]
+    def get_records_for_given_rank(self, rank):
+        return self.records.query("rank == @rank")
 
     @load_taxons
     def get_names_for_given_rank(self, rank):
-        data = [x for x in self.records.values() if x["rank"] == rank]
-        return [x["scientific_name"] for x in data]
+        return self.records.query("rank == @rank").scientific_name.unique()
 
     @load_taxons
     def get_children(self, taxon):
-        taxon = str(taxon)
-        children = [self.records[k] for k in self.records.keys() if self.records[k]["parent"] == taxon]
-        children = [child["id"] for child in children]
-        return children
-
-    @load_taxons
-    def __getitem__(self, iden):
-        return self.records[iden]
+        return self.records.query("parent == @taxon").index.values
 
     @load_taxons
     def __len__(self):
         return len(self.records)
 
-    def append_existing_database(self, filename):
-        """
-
-        Taxonomy DB looks like::
-
-            ID                        : 2731450
-            PARENT ID                 : 1914233
-            RANK                      : genus
-            SCIENTIFIC NAME           : Limnoglobus
-            //
-
-
-            a = NCBITaxonomy("names.dmp", "nodes.dmp")
-            a.create_taxonomy_file("taxonomy.dat")
-            tax = Taxonomy()
-            tax.append_existing_database("taxonomy.dat")
-        """
-        tax = Taxonomy(filename)
-        tax.load_records()
-        self.load_records()
-        toadd = []
-        for record in tax.records.keys():
-            if record not in self.records:
-                toadd.append(record)
-
-        with open(self.database, "a") as fout: #pragma: no cover
-            for record in toadd:
-                fout.write(tax.records[record]["raw"] + "//\n")
+    def __getitem__(self, taxon):
+        return self.records.loc[taxon]
