@@ -10,25 +10,23 @@
 #
 ##############################################################################
 """General tools"""
-import os
-import string
-import glob
-import json
-import re
 import gzip
 import io
+import json
+import os
+import re
+import shutil
+import string
+import subprocess
 from collections import Counter
 
-from sequana.lazy import pandas as pd
-from sequana.lazy import numpy as np
-from sequana import BAM
-
-from pysam import FastxFile
-from easydev import precision
-from easydev.misc import cmd_exists
-import subprocess
-from tqdm import tqdm
 import colorlog
+from tqdm import tqdm
+
+from sequana.bamtools import BAM
+from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
+from sequana.lazy import pysam
 
 logger = colorlog.getLogger(__name__)
 
@@ -36,14 +34,6 @@ logger = colorlog.getLogger(__name__)
 __all__ = ["StatsBAM2Mapped", "bam_to_mapped_unmapped_fastq", "GZLineCounter"]
 
 
-
-
-#try:
-#    _translate = string.maketrans("ACGTacgt", "TGCAtgca")
-#
-#    def bytes(x, dummy):
-#        return x
-#except:
 _translate = bytes.maketrans(b"ACGTacgt", b"TGCAtgca")
 
 
@@ -70,7 +60,7 @@ class StatsBAM2Mapped:
     def to_html(self):
         data = self.data
 
-        html = "Reads with Phix: %s %%<br>" % precision(data["contamination"], 3)
+        html = "Reads with Phix: %s %%<br>" % round(data["contamination"], 3)
 
         # add HTML table
         if "R2_mapped" in data.keys():
@@ -183,7 +173,6 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, progress=True)
     # loop through the BAM (make sure it is rewinded)
     bam.reset()
 
-
     for this in tqdm(bam, disable=not progress):
         if this.flag & 256:
             # Unmapped reads are in the BAM file but have no valid assigned
@@ -198,7 +187,6 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, progress=True)
             if this.is_paired is False:
                 stats["unpaired"] += 1
         else:
-
             # quick hack
             if this.is_read1:
                 suffix = b"/1"
@@ -234,7 +222,7 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, progress=True)
                 else:
                     R2_mapped.write(txt)
                     stats["R2_mapped"] += 1
-            else: #pragma: no cover
+            else:  # pragma: no cover
                 # This should be a single read
                 # assert self.is_paired is False
                 stats["unpaired"] += 1
@@ -252,7 +240,6 @@ def bam_to_mapped_unmapped_fastq(filename, output_directory=None, progress=True)
         R2_mapped.close()
         R2_unmapped.close()
 
-
     R1_mapped.close()
     R1_unmapped.close()
 
@@ -284,7 +271,6 @@ def bam_get_paired_distance(filename):
 
     for fragment in b:
         if not fragment.is_unmapped and not fragment.mate_is_unmapped and fragment.is_read1:
-
             # get the mate:
             mate = next(b)
 
@@ -326,7 +312,7 @@ def fast_gc_content(chrom):
 
 def _base_content(filename, window_size, letters, circular=False):
     # DOC: see gc_content
-    fasta = FastxFile(filename)
+    fasta = pysam.FastxFile(filename)
     checker = set(letters)
     chrom_gc_content = dict()
     for chrom in fasta:
@@ -461,9 +447,9 @@ class GZLineCounter(object):
 
     def __init__(self, filename):
         self.filename = filename
-        if cmd_exists("zcat"):
+        if shutil.which("zcat"):
             self.use_zcat = True
-        else: #pragma: no cover
+        else:  # pragma: no cover
             self.use_zcat = False
 
     def __len__(self):
