@@ -19,42 +19,32 @@
 """ Sequana report config contains configuration informations to create HTML
 report with Jinja2.
 """
-import sys
-import os
-import pkg_resources
 import glob
-from pathlib import Path
+import inspect
+import os
+import sys
 from datetime import datetime
+from pathlib import Path
 
-import easydev
+import sequana
+from sequana import version
 
 time_now = datetime.now().strftime("%m-%d-%Y %H:%M:%S")
 
-# Get sequana informations
-version = pkg_resources.get_distribution("sequana").version
 script_path = os.path.dirname(os.path.realpath(__file__))
 
 # Default options
 output_dir = os.path.realpath(os.getcwd())
 
-
-def get_entry_name(entry_point):
-    return str(entry_point).split("=")[0].strip()
+sequana_path = Path(inspect.getfile(sequana)).parent
 
 
-# Modules available
-module_dict = {
-    get_entry_name(entry_point): entry_point for entry_point in pkg_resources.iter_entry_points("sequana.module")
-}
+css_path = sequana_path / "resources" / "css"
+js_path = sequana_path / "resources" / "js"
+images_path = sequana_path / "resources" / "images"
 
-# Find css/js file necessary for the report
-sequana_path = easydev.get_package_location("sequana")
-css_path = os.sep.join([sequana_path, "sequana", "resources", "css"])
-js_path = os.sep.join([sequana_path, "sequana", "resources", "js"])
-images_path = Path(sequana_path) / "sequana" / "resources" / "images"
-
-css_list = glob.glob(css_path + os.sep + "*css")
-js_list = glob.glob(js_path + os.sep + "*js")
+css_list = [str(x) for x in css_path.glob("*css")]
+js_list = [str(x) for x in js_path.glob("*js")]
 logo = images_path / "logo_256x256.png"
 
 # Sections list for summary.html
