@@ -16,12 +16,10 @@
 ##############################################################################
 
 
-from sequana.viz import Imshow
 from sequana.lazy import numpy as np
 from sequana.lazy import pandas as pd
 
-
-__all__ = ['ANOVA']
+__all__ = ["ANOVA"]
 
 
 class ANOVA(object):
@@ -29,9 +27,9 @@ class ANOVA(object):
 
     Testing if 3(+) population means are all equal.
 
-    Looks like the group are different, visually, and naively. 
+    Looks like the group are different, visually, and naively.
 
-    .. plot:: 
+    .. plot::
         :include-source:
 
         from pylab import *
@@ -49,7 +47,6 @@ class ANOVA(object):
     """
 
     def __init__(self, df):
-
         self.df = df.copy()
 
     def anova(self):
@@ -62,27 +59,31 @@ class ANOVA(object):
         return: the F value (test itself), and its p-value
         """
         import scipy.stats
+
         F, P = scipy.stats.f_oneway(*[self.df[x] for x in self.df.columns])
         return F, P
 
     def imshow_anova_pairs(self, log=True, **kargs):
+        # avoids circular imports
         import scipy.stats
+
+        from sequana.viz import Imshow
+
         N = len(self.df.columns)
 
         # could use a dataframe straight way ?
         res = np.ones((N, N))
-        for i,col1 in enumerate(self.df.columns):
-            for j,col2 in enumerate(self.df.columns):
+        for i, col1 in enumerate(self.df.columns):
+            for j, col2 in enumerate(self.df.columns):
                 d1 = self.df[col1]
                 d2 = self.df[col2]
                 F, P = scipy.stats.f_oneway(*[d1, d2])
                 res[i][j] = P
         df = pd.DataFrame(res, index=self.df.columns, columns=self.df.columns)
-        #FIXME: may have na, which are set to 1
+        # FIXME: may have na, which are set to 1
         df = df.fillna(1)
         if log is True:
             Imshow(-np.log10(df)).plot(**kargs)
         else:
             Imshow(df).plot(**kargs)
         return df
-
