@@ -17,25 +17,24 @@
 
 """
 import string
-import matplotlib.pyplot as plt
+
+import colorlog
 import matplotlib.cm as cm
-from matplotlib.patches import Ellipse, Circle, Rectangle, Wedge
-from matplotlib.collections import PatchCollection
+import matplotlib.pyplot as plt
 import scipy.cluster.hierarchy as hierarchy
 from colormap import cmap_builder
-
+from matplotlib.collections import PatchCollection
+from matplotlib.patches import Circle, Ellipse, Rectangle, Wedge
 
 from sequana.viz.linkage import Linkage
 
-import colorlog
 logger = colorlog.getLogger(__name__)
 
 
-from sequana.lazy import pandas as pd
 from sequana.lazy import numpy as np
+from sequana.lazy import pandas as pd
 
-
-__all__ = ['Corrplot']
+__all__ = ["Corrplot"]
 
 
 class Corrplot(Linkage):
@@ -64,6 +63,7 @@ class Corrplot(Linkage):
         `notebook <http://nbviewer.ipython.org/github/sequana/sequana/blob/main/notebooks/viz/corrplot.ipynb>`_
 
     """
+
     def __init__(self, data, na=0, compute_correlation=False):
         """.. rubric:: Constructor
 
@@ -95,9 +95,9 @@ class Corrplot(Linkage):
         compute_correlation = False
 
         w, h = self.df.shape
-        if self.df.max().max() > 1 or self.df.min().min()<-1:
+        if self.df.max().max() > 1 or self.df.min().min() < -1:
             compute_correlation = True
-        if w !=h:
+        if w != h:
             compute_correlation = True
         if list(self.df.index) != list(self.df.columns):
             compute_correlation = True
@@ -111,15 +111,12 @@ class Corrplot(Linkage):
         self.df.fillna(na, inplace=True)
 
         #: tunable parameters for the :meth:`plot` method.
-        self.params = {
-                'colorbar.N': 100,
-                'colorbar.shrink': .8,
-                'colorbar.orientation':'vertical'}
+        self.params = {"colorbar.N": 100, "colorbar.shrink": 0.8, "colorbar.orientation": "vertical"}
 
     def _set_default_cmap(self):
-        self.cm = cmap_builder('#AA0000','white','darkblue')
+        self.cm = cmap_builder("#AA0000", "white", "darkblue")
 
-    def order(self, method='complete', metric='euclidean',inplace=False):
+    def order(self, method="complete", metric="euclidean", inplace=False):
         """Rearrange the order of rows and columns after clustering
 
         :param method: any scipy method (e.g., single, average, centroid,
@@ -132,10 +129,10 @@ class Corrplot(Linkage):
         the two parameters order_metric and order_method instead.
         """
         Y = self.linkage(self.df, method=method, metric=metric)
-        ind1 = hierarchy.fcluster(Y, 0.7*max(Y[:,2]), 'distance')
+        ind1 = hierarchy.fcluster(Y, 0.7 * max(Y[:, 2]), "distance")
         Z = hierarchy.dendrogram(Y, no_plot=True)
-        idx1 = Z['leaves']
-        cor2 = self.df.iloc[idx1,idx1]
+        idx1 = Z["leaves"]
+        cor2 = self.df.iloc[idx1, idx1]
         if inplace is True:
             self.df = cor2
         else:
@@ -145,21 +142,35 @@ class Corrplot(Linkage):
         self.idx1 = idx1
         self.ind1 = ind1
 
-        #treee$order == Z.leaves and c.idx1
+        # treee$order == Z.leaves and c.idx1
         # hc = c.ind1
 
-        #clustab <- table(hc)[unique(hc[tree$order])]
-        #cu <- c(0, cumsum(clustab))
-        #mat <- cbind(cu[-(k + 1)] + 0.5, n - cu[-(k + 1)] + 0.5,
-        #cu[-1] + 0.5, n - cu[-1] + 0.5)
-        #rect(mat[,1], mat[,2], mat[,3], mat[,4], border = col, lwd = lwd)
+        # clustab <- table(hc)[unique(hc[tree$order])]
+        # cu <- c(0, cumsum(clustab))
+        # mat <- cbind(cu[-(k + 1)] + 0.5, n - cu[-(k + 1)] + 0.5,
+        # cu[-1] + 0.5, n - cu[-1] + 0.5)
+        # rect(mat[,1], mat[,2], mat[,3], mat[,4], border = col, lwd = lwd)
 
-    def plot(self, fig=None, grid=True,
-            rotation=30, lower=None, upper=None,
-            shrink=0.9, facecolor='white', colorbar=True, label_color='black',
-            fontsize='small', edgecolor='black', method='ellipse',
-            order_method='complete', order_metric='euclidean', cmap=None,
-            ax=None, binarise_color=False):
+    def plot(
+        self,
+        fig=None,
+        grid=True,
+        rotation=30,
+        lower=None,
+        upper=None,
+        shrink=0.9,
+        facecolor="white",
+        colorbar=True,
+        label_color="black",
+        fontsize="small",
+        edgecolor="black",
+        method="ellipse",
+        order_method="complete",
+        order_metric="euclidean",
+        cmap=None,
+        ax=None,
+        binarise_color=False,
+    ):
         """plot the correlation matrix from the content of :attr:`df`
         (dataframe)
 
@@ -233,7 +244,7 @@ class Corrplot(Linkage):
 
         # do we have an axes to plot the data in ?
         if ax is None:
-            ax = plt.subplot(1, 1, 1, aspect='equal', facecolor=facecolor)
+            ax = plt.subplot(1, 1, 1, aspect="equal", facecolor=facecolor)
         else:
             # if so, clear the axes. Colorbar cannot be removed easily.
             plt.sca(ax)
@@ -243,213 +254,245 @@ class Corrplot(Linkage):
         fig.set_facecolor(facecolor)
 
         width, height = df.shape
-        labels = (df.columns)
+        labels = df.columns
 
         # add all patches to the figure
         # TODO check value of lower and upper
 
         if upper is None and lower is None:
-            mode = 'method'
+            mode = "method"
             diagonal = True
         elif upper and lower:
-            mode = 'both'
+            mode = "both"
             diagonal = False
         elif lower is not None:
-            mode = 'lower'
+            mode = "lower"
             diagonal = True
         elif upper is not None:
-            mode = 'upper'
+            mode = "upper"
             diagonal = True
 
         self.binarise_color = binarise_color
-        if mode == 'upper':
-            self._add_patches(df, upper, 'upper',  ax, diagonal=True)
-        elif mode == 'lower':
-            self._add_patches(df, lower, 'lower',  ax, diagonal=True)
-        elif mode == 'method':
-            self._add_patches(df, method, 'both',  ax, diagonal=True)
-        elif mode == 'both':
-            self._add_patches(df, upper, 'upper',  ax, diagonal=False)
-            self._add_patches(df, lower, 'lower',  ax, diagonal=False)
-
+        if mode == "upper":
+            self._add_patches(df, upper, "upper", ax, diagonal=True)
+        elif mode == "lower":
+            self._add_patches(df, lower, "lower", ax, diagonal=True)
+        elif mode == "method":
+            self._add_patches(df, method, "both", ax, diagonal=True)
+        elif mode == "both":
+            self._add_patches(df, upper, "upper", ax, diagonal=False)
+            self._add_patches(df, lower, "lower", ax, diagonal=False)
 
         # set xticks/xlabels on top
         ax.xaxis.tick_top()
         xtickslocs = np.arange(len(labels))
         ax.set_xticks(xtickslocs)
-        ax.set_xticklabels(labels, rotation=rotation, color=label_color,
-                fontsize=fontsize, ha='left')
+        ax.set_xticklabels(labels, rotation=rotation, color=label_color, fontsize=fontsize, ha="left")
 
         ytickslocs = np.arange(len(labels))
         ax.set_yticks(ytickslocs)
         ax.set_yticklabels(labels, fontsize=fontsize, color=label_color)
-        plt.tight_layout()
+        plt.gcf().set_layout_engine("tight")
 
         # shift the limits to englobe the patches correctly
         # This should be here afer set_xticks
-        ax.set_xlim(-0.5, width-.5)
-        ax.set_ylim(-0.5, height-.5)
+        ax.set_xlim(-0.5, width - 0.5)
+        ax.set_ylim(-0.5, height - 0.5)
         ax.invert_yaxis()
 
         if grid is not False:
             if grid is True:
-                grid = 'grey'
+                grid = "grey"
             for i in range(0, width):
-                ratio1 = float(i)/width
-                ratio2 = float(i+2)/width
+                ratio1 = float(i) / width
+                ratio2 = float(i + 2) / width
                 # TODO 1- set axis off
                 # 2 - set xlabels along the diagonal
                 # set colorbar either on left or bottom
-                if mode == 'lower':
-                    plt.axvline(i+.5, ymin=1-ratio1, ymax=0., color=grid)
-                    plt.axhline(i+.5, xmin=0, xmax=ratio2, color=grid)
-                if mode == 'upper':
-                    plt.axvline(i+.5, ymin=1 - ratio2, ymax=1, color=grid)
-                    plt.axhline(i+.5, xmin=ratio1, xmax=1, color=grid)
-                if mode in ['method', 'both']:
-                    plt.axvline(i+.5, color=grid)
-                    plt.axhline(i+.5, color=grid)
+                if mode == "lower":
+                    plt.axvline(i + 0.5, ymin=1 - ratio1, ymax=0.0, color=grid)
+                    plt.axhline(i + 0.5, xmin=0, xmax=ratio2, color=grid)
+                if mode == "upper":
+                    plt.axvline(i + 0.5, ymin=1 - ratio2, ymax=1, color=grid)
+                    plt.axhline(i + 0.5, xmin=ratio1, xmax=1, color=grid)
+                if mode in ["method", "both"]:
+                    plt.axvline(i + 0.5, color=grid)
+                    plt.axhline(i + 0.5, color=grid)
 
             # can probably be simplified
-            if mode == 'lower':
-                plt.axvline(-.5, ymin=0, ymax=1, color='grey')
-                plt.axvline(width-.5, ymin=0, ymax=1./width, color='grey', lw=2)
-                plt.axhline(width-.5, xmin=0, xmax=1, color='grey',lw=2)
-                plt.axhline(-.5, xmin=0, xmax=1./width, color='grey',lw=2)
+            if mode == "lower":
+                plt.axvline(-0.5, ymin=0, ymax=1, color="grey")
+                plt.axvline(width - 0.5, ymin=0, ymax=1.0 / width, color="grey", lw=2)
+                plt.axhline(width - 0.5, xmin=0, xmax=1, color="grey", lw=2)
+                plt.axhline(-0.5, xmin=0, xmax=1.0 / width, color="grey", lw=2)
                 plt.xticks([])
                 for i in range(0, width):
-                    plt.text(i, i-.6 ,labels[i],fontsize=fontsize,
-                            color=label_color,
-                            rotation=rotation, verticalalignment='bottom')
-                    plt.text(-.6, i ,labels[i],fontsize=fontsize,
-                            color=label_color,
-                            rotation=0, horizontalalignment='right')
-                plt.axis('off')
+                    plt.text(
+                        i,
+                        i - 0.6,
+                        labels[i],
+                        fontsize=fontsize,
+                        color=label_color,
+                        rotation=rotation,
+                        verticalalignment="bottom",
+                    )
+                    plt.text(
+                        -0.6,
+                        i,
+                        labels[i],
+                        fontsize=fontsize,
+                        color=label_color,
+                        rotation=0,
+                        horizontalalignment="right",
+                    )
+                plt.axis("off")
             # can probably be simplified
-            elif mode == 'upper':
-                plt.axvline(width-.5, ymin=0, ymax=1, color='grey', lw=2)
-                plt.axvline(-.5, ymin=1-1./width, ymax=1, color='grey', lw=2)
-                plt.axhline(-.5, xmin=0, xmax=1, color='grey',lw=2)
-                plt.axhline(width-.5, xmin=1-1./width, xmax=1, color='grey',lw=2)
+            elif mode == "upper":
+                plt.axvline(width - 0.5, ymin=0, ymax=1, color="grey", lw=2)
+                plt.axvline(-0.5, ymin=1 - 1.0 / width, ymax=1, color="grey", lw=2)
+                plt.axhline(-0.5, xmin=0, xmax=1, color="grey", lw=2)
+                plt.axhline(width - 0.5, xmin=1 - 1.0 / width, xmax=1, color="grey", lw=2)
                 plt.yticks([])
                 for i in range(0, width):
-                    plt.text(-.6+i, i ,labels[i],fontsize=fontsize,
-                            color=label_color, horizontalalignment='right',
-                            rotation=0)
-                    plt.text(i, -.5 ,labels[i],fontsize=fontsize,
-                            color=label_color, rotation=rotation, verticalalignment='bottom')
-                plt.axis('off')
+                    plt.text(
+                        -0.6 + i,
+                        i,
+                        labels[i],
+                        fontsize=fontsize,
+                        color=label_color,
+                        horizontalalignment="right",
+                        rotation=0,
+                    )
+                    plt.text(
+                        i,
+                        -0.5,
+                        labels[i],
+                        fontsize=fontsize,
+                        color=label_color,
+                        rotation=rotation,
+                        verticalalignment="bottom",
+                    )
+                plt.axis("off")
 
         # set all ticks length to zero
         ax = plt.gca()
-        ax.tick_params(axis='both',which='both', length=0)
+        ax.tick_params(axis="both", which="both", length=0)
 
         if colorbar:
-            N = self.params['colorbar.N'] + 1
-            assert N >=2
+            N = self.params["colorbar.N"] + 1
+            assert N >= 2
             # make sure the colorbar limits remains between the min (0) and the
             # max (1) (remember colormap are normalised) so that if data is
             # between -0.5 and let us say +1, the colors do not start at -0.5
-            # but -1 indeed. 
-            self.collection.set_clim(0,1)
-            cb = plt.gcf().colorbar(self.collection,
-                    orientation=self.params['colorbar.orientation'],
-                    shrink=self.params['colorbar.shrink'],
-                    boundaries= np.linspace(0,1,N), 
-                    ticks=[0,.25, 0.5, 0.75,1])
-            cb.ax.set_yticklabels([-1,-.5,0,.5,1])
+            # but -1 indeed.
+            self.collection.set_clim(0, 1)
+            cb = plt.gcf().colorbar(
+                self.collection,
+                orientation=self.params["colorbar.orientation"],
+                shrink=self.params["colorbar.shrink"],
+                boundaries=np.linspace(0, 1, N),
+                ticks=[0, 0.25, 0.5, 0.75, 1],
+            )
+            cb.ax.set_yticklabels([-1, -0.5, 0, 0.5, 1])
             return cb
 
     def _add_patches(self, df, method, fill, ax, diagonal=True):
         width, height = df.shape
-        labels = (df.columns)
+        labels = df.columns
 
         patches = []
         colors = []
         for x in range(width):
             for y in range(height):
-                if fill == 'lower' and x > y:
+                if fill == "lower" and x > y:
                     continue
-                elif fill == 'upper' and x < y:
+                elif fill == "upper" and x < y:
                     continue
-                if diagonal is False and x==y:
+                if diagonal is False and x == y:
                     continue
 
-                datum = (df.iloc[x, y] +1.)/2.
+                datum = (df.iloc[x, y] + 1.0) / 2.0
                 d = df.iloc[x, y]
                 d_abs = np.abs(d)
-                #c = self.pvalues[x, y]
+                # c = self.pvalues[x, y]
                 rotate = -45 if d > 0 else +45
-                #cmap = self.poscm if d >= 0 else self.negcm
-                if method in ['ellipse', 'square', 'rectangle', 'color']:
-                    if method == 'ellipse':
+                # cmap = self.poscm if d >= 0 else self.negcm
+                if method in ["ellipse", "square", "rectangle", "color"]:
+                    if method == "ellipse":
                         func = Ellipse
-                        patch = func((x, y), width=1 * self.shrink,
-                                  height=(self.shrink - d_abs*self.shrink), angle=rotate)
+                        patch = func(
+                            (x, y), width=1 * self.shrink, height=(self.shrink - d_abs * self.shrink), angle=rotate
+                        )
                     else:
                         func = Rectangle
                         w = h = d_abs * self.shrink
-                        #FIXME shring must be <=1
-                        offset = (1-w)/2.
-                        if method == 'color':
+                        # FIXME shring must be <=1
+                        offset = (1 - w) / 2.0
+                        if method == "color":
                             w = 1
                             h = 1
                             offset = 0
-                        patch = func((x + offset-.5, y + offset-.5), width=w,
-                                  height=h, angle=0)
+                        patch = func((x + offset - 0.5, y + offset - 0.5), width=w, height=h, angle=0)
                     if self.edgecolor:
                         patch.set_edgecolor(self.edgecolor)
-                    #patch.set_facecolor(cmap(d_abs))
+                    # patch.set_facecolor(cmap(d_abs))
                     colors.append(datum)
                     if d_abs > 0.05:
-                        patch.set_linestyle('dotted')
-                    #ax.add_artist(patch)
+                        patch.set_linestyle("dotted")
+                    # ax.add_artist(patch)
                     patches.append(patch)
-                    #FIXME edgecolor is always printed
-                elif method=='circle':
-                    patch = Circle((x, y), radius=d_abs*self.shrink/2.)
+                    # FIXME edgecolor is always printed
+                elif method == "circle":
+                    patch = Circle((x, y), radius=d_abs * self.shrink / 2.0)
                     if self.edgecolor:
                         patch.set_edgecolor(self.edgecolor)
-                    #patch.set_facecolor(cmap(d_abs))
+                    # patch.set_facecolor(cmap(d_abs))
                     colors.append(datum)
                     if d_abs > 0.05:
-                        patch.set_linestyle('dotted')
-                    #ax.add_artist(patch)
+                        patch.set_linestyle("dotted")
+                    # ax.add_artist(patch)
                     patches.append(patch)
-                elif method in ['number', 'text']:
-                    if d<0:
+                elif method in ["number", "text"]:
+                    if d < 0:
                         edgecolor = self.cm(-1.0)
-                    elif d>=0:
+                    elif d >= 0:
                         edgecolor = self.cm(1.0)
                     d_str = "{:.2f}".format(d).replace("0.", ".").replace(".00", "")
                     # min is to guarantee that alpha<=1 on Python >3.8
-                    ax.text(x,y, d_str, color=edgecolor,
-                            fontsize=self.fontsize, horizontalalignment='center',
-                            weight='bold', alpha=min(1,max(0.5, d_abs)))
-                            # withdash=False)
-                elif method == 'pie':
+                    ax.text(
+                        x,
+                        y,
+                        d_str,
+                        color=edgecolor,
+                        fontsize=self.fontsize,
+                        horizontalalignment="center",
+                        weight="bold",
+                        alpha=min(1, max(0.5, d_abs)),
+                    )
+                    # withdash=False)
+                elif method == "pie":
                     S = 360 * d_abs
                     patch = [
-                        Wedge((x,y), 1*self.shrink/2., -90, S-90),
-                        Wedge((x,y), 1*self.shrink/2., S-90, 360-90),
-                        ]
-                    #patch[0].set_facecolor(cmap(d_abs))
-                    #patch[1].set_facecolor('white')
+                        Wedge((x, y), 1 * self.shrink / 2.0, -90, S - 90),
+                        Wedge((x, y), 1 * self.shrink / 2.0, S - 90, 360 - 90),
+                    ]
+                    # patch[0].set_facecolor(cmap(d_abs))
+                    # patch[1].set_facecolor('white')
                     colors.append(datum)
                     colors.append(0.5)
                     if self.edgecolor:
                         patch[0].set_edgecolor(self.edgecolor)
                         patch[1].set_edgecolor(self.edgecolor)
 
-                    #ax.add_artist(patch[0])
-                    #ax.add_artist(patch[1])
+                    # ax.add_artist(patch[0])
+                    # ax.add_artist(patch[1])
                     patches.append(patch[0])
                     patches.append(patch[1])
                 else:
-                    raise ValueError('Method for the symbols is not known. Use e.g, square, circle')
+                    raise ValueError("Method for the symbols is not known. Use e.g, square, circle")
 
         if self.binarise_color:
-            colors = [1 if color >0.5 else -1 for color in colors]
+            colors = [1 if color > 0.5 else -1 for color in colors]
 
         if len(patches):
             col1 = PatchCollection(patches, array=np.array(colors), cmap=self.cm)
@@ -458,7 +501,6 @@ class Corrplot(Linkage):
             self.collection = col1
             # Somehow a release of matplotlib prevent the edge color
             # from working but the set_edgecolor on the collection itself does
-            # work... 
+            # work...
             if self.edgecolor:
                 self.collection.set_edgecolor(self.edgecolor)
-
